var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
var __accessCheck = (obj, member, msg) => {
  if (!member.has(obj))
    throw TypeError("Cannot " + msg);
};
var __privateGet = (obj, member, getter) => {
  __accessCheck(obj, member, "read from private field");
  return getter ? getter.call(obj) : member.get(obj);
};
var __privateAdd = (obj, member, value) => {
  if (member.has(obj))
    throw TypeError("Cannot add the same private member more than once");
  member instanceof WeakSet ? member.add(obj) : member.set(obj, value);
};
var __privateSet = (obj, member, value, setter) => {
  __accessCheck(obj, member, "write to private field");
  setter ? setter.call(obj, value) : member.set(obj, value);
  return value;
};
var __privateMethod = (obj, member, method) => {
  __accessCheck(obj, member, "access private method");
  return method;
};
var _a, _b, _session, _user, _shareToken, _currentDirectory, _attachmentDirectory, _getImageAttachmentUrl, getImageAttachmentUrl_fn, _getMediaPreviewUrl, getMediaPreviewUrl_fn, _textApiParams, textApiParams_fn, _previewUrl, previewUrl_fn, _davUrl, davUrl_fn, _relativePath, relativePath_fn, _filePath, filePath_fn;
import { Editor, InputRule, wrappingInputRule, Node, mergeAttributes, isNodeActive, Mark, markInputRule, markPasteRule, Extension } from "@tiptap/core";
import { EditorContent, NodeViewWrapper, NodeViewContent, VueNodeViewRenderer, nodeViewProps } from "@tiptap/vue-2";
import { getLoggerBuilder } from "@nextcloud/logger";
import debounce from "debounce";
import { NcButton, NcUserBubble } from "@nextcloud/vue";
import Vuex, { Store, mapState } from "vuex";
import Vue from "vue";
import { getBuilder } from "@nextcloud/browser-storage";
import Blockquote from "@tiptap/extension-blockquote";
import TiptapBulletList from "@tiptap/extension-bullet-list";
import container from "markdown-it-container";
import CharacterCount from "@tiptap/extension-character-count";
import Code from "@tiptap/extension-code";
import TiptapCodeBlock from "@tiptap/extension-code-block";
import { defaultMarkdownSerializer } from "prosemirror-markdown";
import Document from "@tiptap/extension-document";
import Dropcursor from "@tiptap/extension-dropcursor";
import TiptapParagraph from "@tiptap/extension-paragraph";
import { ReferenceList } from "@nextcloud/vue-richtext";
import TipTapHardBreak from "@tiptap/extension-hard-break";
import TipTapHeading from "@tiptap/extension-heading";
import slugify from "slug";
import { v4 } from "uuid";
import HorizontalRule from "@tiptap/extension-horizontal-rule";
import TiptapImage from "@tiptap/extension-image";
import { Plugin, TextSelection, PluginKey } from "prosemirror-state";
import axios from "@nextcloud/axios";
import ClickOutside from "vue-click-outside";
import { generateUrl, generateRemoteUrl } from "@nextcloud/router";
import ListItem from "@tiptap/extension-list-item";
import TipTapMention from "@tiptap/extension-mention";
import { getCurrentUser } from "@nextcloud/auth";
import OrderedList from "@tiptap/extension-ordered-list";
import { Table as Table$1 } from "@tiptap/extension-table";
import { TableCell as TableCell$1 } from "@tiptap/extension-table-cell";
import { TableHeader as TableHeader$1 } from "@tiptap/extension-table-header";
import { TableRow as TableRow$1 } from "@tiptap/extension-table-row";
import { addRowAfter, selectedRect, addRowBefore, isInTable, selectionCell, moveCellForward } from "@tiptap/prosemirror-tables";
import TipTapTaskItem from "@tiptap/extension-task-item";
import { findParentNodeClosestToPos } from "prosemirror-utils";
import TiptapTaskList from "@tiptap/extension-task-list";
import Text from "@tiptap/extension-text";
import TipTapItalic from "@tiptap/extension-italic";
import TipTapLink from "@tiptap/extension-link";
import MarkdownIt from "markdown-it";
import taskLists from "@hedgedoc/markdown-it-task-lists";
import markdownitMentions from "@quartzy/markdown-it-mentions";
import frontMatter from "markdown-it-front-matter";
import implicitFigures from "markdown-it-image-figures";
import TipTapStrike from "@tiptap/extension-strike";
import { Bold, starInputRegex, starPasteRegex, underscoreInputRegex, underscorePasteRegex } from "@tiptap/extension-bold";
import TipTapUnderline from "@tiptap/extension-underline";
import pathNormalize from "path-normalize";
const logger = getLoggerBuilder().setApp("text").detectUser().build();
const EDITOR = Symbol("tiptap:editor");
const ATTACHMENT_RESOLVER = Symbol("attachment:resolver");
const useEditorMixin = {
  inject: {
    $editor: { from: EDITOR, default: null }
  }
};
const useAttachmentResolver = {
  inject: {
    $attachmentResolver: {
      from: ATTACHMENT_RESOLVER,
      default: {
        resolve(src) {
          logger.warn("No attachment resolver provided. Some attachment sources cannot be resolved.");
          return [src];
        }
      }
    }
  }
};
const OUTLINE_STATE = Symbol("wrapper:outline-state");
const OUTLINE_ACTIONS = Symbol("wrapper:outline-actions");
const useOutlineStateMixin = {
  inject: {
    $outlineState: {
      from: OUTLINE_STATE,
      default: {
        visible: false,
        enable: false
      }
    }
  }
};
const useOutlineActions = {
  inject: {
    $outlineActions: {
      from: OUTLINE_ACTIONS,
      default: {
        toggle: () => {
        }
      }
    }
  }
};
const SET_VIEW_WIDTH = "SET_VIEW_WIDTH";
const SET_SHOW_AUTHOR_ANNOTATIONS = "SET_SHOW_AUTHOR_ANNOTATIONS";
const SET_CURRENT_SESSION = "SET_CURRENT_SESSION";
const SET_HEADINGS = "SET_HEADINGS";
const getClientWidth = () => document.documentElement.clientWidth;
const plugin = ({ commit }) => {
  const onResize = debounce(() => {
    commit(`text/${SET_VIEW_WIDTH}`, getClientWidth());
  }, 100);
  window.addEventListener("resize", onResize);
};
const persistentStorage = getBuilder("text").persist().build();
Vue.use(Vuex);
const textModule = {
  state: {
    showAuthorAnnotations: persistentStorage.getItem("showAuthorAnnotations") === "true",
    currentSession: persistentStorage.getItem("currentSession"),
    viewWidth: getClientWidth(),
    headings: Object.freeze([])
  },
  mutations: {
    [SET_VIEW_WIDTH](state, value) {
      state.viewWidth = value;
    },
    [SET_SHOW_AUTHOR_ANNOTATIONS](state, value) {
      state.showAuthorAnnotations = value;
      persistentStorage.setItem("showAuthorAnnotations", "" + value);
    },
    [SET_CURRENT_SESSION](state, value) {
      state.currentSession = value;
      persistentStorage.setItem("currentSession", value);
    },
    [SET_HEADINGS](state, value) {
      if (state.headings.length !== value.length) {
        state.headings = Object.freeze(value);
        return;
      }
      const old = state.headings;
      const headings = value.map((row, index) => {
        const previous = old[index].level;
        return Object.freeze({
          ...row,
          previous
        });
      });
      state.headings = Object.freeze(headings);
    }
  },
  actions: {
    setShowAuthorAnnotations({ commit }, value) {
      commit(SET_SHOW_AUTHOR_ANNOTATIONS, value);
    },
    setCurrentSession({ commit }, value) {
      commit(SET_CURRENT_SESSION, value);
    },
    setHeadings({ commit }, value) {
      commit(SET_HEADINGS, value);
    }
  }
};
const store$1 = new Store({
  plugins: [plugin],
  modules: {
    text: {
      namespaced: true,
      ...textModule
    }
  }
});
const store = {
  data() {
    return {
      $store: store$1
    };
  },
  beforeMount() {
    if (typeof this.$store === "undefined") {
      this.$store = store$1;
    } else if (!this.$store.hasModule("text")) {
      this.$store.registerModule("text", textModule);
    }
  }
};
const TableOfContents_vue_vue_type_style_index_0_lang = "";
function normalizeComponent(scriptExports, render17, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render17) {
    options.render = render17;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function(context) {
      context = context || this.$vnode && this.$vnode.ssrContext || this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(
        this,
        (options.functional ? this.parent : this).$root.$options.shadowRoot
      );
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}
const _sfc_main$f = {
  name: "TableOfContents",
  mixins: [store, useEditorMixin],
  data: () => ({
    initialRender: true
  }),
  computed: {
    ...mapState({
      headings: (state) => state.text.headings
    })
  },
  mounted() {
    setTimeout(() => {
      this.initialRender = false;
    }, 1e3);
  },
  methods: {
    goto(heading) {
      this.$editor.chain().focus().setTextSelection(heading.position).scrollIntoView().run();
      this.$nextTick(() => {
        window.location.hash = heading.id;
      });
    }
  }
};
var _sfc_render$f = function render() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "editor--toc", class: { "--initial-render": _vm.initialRender }, attrs: { "data-text-el": "editor-table-of-contents" } }, [_c("ul", { staticClass: "editor--toc__list" }, _vm._l(_vm.headings, function(heading) {
    return _c("li", { key: heading.uuid, staticClass: "editor--toc__item", class: {
      [`editor--toc__item--${heading.level}`]: true,
      [`editor--toc__item--previous-${heading.previous}`]: heading.previous > 0
    }, attrs: { "data-toc-level": heading.level } }, [_c("a", { attrs: { "href": `#${heading.id}` }, on: { "click": function($event) {
      $event.preventDefault();
      return _vm.goto(heading);
    } } }, [_vm._v(" " + _vm._s(heading.text) + " ")])]);
  }), 0)]);
};
var _sfc_staticRenderFns$f = [];
var __component__$f = /* @__PURE__ */ normalizeComponent(
  _sfc_main$f,
  _sfc_render$f,
  _sfc_staticRenderFns$f,
  false,
  null,
  null,
  null,
  null
);
const TableOfContents = __component__$f.exports;
const _sfc_main$e = {
  name: "CloseIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$e = function render2() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon close-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$e = [];
var __component__$e = /* @__PURE__ */ normalizeComponent(
  _sfc_main$e,
  _sfc_render$e,
  _sfc_staticRenderFns$e,
  false,
  null,
  null,
  null,
  null
);
const MDI_Close = __component__$e.exports;
const _sfc_main$d = {
  name: "AlertDecagramIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$d = function render3() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon alert-decagram-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M23,12L20.56,9.22L20.9,5.54L17.29,4.72L15.4,1.54L12,3L8.6,1.54L6.71,4.72L3.1,5.53L3.44,9.21L1,12L3.44,14.78L3.1,18.47L6.71,19.29L8.6,22.47L12,21L15.4,22.46L17.29,19.28L20.9,18.46L20.56,14.78L23,12M13,17H11V15H13V17M13,13H11V7H13V13Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$d = [];
var __component__$d = /* @__PURE__ */ normalizeComponent(
  _sfc_main$d,
  _sfc_render$d,
  _sfc_staticRenderFns$d,
  false,
  null,
  null,
  null,
  null
);
const MDI_Danger = __component__$d.exports;
const _sfc_main$c = {
  name: "DeleteIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$c = function render4() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon delete-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M19,4H15.5L14.5,3H9.5L8.5,4H5V6H19M6,19A2,2 0 0,0 8,21H16A2,2 0 0,0 18,19V7H6V19Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$c = [];
var __component__$c = /* @__PURE__ */ normalizeComponent(
  _sfc_main$c,
  _sfc_render$c,
  _sfc_staticRenderFns$c,
  false,
  null,
  null,
  null,
  null
);
const MDI_Delete = __component__$c.exports;
const _sfc_main$b = {
  name: "ImageOutlineIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$b = function render5() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon image-outline-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M19,19H5V5H19M19,3H5A2,2 0 0,0 3,5V19A2,2 0 0,0 5,21H19A2,2 0 0,0 21,19V5A2,2 0 0,0 19,3M13.96,12.29L11.21,15.83L9.25,13.47L6.5,17H17.5L13.96,12.29Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$b = [];
var __component__$b = /* @__PURE__ */ normalizeComponent(
  _sfc_main$b,
  _sfc_render$b,
  _sfc_staticRenderFns$b,
  false,
  null,
  null,
  null,
  null
);
const MDI_Image = __component__$b.exports;
const _sfc_main$a = {
  name: "InformationIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$a = function render6() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon information-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M13,9H11V7H13M13,17H11V11H13M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$a = [];
var __component__$a = /* @__PURE__ */ normalizeComponent(
  _sfc_main$a,
  _sfc_render$a,
  _sfc_staticRenderFns$a,
  false,
  null,
  null,
  null,
  null
);
const MDI_Info = __component__$a.exports;
const _sfc_main$9 = {
  name: "CheckboxMarkedCircleIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$9 = function render7() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon checkbox-marked-circle-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M10,17L5,12L6.41,10.58L10,14.17L17.59,6.58L19,8M12,2A10,10 0 0,0 2,12A10,10 0 0,0 12,22A10,10 0 0,0 22,12A10,10 0 0,0 12,2Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$9 = [];
var __component__$9 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$9,
  _sfc_render$9,
  _sfc_staticRenderFns$9,
  false,
  null,
  null,
  null,
  null
);
const MDI_Positive = __component__$9.exports;
const _sfc_main$8 = {
  name: "AlertIcon",
  emits: ["click"],
  props: {
    title: {
      type: String
    },
    fillColor: {
      type: String,
      default: "currentColor"
    },
    size: {
      type: Number,
      default: 24
    }
  }
};
var _sfc_render$8 = function render8() {
  var _vm = this, _c = _vm._self._c;
  return _c("span", _vm._b({ staticClass: "material-design-icon alert-icon", attrs: { "aria-hidden": !_vm.title, "aria-label": _vm.title, "role": "img" }, on: { "click": function($event) {
    return _vm.$emit("click", $event);
  } } }, "span", _vm.$attrs, false), [_c("svg", { staticClass: "material-design-icon__svg", attrs: { "fill": _vm.fillColor, "width": _vm.size, "height": _vm.size, "viewBox": "0 0 24 24" } }, [_c("path", { attrs: { "d": "M13 14H11V9H13M13 18H11V16H13M1 21H23L12 2L1 21Z" } }, [_vm.title ? _c("title", [_vm._v(_vm._s(_vm.title))]) : _vm._e()])])]);
};
var _sfc_staticRenderFns$8 = [];
var __component__$8 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$8,
  _sfc_render$8,
  _sfc_staticRenderFns$8,
  false,
  null,
  null,
  null,
  null
);
const MDI_Warn = __component__$8.exports;
const DEFAULT_ICON_SIZE = 20;
const makeIcon = (original) => ({
  functional: true,
  render(h, { data, props }) {
    return h(original, {
      data,
      key: data.key,
      staticClass: data.staticClass,
      props: { size: DEFAULT_ICON_SIZE, ...props }
    });
  }
});
const Close = makeIcon(MDI_Close);
const Danger = makeIcon(MDI_Danger);
const Delete = makeIcon(MDI_Delete);
const Image$2 = makeIcon(MDI_Image);
const Info = makeIcon(MDI_Info);
const Positive = makeIcon(MDI_Positive);
const Warn = makeIcon(MDI_Warn);
const EditorOutline_vue_vue_type_style_index_0_scoped_0c9e1c76_lang = "";
const _sfc_main$7 = {
  name: "EditorOutline",
  components: {
    Close,
    NcButton,
    TableOfContents
  },
  mixins: [store, useOutlineStateMixin, useOutlineActions],
  data: () => ({
    mobile: false
  }),
  mounted() {
    this.$onResize = debounce(() => {
      this.mobile = this.$el.parentElement.clientWidth < 320;
    }, 10);
    this.$resizeObserver = new ResizeObserver(this.$onResize);
    this.$resizeObserver.observe(this.$el.parentElement);
    this.$onResize();
  },
  beforeDestroy() {
    this.$resizeObserver.unobserve(this.$el.parentElement);
    this.$resizeObserver = null;
    this.$onResize = null;
  }
};
var _sfc_render$7 = function render9() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "editor--outline", class: { "editor--outline-mobile": _vm.mobile }, attrs: { "data-text-el": "editor-outline" } }, [_c("header", { staticClass: "editor--outline__header" }, [_c("NcButton", { staticClass: "editor--outline__btn-close", attrs: { "type": "tertiary", "aria-label": _vm.t("text", "Close outline view") }, on: { "click": _vm.$outlineActions.toggle }, scopedSlots: _vm._u([{ key: "icon", fn: function() {
    return [_c("Close")];
  }, proxy: true }]) }), _c("h2", [_vm._v(_vm._s(_vm.t("text", "Outline")))])], 1), _c("TableOfContents")], 1);
};
var _sfc_staticRenderFns$7 = [];
var __component__$7 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$7,
  _sfc_render$7,
  _sfc_staticRenderFns$7,
  false,
  null,
  "0c9e1c76",
  null,
  null
);
const EditorOutline = __component__$7.exports;
const BaseReader_vue_vue_type_style_index_0_scoped_20572680_lang = "";
const _sfc_main$6 = {
  name: "BaseReader",
  components: {
    EditorContent,
    EditorOutline
  },
  mixins: [useOutlineStateMixin, useOutlineActions],
  provide() {
    const val = {};
    Object.defineProperties(val, {
      [EDITOR]: {
        get: () => this.$editor
      }
    });
    return val;
  },
  inject: ["renderHtml", "extensions"],
  props: {
    content: {
      type: String,
      required: true
    }
  },
  computed: {
    htmlContent() {
      return this.renderHtml(this.content);
    },
    showOutline() {
      return this.$outlineState.visible;
    }
  },
  watch: {
    content() {
      this.updateContent();
    }
  },
  created() {
    this.$editor = this.createEditor();
    this.$editor.setOptions({ editable: false });
  },
  beforeDestroy() {
    this.$editor.destroy();
  },
  methods: {
    createEditor() {
      return new Editor({
        content: this.htmlContent,
        extensions: this.extensions()
      });
    },
    updateContent() {
      this.$editor.commands.setContent(this.htmlContent, true);
    }
  }
};
var _sfc_render$6 = function render10() {
  var _vm = this, _c = _vm._self._c;
  return _c("div", { staticClass: "content-wrapper text-editor__content-wrapper", class: {
    "--show-outline": _vm.showOutline
  }, attrs: { "data-text-el": "editor-content-wrapper" } }, [_vm.showOutline ? _c("div", { staticClass: "text-editor__content-wrapper__left" }, [_c("EditorOutline")], 1) : _vm._e(), _vm.$editor ? _c("EditorContent", { staticClass: "editor__content text-editor__content", attrs: { "id": "read-only-editor", "editor": _vm.$editor } }) : _vm._e(), _c("div", { staticClass: "text-editor__content-wrapper__right" })], 1);
};
var _sfc_staticRenderFns$6 = [];
var __component__$6 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$6,
  _sfc_render$6,
  _sfc_staticRenderFns$6,
  false,
  null,
  "20572680",
  null,
  null
);
const BaseReader = __component__$6.exports;
function listInputRule(find, type, getAttributes) {
  const handler = ({ state, range: range2, match }) => {
    const wrap = wrappingInputRule({ find, type, getAttributes });
    wrap.handler({ state, range: range2, match });
    if (match.length >= 3) {
      state.tr.insertText(match[2]);
    }
  };
  return new InputRule({ find, handler });
}
const BulletList = TiptapBulletList.extend({
  parseHTML() {
    return this.parent().map((rule) => Object.assign(rule, { preserveWhitespace: true }));
  },
  addAttributes() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      bullet: {
        default: "-",
        rendered: false,
        isRequired: true,
        parseHTML: (el2) => el2.getAttribute("data-bullet")
      }
    };
  },
  addInputRules() {
    return [
      listInputRule(
        /^\s*([-+*])\s([^\s[]+)$/,
        this.type
      )
    ];
  }
});
const typesAvailable = ["info", "warn", "error", "success"];
const buildRender = (type) => (tokens, idx, options, env, slf) => {
  const tag = tokens[idx];
  if (tag.nesting === 1) {
    tag.attrSet("data-callout", type);
    tag.attrJoin("class", `callout callout-${type}`);
  }
  return slf.renderToken(tokens, idx, options, env, slf);
};
const callouts = (md) => {
  typesAvailable.forEach((type) => {
    md.use(container, type, {
      render: buildRender(type)
    });
  });
  return md;
};
const Callout_vue_vue_type_style_index_0_scoped_888f3688_lang = "";
const ICONS_MAP = {
  info: Info,
  success: Positive,
  error: Danger,
  warn: Warn
};
const _sfc_main$5 = {
  name: "Callout",
  components: {
    NodeViewWrapper,
    NodeViewContent
  },
  props: {
    node: {
      type: Object,
      required: true
    }
  },
  computed: {
    icon() {
      return ICONS_MAP[this.type] || Info;
    },
    type() {
      var _a2, _b2;
      return ((_b2 = (_a2 = this.node) == null ? void 0 : _a2.attrs) == null ? void 0 : _b2.type) || "info";
    }
  }
};
var _sfc_render$5 = function render11() {
  var _vm = this, _c = _vm._self._c;
  return _c("NodeViewWrapper", { staticClass: "callout", class: `callout--${_vm.type}`, attrs: { "data-text-el": "callout", "as": "div" } }, [_c(_vm.icon, { tag: "component", staticClass: "callout__icon" }), _c("NodeViewContent", { staticClass: "callout__content" })], 1);
};
var _sfc_staticRenderFns$5 = [];
var __component__$5 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$5,
  _sfc_render$5,
  _sfc_staticRenderFns$5,
  false,
  null,
  "888f3688",
  null,
  null
);
const Callout$1 = __component__$5.exports;
const Callout = Node.create({
  name: "callout",
  content: "paragraph+",
  group: "block",
  defining: true,
  addOptions() {
    return {
      types: typesAvailable,
      HTMLAttributes: {
        class: "callout"
      }
    };
  },
  addAttributes() {
    return {
      type: {
        default: "info",
        rendered: false,
        parseHTML: (element) => {
          return element.getAttribute("data-callout") || typesAvailable.find((type) => element.classList.contains(type)) || element.classList.contains("warning") && "warn";
        },
        renderHTML: (attributes) => {
          return {
            "data-callout": attributes.type,
            class: `callout-${attributes.type}`
          };
        }
      }
    };
  },
  parseHTML() {
    return [
      {
        tag: "div.callout"
      },
      {
        tag: "p.callout",
        priority: 1001
      }
    ];
  },
  renderHTML({ node, HTMLAttributes }) {
    const { class: classy } = this.options.HTMLAttributes;
    const attributes = {
      ...this.options.HTMLAttributes,
      "data-callout": node.attrs.type,
      class: `${classy} ${classy}-${node.attrs.type}`
    };
    return ["div", mergeAttributes(attributes, HTMLAttributes), 0];
  },
  toMarkdown: (state, node) => {
    state.write("::: " + (node.attrs.type || "info") + "\n");
    state.renderContent(node);
    state.ensureNewLine();
    state.write(":::");
    state.closeBlock(node);
  },
  addNodeView() {
    return VueNodeViewRenderer(Callout$1);
  },
  addCommands() {
    return {
      setCallout: (attributes) => ({ commands }) => {
        return commands.wrapIn(this.name, attributes);
      },
      toggleCallout: (attributes) => ({ commands, state }) => {
        if (!isNodeActive(state, this.name)) {
          return commands.setCallout(attributes);
        }
        if (!isNodeActive(state, this.name, attributes)) {
          return commands.updateAttributes(this.name, attributes);
        }
        return commands.unsetCallout();
      },
      unsetCallout: () => ({ commands }) => {
        return commands.lift(this.name);
      }
    };
  }
});
const CodeBlock = TiptapCodeBlock.extend({
  parseHTML() {
    return [
      {
        tag: "pre",
        preserveWhitespace: "full",
        getContent: (node, schema) => {
          return schema.nodes.codeBlock.create(null, [schema.text(node.textContent.replace(/\n$/, ""))]);
        }
      }
    ];
  },
  toMarkdown(state, node, parent, index) {
    node.attrs.params = node.attrs.language;
    return defaultMarkdownSerializer.nodes.code_block(state, node, parent, index);
  }
});
const FrontMatter = TiptapCodeBlock.extend({
  name: "frontMatter",
  draggable: false,
  renderHTML({ node, HTMLAttributes }) {
    return this.parent({
      node,
      HTMLAttributes: mergeAttributes(HTMLAttributes, { "data-title": t("text", "Front matter"), class: "frontmatter" })
    });
  },
  parseHTML() {
    return [{
      tag: "pre#frontmatter",
      preserveWhitespace: "full",
      priority: 9001,
      attrs: {
        language: "yaml"
      }
    }];
  },
  toMarkdown: (state, node) => {
    if (!state.out.match(/^\s*/))
      throw Error("FrontMatter must be the first node of the document!");
    const text = node.textContent;
    const dashes = text.match(/-{3,}/gm);
    const separator = dashes ? dashes.sort().slice(-1)[0] + "-" : "---";
    state.write("");
    state.out = "";
    state.write(`${separator}
`);
    state.text(text, false);
    state.ensureNewLine();
    state.write(separator);
    state.closeBlock(node);
  },
  addInputRules() {
    return [
      {
        find: /^---$/g,
        handler: ({ state, range: range2, chain }) => {
          if (range2.from === 1) {
            if (state.doc.resolve(1).parent.type.name === this.name)
              return false;
            chain().deleteRange(range2).insertContentAt(0, {
              type: this.name
            });
            return true;
          }
          return false;
        }
      }
    ];
  },
  addCommands() {
    return {};
  },
  addPasteRules: () => [],
  addProseMirrorPlugins: () => []
});
const style = "";
const ParagraphView_vue_vue_type_style_index_0_scoped_a5a15327_lang = "";
const _sfc_main$4 = {
  name: "ParagraphView",
  components: {
    NodeViewWrapper,
    NodeViewContent,
    ReferenceList
  },
  props: nodeViewProps,
  data() {
    return {
      text: null
    };
  },
  watch: {
    node: {
      handler(newNode) {
        if (!(newNode == null ? void 0 : newNode.textContent)) {
          this.text = "";
          return;
        }
        this.debouncedUpdateText(newNode);
      }
    }
  },
  beforeCreate() {
    this.debouncedUpdateText = debounce((newNode) => {
      var _a2;
      this.text = this.getTextReference((_a2 = this.node) == null ? void 0 : _a2.textContent);
    }, 500);
  },
  created() {
    var _a2;
    this.text = this.getTextReference((_a2 = this.node) == null ? void 0 : _a2.textContent);
  },
  beforeUnmount() {
    var _a2;
    (_a2 = this.debouncedUpdateText) == null ? void 0 : _a2.cancel();
  },
  methods: {
    getTextReference(text) {
      const PATTERN = /(^)(https?:\/\/)?((?:[-A-Z0-9+_]+\.)+[-A-Z]+(?:\/[-A-Z0-9+&@#%?=~_|!:,.;()]*)*)($)/ig;
      if (new RegExp(PATTERN).test(text)) {
        return text;
      }
      return null;
    }
  }
};
var _sfc_render$4 = function render12() {
  var _vm = this, _c = _vm._self._c;
  return _c("NodeViewWrapper", { staticClass: "vue-component", attrs: { "as": "p" } }, [_c("NodeViewContent", { staticClass: "paragraph-content" }), _vm.text ? _c("ReferenceList", { attrs: { "text": _vm.text, "limit": 1, "contenteditable": "false" } }) : _vm._e()], 1);
};
var _sfc_staticRenderFns$4 = [];
var __component__$4 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$4,
  _sfc_render$4,
  _sfc_staticRenderFns$4,
  false,
  null,
  "a5a15327",
  null,
  null
);
const ParagraphView = __component__$4.exports;
const Paragraph = TiptapParagraph.extend({
  addNodeView() {
    return VueNodeViewRenderer(ParagraphView);
  },
  parseHTML() {
    return this.parent().map((rule) => Object.assign(rule, { preserveWhitespace: "full" }));
  },
  addKeyboardShortcuts() {
    return {
      Backspace: () => {
        const selection = this.editor.state.selection;
        if (selection.$from.parentOffset !== 0)
          return false;
        const node = selection.$from.parent;
        const index = selection.$from.index(selection.$from.depth - 1);
        if (index === 0)
          return false;
        const parent = selection.$from.node(selection.$from.depth - 1);
        const previousNode = parent.child(index - 1);
        if (node.type.name === this.name && previousNode.type.name === this.name) {
          return this.editor.chain().joinBackward().setHardBreak().run();
        }
        return false;
      }
    };
  }
});
const HardBreak = TipTapHardBreak.extend({
  addAttributes() {
    return {
      syntax: {
        default: "  ",
        rendered: false,
        keepOnSplit: true,
        parseHTML: (el2) => el2.getAttribute("data-syntax") || "  "
      }
    };
  },
  addCommands() {
    return {
      ...this == null ? void 0 : this.parent(),
      setHardBreak: () => (ctx) => {
        for (let d = ctx.state.selection.$from.depth; d >= 0; d--) {
          if (ctx.state.selection.$from.node(d).type.name === "heading")
            return false;
        }
        return this.parent().setHardBreak()(ctx);
      }
    };
  },
  toMarkdown(state, node, parent, index) {
    var _a2;
    for (let i = index + 1; i < parent.childCount; i++) {
      if (parent.child(i).type !== node.type) {
        if (node.attrs.syntax !== "html") {
          state.write(node.attrs.syntax);
          if (!((_a2 = parent.child(i).text) == null ? void 0 : _a2.startsWith("\n")))
            state.write("\n");
        } else {
          state.write("<br />");
        }
        return;
      }
    }
  }
});
const setHeadings = (val) => store$1.dispatch("text/setHeadings", val);
const extractHeadings = (editor) => {
  const counter = /* @__PURE__ */ new Map();
  const headings = [];
  const tr = editor.state.tr;
  const getId = (text) => {
    const id = slugify(text);
    if (counter.has(id)) {
      const next = counter.get(id);
      counter.set(id, next + 1);
      return `${id}--${next}`;
    }
    counter.set(id, 1);
    return id;
  };
  editor.state.doc.descendants((node, position) => {
    if (node.type.name === "heading") {
      const text = node.textContent;
      const id = getId(text);
      const uuid = node.attrs.uuid ?? v4();
      if (node.attrs.id !== id || !node.attrs.uuid) {
        const attrs = {
          ...node.attrs,
          uuid,
          id
        };
        tr.setNodeMarkup(position, void 0, attrs);
      }
      headings.push(Object.freeze({
        level: node.attrs.level,
        position,
        text,
        id,
        uuid
      }));
    }
  });
  tr.setMeta("addToHistory", false);
  tr.setMeta("preventUpdate", true);
  editor.view.dispatch(tr);
  setHeadings(headings);
};
const HeadingView_vue_vue_type_style_index_0_lang = "";
const _sfc_main$3 = Vue.extend({
  name: "HeadingView",
  components: {
    NodeViewWrapper,
    NodeViewContent
  },
  mixins: [useEditorMixin],
  props: {
    node: {
      type: Object,
      required: true
    },
    extension: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      content: null
    };
  },
  computed: {
    href() {
      return `#${this.node.attrs.id}`;
    },
    domElement() {
      const hasLevel = this.extension.options.levels.includes(this.node.attrs.level);
      const level = hasLevel ? this.node.attrs.level : this.extension.options.levels[0];
      return `h${level}`;
    },
    linkSymbol() {
      return this.extension.options.linkSymbol;
    },
    t: () => window.t
  },
  methods: {
    click() {
      this.$refs.container.$el.scrollIntoView();
      window.location.hash = this.href;
    }
  }
});
var _sfc_render$3 = function render13() {
  var _vm = this, _c = _vm._self._c;
  _vm._self._setupProxy;
  return _c("NodeViewWrapper", { ref: "container", attrs: { "id": _vm.node.attrs.id, "as": _vm.domElement } }, [_c("a", { staticClass: "heading-anchor", attrs: { "aria-hidden": "true", "href": _vm.href, "title": _vm.t("text", "Link to this section"), "contenteditable": false }, on: { "click": function($event) {
    $event.stopPropagation();
    return _vm.click.apply(null, arguments);
  } } }, [_vm._v(_vm._s(_vm.linkSymbol))]), _c("NodeViewContent", { attrs: { "as": "span" } })], 1);
};
var _sfc_staticRenderFns$3 = [];
var __component__$3 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$3,
  _sfc_render$3,
  _sfc_staticRenderFns$3,
  false,
  null,
  null,
  null,
  null
);
const HeaderViewVue = __component__$3.exports;
const Heading = TipTapHeading.extend({
  addAttributes() {
    return {
      ...this.parent(),
      id: {
        default: void 0,
        rendered: true
      },
      uuid: {
        default: void 0,
        rendered: false
      }
    };
  },
  addOptions() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      linkSymbol: "#"
    };
  },
  addKeyboardShortcuts() {
    return this.options.levels.reduce((items, level) => ({
      ...items,
      [`Mod-Shift-${level}`]: () => this.editor.commands.toggleHeading({ level })
    }), {});
  },
  addNodeView() {
    return VueNodeViewRenderer(HeaderViewVue, {
      update: ({ oldNode, newNode, updateProps }) => {
        if (newNode.type.name !== this.name)
          return false;
        if (newNode.attrs !== oldNode.attrs)
          return false;
        updateProps();
        return true;
      }
    });
  },
  onCreate() {
    extractHeadings(this.editor);
    if (this.parent) {
      this.parent();
    }
  },
  onUpdate: debounce(({ editor }) => {
    if (editor.view && editor.state && !editor.isDestroyed) {
      extractHeadings(editor);
    }
  }, 900)
});
const mimetypesImages = [
  "image/png",
  "image/jpeg",
  "image/jpg",
  "image/gif",
  "image/x-xbitmap",
  "image/x-ms-bmp",
  "image/bmp",
  "image/svg+xml",
  "image/webp"
];
if (!((_a = window.oc_appswebroots) == null ? void 0 : _a.richdocuments) && !((_b = window.oc_appswebroots) == null ? void 0 : _b.onlyoffice))
  ;
const ImageView_vue_vue_type_style_index_0_scoped_9a2764a6_lang = "";
const getQueryVariable$1 = (src, variable) => {
  const query = src.split("?")[1];
  if (typeof query === "undefined") {
    return;
  }
  const vars = query.split(/[&#]/);
  if (typeof vars === "undefined") {
    return;
  }
  for (let i = 0; i < vars.length; i++) {
    const pair = vars[i].split("=");
    if (decodeURIComponent(pair[0]) === variable) {
      return decodeURIComponent(pair[1]);
    }
  }
};
class LoadImageError extends Error {
  constructor(reason, imageUrl) {
    super((reason == null ? void 0 : reason.message) || t("text", "Failed to load"));
    this.reason = reason;
    this.imageUrl = imageUrl;
  }
}
const _sfc_main$2 = {
  name: "ImageView",
  components: {
    ImageIcon: Image$2,
    DeleteIcon: Delete,
    NcButton,
    NodeViewWrapper
  },
  directives: {
    ClickOutside
  },
  mixins: [
    store,
    useAttachmentResolver
  ],
  props: ["editor", "node", "extension", "updateAttributes", "deleteNode"],
  data() {
    return {
      imageLoaded: false,
      loaded: false,
      failed: false,
      showIcons: false,
      imageUrl: null,
      errorMessage: null,
      attachmentType: null,
      attachmentMetadata: {}
    };
  },
  computed: {
    isMediaAttachment() {
      return this.attachmentType === this.$attachmentResolver.ATTACHMENT_TYPE_MEDIA;
    },
    editable() {
      return this.editor.isEditable;
    },
    showDeleteIcon() {
      return this.editable && this.showIcons;
    },
    showImageDeleteIcon() {
      return this.showDeleteIcon && !this.isMediaAttachment;
    },
    canDisplayImage() {
      if (!this.isSupportedImage) {
        return false;
      }
      if (this.failed && this.loaded) {
        return true;
      }
      return this.loaded && this.imageLoaded;
    },
    imageFileId() {
      return getQueryVariable$1(this.src, "fileId");
    },
    isSupportedImage() {
      return typeof this.mime === "undefined" || mimetypesImages.indexOf(this.mime) !== -1;
    },
    internalLinkOrImage() {
      if (this.imageFileId) {
        return generateUrl("/f/" + this.imageFileId);
      }
      return this.src;
    },
    src: {
      get() {
        return this.node.attrs.src || "";
      },
      set(src) {
        this.updateAttributes({
          src
        });
      }
    },
    alt: {
      get() {
        return this.node.attrs.alt ? this.node.attrs.alt : "";
      },
      set(alt) {
        this.updateAttributes({
          alt
        });
      }
    },
    t() {
      return (a, s) => window.t(a, s);
    },
    token() {
      return document.getElementById("sharingToken") && document.getElementById("sharingToken").value;
    }
  },
  beforeMount() {
    if (!this.isSupportedImage) {
      this.failed = true;
      this.imageLoaded = false;
      this.loaded = true;
      this.errorMessage = t("text", "Unsupported image type");
      return;
    }
    this.init().catch(this.onImageLoadFailure);
  },
  methods: {
    async init() {
      const candidates = this.$attachmentResolver.resolve(this.src);
      return this.load(candidates);
    },
    async load(candidates) {
      const [candidate, ...fallbacks] = candidates;
      return this.loadImage(candidate.url, candidate.type, candidate.name).catch((e) => {
        if (fallbacks.length > 0) {
          return this.load(fallbacks);
        }
        return Promise.reject(e);
      });
    },
    async loadImage(imageUrl, attachmentType, name = null) {
      return new Promise((resolve, reject) => {
        const img = new Image();
        img.onload = async () => {
          this.imageUrl = imageUrl;
          this.imageLoaded = true;
          this.loaded = true;
          this.attachmentType = attachmentType;
          if (attachmentType === this.$attachmentResolver.ATTACHMENT_TYPE_MEDIA) {
            await this.loadMediaMetadata(name);
          }
          resolve(imageUrl);
        };
        img.onerror = (e) => {
          reject(new LoadImageError(e, imageUrl));
        };
        img.src = imageUrl;
      });
    },
    loadMediaMetadata(name) {
      const metadataUrl = this.$attachmentResolver.getMediaMetadataUrl(name);
      return axios.get(metadataUrl).then((response) => {
        this.attachmentMetadata = response.data;
      }).catch((error) => {
        logger.error("Failed to load media metadata", { error });
      });
    },
    onImageLoadFailure(err) {
      this.failed = true;
      this.imageLoaded = false;
      this.loaded = true;
      this.errorMessage = err.message;
      if (err instanceof LoadImageError) {
        this.errorMessage = `${this.errorMessage} ${this.src}`;
      }
      this.$emit("error", { error: err, src: this.src });
    },
    updateAlt(event) {
      this.updateAttributes({
        alt: event.target.value
      });
    },
    onLoaded() {
      this.loaded = true;
    }
  }
};
var _sfc_render$2 = function render14() {
  var _vm = this, _c = _vm._self._c;
  return _c("NodeViewWrapper", [_c("figure", { staticClass: "image image-view", class: { "icon-loading": !_vm.loaded, "image-view--failed": _vm.failed }, attrs: { "data-component": "image-view", "data-src": _vm.src } }, [_vm.canDisplayImage ? _c("div", { directives: [{ name: "click-outside", rawName: "v-click-outside", value: () => _vm.showIcons = false, expression: "() => showIcons = false" }], staticClass: "image__view", on: { "click": function($event) {
    _vm.showIcons = true;
  }, "mouseover": function($event) {
    _vm.showIcons = true;
  }, "mouseleave": function($event) {
    _vm.showIcons = false;
  } } }, [_c("transition", { attrs: { "name": "fade" } }, [!_vm.failed ? [_vm.isMediaAttachment ? _c("div", { staticClass: "media" }, [_c("div", { staticClass: "media__wrapper" }, [_c("img", { directives: [{ name: "show", rawName: "v-show", value: _vm.loaded, expression: "loaded" }], staticClass: "image__main", attrs: { "src": _vm.imageUrl }, on: { "load": _vm.onLoaded } }), _c("div", { staticClass: "metadata" }, [_c("span", { staticClass: "name" }, [_vm._v(_vm._s(_vm.alt))]), _c("span", { staticClass: "size" }, [_vm._v(_vm._s(_vm.attachmentMetadata.size))])])]), _vm.showDeleteIcon ? _c("div", { staticClass: "buttons" }, [_c("NcButton", { attrs: { "aria-label": _vm.t("text", "Delete this attachment"), "title": _vm.t("text", "Delete this attachment") }, on: { "click": _vm.deleteNode }, scopedSlots: _vm._u([{ key: "icon", fn: function() {
    return [_c("DeleteIcon")];
  }, proxy: true }], null, false, 3930079857) })], 1) : _vm._e()]) : _c("div", [_c("img", { directives: [{ name: "show", rawName: "v-show", value: _vm.loaded, expression: "loaded" }], staticClass: "image__main", attrs: { "src": _vm.imageUrl }, on: { "load": _vm.onLoaded } })])] : [_c("ImageIcon", { staticClass: "image__main image__main--broken-icon", attrs: { "size": 100 } })]], 2), _c("transition", { attrs: { "name": "fade" } }, [!_vm.isMediaAttachment ? _c("div", { directives: [{ name: "show", rawName: "v-show", value: _vm.loaded, expression: "loaded" }], staticClass: "image__caption" }, [!_vm.editable ? _c("figcaption", [_vm._v(" " + _vm._s(_vm.alt) + " ")]) : _c("div", { staticClass: "image__caption__wrapper" }, [_c("input", { directives: [{ name: "show", rawName: "v-show", value: !_vm.isMediaAttachment, expression: "!isMediaAttachment" }], ref: "altInput", staticClass: "image__caption__input", attrs: { "type": "text" }, domProps: { "value": _vm.alt }, on: { "blur": _vm.updateAlt, "keyup": function($event) {
    if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
      return null;
    return _vm.updateAlt.apply(null, arguments);
  } } }), _vm.showImageDeleteIcon ? _c("div", { staticClass: "image__caption__delete" }, [_c("NcButton", { attrs: { "aria-label": _vm.t("text", "Delete this image"), "title": _vm.t("text", "Delete this image") }, on: { "click": _vm.deleteNode }, scopedSlots: _vm._u([{ key: "icon", fn: function() {
    return [_c("DeleteIcon")];
  }, proxy: true }], null, false, 3930079857) })], 1) : _vm._e()])]) : _vm._e()])], 1) : _c("div", { staticClass: "image-view__cant_display" }, [_c("transition", { attrs: { "name": "fade" } }, [_c("div", { directives: [{ name: "show", rawName: "v-show", value: _vm.loaded, expression: "loaded" }] }, [_c("a", { attrs: { "href": _vm.internalLinkOrImage, "target": "_blank" } }, [!_vm.isSupportedImage ? _c("span", [_vm._v(_vm._s(_vm.alt))]) : _vm._e()])])]), _vm.isSupportedImage ? _c("transition", { attrs: { "name": "fade" } }, [_c("div", { directives: [{ name: "show", rawName: "v-show", value: _vm.loaded, expression: "loaded" }], staticClass: "image__caption" }, [_c("input", { ref: "altInput", attrs: { "type": "text", "disabled": !_vm.editable }, domProps: { "value": _vm.alt }, on: { "blur": _vm.updateAlt, "keyup": function($event) {
    if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter"))
      return null;
    return _vm.updateAlt.apply(null, arguments);
  } } })])]) : _vm._e()], 1), _vm.errorMessage ? _c("small", { staticClass: "image__error-message" }, [_vm._v(" " + _vm._s(_vm.errorMessage) + " ")]) : _vm._e()])]);
};
var _sfc_staticRenderFns$2 = [];
var __component__$2 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$2,
  _sfc_render$2,
  _sfc_staticRenderFns$2,
  false,
  null,
  "9a2764a6",
  null,
  null
);
const ImageView = __component__$2.exports;
const Image$1 = TiptapImage.extend({
  selectable: false,
  parseHTML() {
    return [
      {
        tag: this.options.allowBase64 ? "figure img[src]" : 'figure img[src]:not([src^="data:"])'
      }
    ];
  },
  renderHTML() {
    return ["img"];
  },
  addOptions() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this)
    };
  },
  addNodeView() {
    return VueNodeViewRenderer(ImageView);
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        props: {
          handleDrop: (view, event, slice) => {
            if (event.dataTransfer.files && event.dataTransfer.files.length > 0) {
              const coordinates = view.posAtCoords({ left: event.clientX, top: event.clientY });
              const customEvent = new CustomEvent("file-drop", {
                bubbles: true,
                detail: {
                  files: event.dataTransfer.files,
                  position: coordinates.pos
                }
              });
              event.target.dispatchEvent(customEvent);
              return true;
            }
          },
          handlePaste: (view, event, slice) => {
            if (event.clipboardData.files && event.clipboardData.files.length > 0) {
              const customEvent = new CustomEvent("image-paste", {
                bubbles: true,
                detail: {
                  files: event.clipboardData.files
                }
              });
              event.target.dispatchEvent(customEvent);
              return true;
            }
          }
        }
      })
    ];
  },
  toMarkdown(state, node, parent, index) {
    defaultMarkdownSerializer.nodes.image(state, node, parent, index);
    state.closeBlock(node);
  }
});
const ImageInline = TiptapImage.extend({
  name: "image-inline",
  priority: 99,
  selectable: false,
  parseHTML() {
    return [
      {
        tag: this.options.allowBase64 ? "img[src]" : 'img[src]:not([src^="data:"])'
      }
    ];
  },
  addOptions() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      inline: true
    };
  },
  addCommands() {
    return {};
  },
  addInputRules() {
    return [];
  },
  addNodeView() {
    return VueNodeViewRenderer(ImageView);
  },
  toMarkdown(state, node, parent, index) {
    return defaultMarkdownSerializer.nodes.image(state, node, parent, index);
  }
});
const KeepSyntax = Mark.create({
  name: "keep-syntax",
  parseHTML() {
    return [
      {
        tag: "span.keep-md"
      }
    ];
  },
  renderHTML() {
    return ["span", { class: "keep-md" }, 0];
  },
  toMarkdown: {
    open: "",
    close: "",
    mixable: true,
    escape: false,
    expelEnclosingWhitespace: true
  },
  onUpdate() {
    const tr = this.editor.state.tr;
    this.editor.state.doc.descendants((node, pos, parent, index) => {
      if (node.marks.findIndex((mark) => mark.type.name === this.name) !== -1) {
        if (node.type.name !== "text" || node.text.length !== 1) {
          tr.removeMark(pos, pos + node.nodeSize, this.type);
        }
      }
    });
    if (tr.docChanged) {
      tr.setMeta("addToHistory", false);
      tr.setMeta("preventUpdate", true);
      this.editor.view.dispatch(tr);
    }
  }
});
const Mention_vue_vue_type_style_index_0_scoped_94fe9c88_lang = "";
const _sfc_main$1 = {
  name: "Mention",
  components: {
    NcUserBubble,
    NodeViewWrapper
  },
  props: {
    updateAttributes: {
      type: Function,
      required: true
    },
    node: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      username: this.node.attrs.label
    };
  },
  computed: {
    isCurrentUser() {
      var _a2;
      return this.node.attrs.id === ((_a2 = getCurrentUser()) == null ? void 0 : _a2.uid);
    }
  }
};
var _sfc_render$1 = function render15() {
  var _vm = this, _c = _vm._self._c;
  return _c("NodeViewWrapper", { staticClass: "mention", attrs: { "as": "span", "contenteditable": "false" } }, [_c("NcUserBubble", { staticClass: "mention-user-bubble", attrs: { "user": _vm.node.attrs.id, "display-name": _vm.username, "primary": _vm.isCurrentUser } }, [_vm._v(" @" + _vm._s(_vm.username) + " ")])], 1);
};
var _sfc_staticRenderFns$1 = [];
var __component__$1 = /* @__PURE__ */ normalizeComponent(
  _sfc_main$1,
  _sfc_render$1,
  _sfc_staticRenderFns$1,
  false,
  null,
  "94fe9c88",
  null,
  null
);
const Mention$1 = __component__$1.exports;
const Mention = TipTapMention.extend({
  parseHTML() {
    return [
      {
        tag: 'span[data-type="user"]',
        getAttrs: (element) => {
          return {
            id: element.getAttribute("data-id"),
            label: element.innerText || element.textContent || element.getAttribute("data-label")
          };
        },
        priority: 100
      }
    ];
  },
  renderHTML({ node, HTMLAttributes }) {
    return [
      "span",
      mergeAttributes({ "data-type": "user" }, this.options.HTMLAttributes, HTMLAttributes),
      this.options.renderLabel({
        options: this.options,
        node
      })
    ];
  },
  addNodeView() {
    return VueNodeViewRenderer(Mention$1);
  },
  toMarkdown(state, node) {
    state.write(" ");
    state.write(`@[${node.attrs.label}](mention://user/${node.attrs.id})`);
    state.write(" ");
  }
});
const TableCaption = Node.create({
  name: "tableCaption",
  content: "inline*",
  addAttributes() {
    return {};
  },
  renderHTML() {
    return ["caption"];
  },
  toMarkdown(state, node) {
  },
  parseHTML() {
    return [
      { tag: "table caption", priority: 90 }
    ];
  }
});
const TableCell = TableCell$1.extend({
  content: "inline*",
  toMarkdown(state, node) {
    var _a2;
    state.write(" ");
    const backup = (_a2 = state.options) == null ? void 0 : _a2.escapeExtraCharacters;
    state.options.escapeExtraCharacters = /\|/;
    state.renderInline(node);
    state.options.escapeExtraCharacters = backup;
    state.write(" |");
  },
  parseHTML() {
    return [
      { tag: "td", preserveWhitespace: true },
      { tag: "th", preserveWhitespace: true },
      { tag: "table thead ~ tbody th", priority: 70, preserveWhitespace: true },
      { tag: "table thead ~ tbody td", priority: 70, preserveWhitespace: true }
    ];
  },
  addAttributes() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      textAlign: {
        rendered: false,
        parseHTML: (element) => element.style.textAlign || null
      }
    };
  }
});
const TableHeader = TableHeader$1.extend({
  content: "inline*",
  toMarkdown(state, node) {
    state.write(" ");
    state.renderInline(node);
    state.write(" |");
  },
  parseHTML() {
    return [
      { tag: "table thead:empty ~ tbody :first-child th", priority: 80 },
      { tag: "table thead:empty ~ tbody :first-child td", priority: 80 },
      { tag: "table thead :first-child th", priority: 60 },
      { tag: "table thead :first-child td", priority: 60 },
      { tag: "table tbody :first-child th", priority: 60 },
      { tag: "table tbody :first-child td", priority: 60 },
      { tag: "table > :first-child > th", priority: 60 },
      { tag: "table > :first-child > td", priority: 60 }
    ];
  },
  addAttributes() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      textAlign: {
        rendered: false,
        parseHTML: (element) => element.style.textAlign || null
      }
    };
  }
});
const TableRow = TableRow$1.extend({
  content: "tableCell*",
  toMarkdown(state, node) {
    state.write("|");
    state.renderInline(node);
    state.ensureNewLine();
  },
  parseHTML() {
    return [
      { tag: "tr", priority: 80 }
    ];
  }
});
const TableHeadRow = TableRow.extend({
  name: "tableHeadRow",
  content: "tableHeader*",
  toMarkdown(state, node) {
    state.write("|");
    state.renderInline(node);
    state.ensureNewLine();
    state.write("|");
    node.forEach((cell) => {
      var _a2;
      let row = state.repeat("-", cell.textContent.length + 2);
      const align = (_a2 = cell.attrs) == null ? void 0 : _a2.textAlign;
      if (align === "center" || align === "left")
        row = ":" + row.slice(1);
      if (align === "center" || align === "right")
        row = row.slice(0, -1) + ":";
      state.write(row);
      state.write("|");
    });
    state.ensureNewLine();
  },
  parseHTML() {
    return [
      { tag: "tr", priority: 70 }
    ];
  }
});
function createTable(schema, rowsCount, colsCount, cellContent) {
  const headerCells = [];
  const cells = [];
  for (let index = 0; index < colsCount; index += 1) {
    const cell = schema.nodes.tableCell.createAndFill();
    if (cell) {
      cells.push(cell);
    }
    const headerCell = schema.nodes.tableHeader.createAndFill();
    if (headerCell) {
      headerCells.push(headerCell);
    }
  }
  const headRow = schema.nodes.tableHeadRow.createChecked(null, headerCells);
  const rows = [];
  for (let index = 1; index < rowsCount; index += 1) {
    rows.push(schema.nodes.tableRow.createChecked(null, cells));
  }
  return schema.nodes.table.createChecked(null, [headRow, ...rows]);
}
function findSameCellInNextRow($cell) {
  if ($cell.index(-1) === $cell.node(-1).childCount - 1) {
    return null;
  }
  let cellStart = $cell.after();
  const table = $cell.node(-1);
  for (let row = $cell.indexAfter(-1); row < table.childCount; row++) {
    const rowNode = table.child(row);
    if (rowNode.childCount >= $cell.index()) {
      for (let cell = 0; cell < $cell.index(); cell++) {
        const cellNode = rowNode.child(cell);
        cellStart += cellNode.nodeSize;
      }
      return cellStart + 1;
    }
    cellStart += rowNode.nodeSize;
  }
}
const Table = Table$1.extend({
  content: "tableCaption? tableHeadRow tableRow*",
  addExtensions() {
    return [
      TableCaption,
      TableCell,
      TableHeader,
      TableHeadRow,
      TableRow
    ];
  },
  addCommands() {
    return {
      ...this.parent(),
      addRowAfter: () => ({ chain, dispatch }) => {
        return chain().command(({ state }) => addRowAfter(state, dispatch)).command(({ state, tr }) => {
          const { tableStart, table, bottom: bottom2 } = selectedRect(state);
          if (dispatch) {
            const lastRow = table.child(bottom2 - 1);
            const newRow = table.child(bottom2);
            let pos = tableStart + 1;
            for (let i = 0; i < bottom2; i++) {
              pos += table.child(i).nodeSize;
            }
            for (let i = 0; i < lastRow.childCount; i++) {
              tr.setNodeAttribute(
                pos,
                "textAlign",
                lastRow.child(i).attrs.textAlign
              );
              pos += newRow.child(i).nodeSize;
            }
          }
          return true;
        }).run();
      },
      addRowBefore: () => ({ chain, dispatch }) => chain().command(({ state }) => addRowBefore(state, dispatch)).command(({ state, tr }) => {
        const { tableStart, table, top: top2 } = selectedRect(state);
        if (dispatch) {
          const lastRow = table.child(top2);
          const newRow = table.child(top2 - 1);
          let pos = tableStart + 1;
          for (let i = 0; i < top2 - 1; i++) {
            pos += table.child(i).nodeSize;
          }
          for (let i = 0; i < lastRow.childCount; i++) {
            tr.setNodeAttribute(
              pos,
              "textAlign",
              lastRow.child(i).attrs.textAlign
            );
            pos += newRow.child(i).nodeSize;
          }
        }
        return true;
      }).run(),
      insertTable: () => ({ tr, dispatch, editor }) => {
        if (isInTable(tr))
          return false;
        const node = createTable(editor.schema, 3, 3);
        if (dispatch) {
          const offset = tr.selection.anchor + 1;
          tr.replaceSelectionWith(node).scrollIntoView().setSelection(TextSelection.near(tr.doc.resolve(offset)));
        }
        return true;
      },
      leaveTable: () => ({ tr, dispatch, editor }) => {
        if (!isInTable(tr))
          return false;
        const { $head, empty: empty2 } = tr.selection;
        if (!empty2)
          return false;
        const tableDepth = $head.depth < 3 ? 1 : $head.depth - 2;
        if (dispatch) {
          const $next = tr.doc.resolve($head.after(tableDepth) + 1);
          const selection = TextSelection.near($next);
          dispatch(tr.setSelection(selection).scrollIntoView());
        }
        return true;
      },
      goToNextRow: () => ({ tr, dispatch, editor }) => {
        if (!isInTable(tr))
          return false;
        const cell = findSameCellInNextRow(selectionCell(tr));
        if (cell == null)
          return;
        if (dispatch) {
          const $cell = tr.doc.resolve(cell);
          const selection = TextSelection.between($cell, moveCellForward($cell));
          dispatch(tr.setSelection(selection).scrollIntoView());
        }
        return true;
      }
    };
  },
  renderHTML({ HTMLAttributes }) {
    return ["table", mergeAttributes(this.options.HTMLAttributes, HTMLAttributes), 0];
  },
  toMarkdown(state, node) {
    state.renderContent(node);
    state.closeBlock(node);
  },
  addKeyboardShortcuts() {
    return {
      ...this.parent(),
      Tab: () => this.editor.commands.goToNextCell() || this.editor.commands.leaveTable(),
      Enter: ({ editor }) => {
        var _a2;
        const { selection } = editor.state;
        if (!selection.$from.parent.type.name.startsWith("table"))
          return false;
        if (((_a2 = selection.$from.nodeBefore) == null ? void 0 : _a2.type.name) === "hardBreak") {
          if (editor.can().goToNextRow() || editor.can().addRowAfter()) {
            editor.chain().setTextSelection({ from: selection.from - 1, to: selection.from }).deleteSelection().run();
            if (editor.commands.goToNextRow())
              return true;
            return editor.chain().addRowAfter().goToNextRow().run();
          }
          return false;
        } else {
          return editor.chain().insertContent('<br data-syntax="html" />').focus().run();
        }
      }
    };
  }
});
const TaskItem = TipTapTaskItem.extend({
  addOptions() {
    return {
      nested: true,
      HTMLAttributes: {}
    };
  },
  draggable: false,
  content: "paragraph block*",
  addAttributes() {
    const adjust = { ...this.parent() };
    adjust.checked.parseHTML = (el2) => {
      var _a2;
      return (_a2 = el2.querySelector("input[type=checkbox]")) == null ? void 0 : _a2.checked;
    };
    return adjust;
  },
  parseHTML: [
    {
      priority: 101,
      tag: "li",
      getAttrs: (el2) => {
        const checkbox = el2.querySelector("input[type=checkbox]");
        return checkbox;
      },
      context: "taskList/"
    }
  ],
  renderHTML({ node, HTMLAttributes }) {
    const listAttributes = { class: "checkbox-item" };
    const checkboxAttributes = { type: "checkbox", class: "", contenteditable: false };
    if (node.attrs.checked) {
      checkboxAttributes.checked = true;
      listAttributes.class += " checked";
    }
    return [
      "li",
      mergeAttributes(HTMLAttributes, listAttributes),
      [
        "input",
        checkboxAttributes
      ],
      [
        "label",
        0
      ]
    ];
  },
  addNodeView: false,
  toMarkdown: (state, node) => {
    state.write(`[${node.attrs.checked ? "x" : " "}] `);
    state.renderContent(node);
  },
  addInputRules() {
    return [
      ...this.parent(),
      wrappingInputRule({
        find: /^\s*([-+*])\s(\[(x|X|\s)?\])\s$/,
        type: this.type,
        getAttributes: (match) => ({
          checked: "xX".includes(match[match.length - 1])
        })
      })
    ];
  },
  addProseMirrorPlugins() {
    return [
      new Plugin({
        props: {
          handleClick: (view, pos, event) => {
            const state = view.state;
            const schema = state.schema;
            const coordinates = view.posAtCoords({ left: event.clientX, top: event.clientY });
            const position = state.doc.resolve(coordinates.pos);
            const parentList = findParentNodeClosestToPos(position, function(node) {
              return node.type === schema.nodes.taskItem || node.type === schema.nodes.listItem;
            });
            const isListClicked = event.target.tagName.toLowerCase() === "li";
            if (!isListClicked || !parentList || parentList.node.type !== schema.nodes.taskItem || !view.editable) {
              return;
            }
            const tr = state.tr;
            tr.setNodeMarkup(parentList.pos, schema.nodes.taskItem, { checked: !parentList.node.attrs.checked });
            view.dispatch(tr);
          }
        }
      })
    ];
  }
});
const TaskList = TiptapTaskList.extend({
  parseHTML: [
    {
      priority: 100,
      tag: "ul.contains-task-list"
    }
  ],
  addAttributes() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      bullet: {
        default: "-",
        rendered: false,
        isRequired: true,
        parseHTML: (el2) => el2.getAttribute("data-bullet")
      }
    };
  },
  toMarkdown: (state, node) => {
    state.renderList(node, "  ", () => `${node.attrs.bullet} `);
  }
});
function markdownUnderlines(md) {
  md.inline.ruler2.after("emphasis", "underline", (state) => {
    const tokens = state.tokens;
    for (let i = tokens.length - 1; i > 0; i--) {
      const token = tokens[i];
      if (token.markup === "__") {
        if (token.type === "strong_open") {
          tokens[i].tag = "u";
          tokens[i].type = "u_open";
        }
        if (token.type === "strong_close") {
          tokens[i].tag = "u";
          tokens[i].type = "u_close";
        }
      }
    }
    return false;
  });
}
function splitMixedLists(md) {
  md.core.ruler.after("task-lists", "split-mixed-task-lists", (state) => {
    const tokens = state.tokens;
    for (let i = 0; i < tokens.length; i++) {
      const token = tokens[i];
      if (!includesClass(token, "contains-task-list")) {
        continue;
      }
      const firstChild = tokens[i + 1];
      const startsWithTask = includesClass(firstChild, "task-list-item");
      if (!startsWithTask) {
        token.attrs.splice(token.attrIndex("class"));
        if (token.attrs.length === 0) {
          token.attrs = null;
        }
      }
      const splitBefore = findChildOf(tokens, i, (child) => {
        return child.nesting === 1 && includesClass(child, "task-list-item") !== startsWithTask;
      });
      if (splitBefore > i) {
        splitListAt(tokens, splitBefore, state.Token);
      }
    }
    return false;
  });
}
function includesClass(token, cls) {
  var _a2;
  return ((_a2 = token.attrGet("class")) == null ? void 0 : _a2.split(" ").includes(cls)) || false;
}
function splitListAt(tokens, index, TokenConstructor) {
  const closeList = new TokenConstructor("bullet_list_close", "ul", -1);
  closeList.block = true;
  const openList = new TokenConstructor("bullet_list_open", "ul", 1);
  openList.attrSet("class", "contains-task-list");
  openList.block = true;
  openList.markup = tokens[index].markup;
  tokens.splice(index, 0, closeList, openList);
}
function findChildOf(tokens, parentIndex, predicate) {
  const searchLevel = tokens[parentIndex].level + 1;
  for (let i = parentIndex + 1; i < tokens.length; i++) {
    const token = tokens[i];
    if (token.level < searchLevel) {
      return -1;
    }
    if (token.level === searchLevel && predicate(tokens[i])) {
      return i;
    }
  }
  return -1;
}
var utils = {};
var entitiesExports = {};
var entities = {
  get exports() {
    return entitiesExports;
  },
  set exports(v) {
    entitiesExports = v;
  }
};
const Aacute = "Á";
const aacute = "á";
const Abreve = "Ă";
const abreve = "ă";
const ac = "∾";
const acd = "∿";
const acE = "∾̳";
const Acirc = "Â";
const acirc = "â";
const acute = "´";
const Acy = "А";
const acy = "а";
const AElig = "Æ";
const aelig = "æ";
const af = "⁡";
const Afr = "𝔄";
const afr = "𝔞";
const Agrave = "À";
const agrave = "à";
const alefsym = "ℵ";
const aleph = "ℵ";
const Alpha = "Α";
const alpha = "α";
const Amacr = "Ā";
const amacr = "ā";
const amalg = "⨿";
const amp = "&";
const AMP = "&";
const andand = "⩕";
const And = "⩓";
const and = "∧";
const andd = "⩜";
const andslope = "⩘";
const andv = "⩚";
const ang = "∠";
const ange = "⦤";
const angle = "∠";
const angmsdaa = "⦨";
const angmsdab = "⦩";
const angmsdac = "⦪";
const angmsdad = "⦫";
const angmsdae = "⦬";
const angmsdaf = "⦭";
const angmsdag = "⦮";
const angmsdah = "⦯";
const angmsd = "∡";
const angrt = "∟";
const angrtvb = "⊾";
const angrtvbd = "⦝";
const angsph = "∢";
const angst = "Å";
const angzarr = "⍼";
const Aogon = "Ą";
const aogon = "ą";
const Aopf = "𝔸";
const aopf = "𝕒";
const apacir = "⩯";
const ap = "≈";
const apE = "⩰";
const ape = "≊";
const apid = "≋";
const apos = "'";
const ApplyFunction = "⁡";
const approx = "≈";
const approxeq = "≊";
const Aring = "Å";
const aring = "å";
const Ascr = "𝒜";
const ascr = "𝒶";
const Assign = "≔";
const ast = "*";
const asymp = "≈";
const asympeq = "≍";
const Atilde = "Ã";
const atilde = "ã";
const Auml = "Ä";
const auml = "ä";
const awconint = "∳";
const awint = "⨑";
const backcong = "≌";
const backepsilon = "϶";
const backprime = "‵";
const backsim = "∽";
const backsimeq = "⋍";
const Backslash = "∖";
const Barv = "⫧";
const barvee = "⊽";
const barwed = "⌅";
const Barwed = "⌆";
const barwedge = "⌅";
const bbrk = "⎵";
const bbrktbrk = "⎶";
const bcong = "≌";
const Bcy = "Б";
const bcy = "б";
const bdquo = "„";
const becaus = "∵";
const because = "∵";
const Because = "∵";
const bemptyv = "⦰";
const bepsi = "϶";
const bernou = "ℬ";
const Bernoullis = "ℬ";
const Beta = "Β";
const beta = "β";
const beth = "ℶ";
const between = "≬";
const Bfr = "𝔅";
const bfr = "𝔟";
const bigcap = "⋂";
const bigcirc = "◯";
const bigcup = "⋃";
const bigodot = "⨀";
const bigoplus = "⨁";
const bigotimes = "⨂";
const bigsqcup = "⨆";
const bigstar = "★";
const bigtriangledown = "▽";
const bigtriangleup = "△";
const biguplus = "⨄";
const bigvee = "⋁";
const bigwedge = "⋀";
const bkarow = "⤍";
const blacklozenge = "⧫";
const blacksquare = "▪";
const blacktriangle = "▴";
const blacktriangledown = "▾";
const blacktriangleleft = "◂";
const blacktriangleright = "▸";
const blank = "␣";
const blk12 = "▒";
const blk14 = "░";
const blk34 = "▓";
const block = "█";
const bne = "=⃥";
const bnequiv = "≡⃥";
const bNot = "⫭";
const bnot = "⌐";
const Bopf = "𝔹";
const bopf = "𝕓";
const bot = "⊥";
const bottom = "⊥";
const bowtie = "⋈";
const boxbox = "⧉";
const boxdl = "┐";
const boxdL = "╕";
const boxDl = "╖";
const boxDL = "╗";
const boxdr = "┌";
const boxdR = "╒";
const boxDr = "╓";
const boxDR = "╔";
const boxh = "─";
const boxH = "═";
const boxhd = "┬";
const boxHd = "╤";
const boxhD = "╥";
const boxHD = "╦";
const boxhu = "┴";
const boxHu = "╧";
const boxhU = "╨";
const boxHU = "╩";
const boxminus = "⊟";
const boxplus = "⊞";
const boxtimes = "⊠";
const boxul = "┘";
const boxuL = "╛";
const boxUl = "╜";
const boxUL = "╝";
const boxur = "└";
const boxuR = "╘";
const boxUr = "╙";
const boxUR = "╚";
const boxv = "│";
const boxV = "║";
const boxvh = "┼";
const boxvH = "╪";
const boxVh = "╫";
const boxVH = "╬";
const boxvl = "┤";
const boxvL = "╡";
const boxVl = "╢";
const boxVL = "╣";
const boxvr = "├";
const boxvR = "╞";
const boxVr = "╟";
const boxVR = "╠";
const bprime = "‵";
const breve = "˘";
const Breve = "˘";
const brvbar = "¦";
const bscr = "𝒷";
const Bscr = "ℬ";
const bsemi = "⁏";
const bsim = "∽";
const bsime = "⋍";
const bsolb = "⧅";
const bsol = "\\";
const bsolhsub = "⟈";
const bull = "•";
const bullet = "•";
const bump = "≎";
const bumpE = "⪮";
const bumpe = "≏";
const Bumpeq = "≎";
const bumpeq = "≏";
const Cacute = "Ć";
const cacute = "ć";
const capand = "⩄";
const capbrcup = "⩉";
const capcap = "⩋";
const cap = "∩";
const Cap = "⋒";
const capcup = "⩇";
const capdot = "⩀";
const CapitalDifferentialD = "ⅅ";
const caps = "∩︀";
const caret = "⁁";
const caron = "ˇ";
const Cayleys = "ℭ";
const ccaps = "⩍";
const Ccaron = "Č";
const ccaron = "č";
const Ccedil = "Ç";
const ccedil = "ç";
const Ccirc = "Ĉ";
const ccirc = "ĉ";
const Cconint = "∰";
const ccups = "⩌";
const ccupssm = "⩐";
const Cdot = "Ċ";
const cdot = "ċ";
const cedil = "¸";
const Cedilla = "¸";
const cemptyv = "⦲";
const cent = "¢";
const centerdot = "·";
const CenterDot = "·";
const cfr = "𝔠";
const Cfr = "ℭ";
const CHcy = "Ч";
const chcy = "ч";
const check = "✓";
const checkmark = "✓";
const Chi = "Χ";
const chi = "χ";
const circ = "ˆ";
const circeq = "≗";
const circlearrowleft = "↺";
const circlearrowright = "↻";
const circledast = "⊛";
const circledcirc = "⊚";
const circleddash = "⊝";
const CircleDot = "⊙";
const circledR = "®";
const circledS = "Ⓢ";
const CircleMinus = "⊖";
const CirclePlus = "⊕";
const CircleTimes = "⊗";
const cir = "○";
const cirE = "⧃";
const cire = "≗";
const cirfnint = "⨐";
const cirmid = "⫯";
const cirscir = "⧂";
const ClockwiseContourIntegral = "∲";
const CloseCurlyDoubleQuote = "”";
const CloseCurlyQuote = "’";
const clubs = "♣";
const clubsuit = "♣";
const colon = ":";
const Colon = "∷";
const Colone = "⩴";
const colone = "≔";
const coloneq = "≔";
const comma = ",";
const commat = "@";
const comp = "∁";
const compfn = "∘";
const complement = "∁";
const complexes = "ℂ";
const cong = "≅";
const congdot = "⩭";
const Congruent = "≡";
const conint = "∮";
const Conint = "∯";
const ContourIntegral = "∮";
const copf = "𝕔";
const Copf = "ℂ";
const coprod = "∐";
const Coproduct = "∐";
const copy = "©";
const COPY = "©";
const copysr = "℗";
const CounterClockwiseContourIntegral = "∳";
const crarr = "↵";
const cross = "✗";
const Cross = "⨯";
const Cscr = "𝒞";
const cscr = "𝒸";
const csub = "⫏";
const csube = "⫑";
const csup = "⫐";
const csupe = "⫒";
const ctdot = "⋯";
const cudarrl = "⤸";
const cudarrr = "⤵";
const cuepr = "⋞";
const cuesc = "⋟";
const cularr = "↶";
const cularrp = "⤽";
const cupbrcap = "⩈";
const cupcap = "⩆";
const CupCap = "≍";
const cup = "∪";
const Cup = "⋓";
const cupcup = "⩊";
const cupdot = "⊍";
const cupor = "⩅";
const cups = "∪︀";
const curarr = "↷";
const curarrm = "⤼";
const curlyeqprec = "⋞";
const curlyeqsucc = "⋟";
const curlyvee = "⋎";
const curlywedge = "⋏";
const curren = "¤";
const curvearrowleft = "↶";
const curvearrowright = "↷";
const cuvee = "⋎";
const cuwed = "⋏";
const cwconint = "∲";
const cwint = "∱";
const cylcty = "⌭";
const dagger = "†";
const Dagger = "‡";
const daleth = "ℸ";
const darr = "↓";
const Darr = "↡";
const dArr = "⇓";
const dash = "‐";
const Dashv = "⫤";
const dashv = "⊣";
const dbkarow = "⤏";
const dblac = "˝";
const Dcaron = "Ď";
const dcaron = "ď";
const Dcy = "Д";
const dcy = "д";
const ddagger = "‡";
const ddarr = "⇊";
const DD = "ⅅ";
const dd = "ⅆ";
const DDotrahd = "⤑";
const ddotseq = "⩷";
const deg = "°";
const Del = "∇";
const Delta = "Δ";
const delta = "δ";
const demptyv = "⦱";
const dfisht = "⥿";
const Dfr = "𝔇";
const dfr = "𝔡";
const dHar = "⥥";
const dharl = "⇃";
const dharr = "⇂";
const DiacriticalAcute = "´";
const DiacriticalDot = "˙";
const DiacriticalDoubleAcute = "˝";
const DiacriticalGrave = "`";
const DiacriticalTilde = "˜";
const diam = "⋄";
const diamond = "⋄";
const Diamond = "⋄";
const diamondsuit = "♦";
const diams = "♦";
const die = "¨";
const DifferentialD = "ⅆ";
const digamma = "ϝ";
const disin = "⋲";
const div = "÷";
const divide = "÷";
const divideontimes = "⋇";
const divonx = "⋇";
const DJcy = "Ђ";
const djcy = "ђ";
const dlcorn = "⌞";
const dlcrop = "⌍";
const dollar = "$";
const Dopf = "𝔻";
const dopf = "𝕕";
const Dot = "¨";
const dot = "˙";
const DotDot = "⃜";
const doteq = "≐";
const doteqdot = "≑";
const DotEqual = "≐";
const dotminus = "∸";
const dotplus = "∔";
const dotsquare = "⊡";
const doublebarwedge = "⌆";
const DoubleContourIntegral = "∯";
const DoubleDot = "¨";
const DoubleDownArrow = "⇓";
const DoubleLeftArrow = "⇐";
const DoubleLeftRightArrow = "⇔";
const DoubleLeftTee = "⫤";
const DoubleLongLeftArrow = "⟸";
const DoubleLongLeftRightArrow = "⟺";
const DoubleLongRightArrow = "⟹";
const DoubleRightArrow = "⇒";
const DoubleRightTee = "⊨";
const DoubleUpArrow = "⇑";
const DoubleUpDownArrow = "⇕";
const DoubleVerticalBar = "∥";
const DownArrowBar = "⤓";
const downarrow = "↓";
const DownArrow = "↓";
const Downarrow = "⇓";
const DownArrowUpArrow = "⇵";
const DownBreve = "̑";
const downdownarrows = "⇊";
const downharpoonleft = "⇃";
const downharpoonright = "⇂";
const DownLeftRightVector = "⥐";
const DownLeftTeeVector = "⥞";
const DownLeftVectorBar = "⥖";
const DownLeftVector = "↽";
const DownRightTeeVector = "⥟";
const DownRightVectorBar = "⥗";
const DownRightVector = "⇁";
const DownTeeArrow = "↧";
const DownTee = "⊤";
const drbkarow = "⤐";
const drcorn = "⌟";
const drcrop = "⌌";
const Dscr = "𝒟";
const dscr = "𝒹";
const DScy = "Ѕ";
const dscy = "ѕ";
const dsol = "⧶";
const Dstrok = "Đ";
const dstrok = "đ";
const dtdot = "⋱";
const dtri = "▿";
const dtrif = "▾";
const duarr = "⇵";
const duhar = "⥯";
const dwangle = "⦦";
const DZcy = "Џ";
const dzcy = "џ";
const dzigrarr = "⟿";
const Eacute = "É";
const eacute = "é";
const easter = "⩮";
const Ecaron = "Ě";
const ecaron = "ě";
const Ecirc = "Ê";
const ecirc = "ê";
const ecir = "≖";
const ecolon = "≕";
const Ecy = "Э";
const ecy = "э";
const eDDot = "⩷";
const Edot = "Ė";
const edot = "ė";
const eDot = "≑";
const ee = "ⅇ";
const efDot = "≒";
const Efr = "𝔈";
const efr = "𝔢";
const eg = "⪚";
const Egrave = "È";
const egrave = "è";
const egs = "⪖";
const egsdot = "⪘";
const el = "⪙";
const Element = "∈";
const elinters = "⏧";
const ell = "ℓ";
const els = "⪕";
const elsdot = "⪗";
const Emacr = "Ē";
const emacr = "ē";
const empty = "∅";
const emptyset = "∅";
const EmptySmallSquare = "◻";
const emptyv = "∅";
const EmptyVerySmallSquare = "▫";
const emsp13 = " ";
const emsp14 = " ";
const emsp = " ";
const ENG = "Ŋ";
const eng = "ŋ";
const ensp = " ";
const Eogon = "Ę";
const eogon = "ę";
const Eopf = "𝔼";
const eopf = "𝕖";
const epar = "⋕";
const eparsl = "⧣";
const eplus = "⩱";
const epsi = "ε";
const Epsilon = "Ε";
const epsilon = "ε";
const epsiv = "ϵ";
const eqcirc = "≖";
const eqcolon = "≕";
const eqsim = "≂";
const eqslantgtr = "⪖";
const eqslantless = "⪕";
const Equal = "⩵";
const equals = "=";
const EqualTilde = "≂";
const equest = "≟";
const Equilibrium = "⇌";
const equiv = "≡";
const equivDD = "⩸";
const eqvparsl = "⧥";
const erarr = "⥱";
const erDot = "≓";
const escr = "ℯ";
const Escr = "ℰ";
const esdot = "≐";
const Esim = "⩳";
const esim = "≂";
const Eta = "Η";
const eta = "η";
const ETH = "Ð";
const eth = "ð";
const Euml = "Ë";
const euml = "ë";
const euro = "€";
const excl = "!";
const exist = "∃";
const Exists = "∃";
const expectation = "ℰ";
const exponentiale = "ⅇ";
const ExponentialE = "ⅇ";
const fallingdotseq = "≒";
const Fcy = "Ф";
const fcy = "ф";
const female = "♀";
const ffilig = "ﬃ";
const fflig = "ﬀ";
const ffllig = "ﬄ";
const Ffr = "𝔉";
const ffr = "𝔣";
const filig = "ﬁ";
const FilledSmallSquare = "◼";
const FilledVerySmallSquare = "▪";
const fjlig = "fj";
const flat = "♭";
const fllig = "ﬂ";
const fltns = "▱";
const fnof = "ƒ";
const Fopf = "𝔽";
const fopf = "𝕗";
const forall = "∀";
const ForAll = "∀";
const fork = "⋔";
const forkv = "⫙";
const Fouriertrf = "ℱ";
const fpartint = "⨍";
const frac12 = "½";
const frac13 = "⅓";
const frac14 = "¼";
const frac15 = "⅕";
const frac16 = "⅙";
const frac18 = "⅛";
const frac23 = "⅔";
const frac25 = "⅖";
const frac34 = "¾";
const frac35 = "⅗";
const frac38 = "⅜";
const frac45 = "⅘";
const frac56 = "⅚";
const frac58 = "⅝";
const frac78 = "⅞";
const frasl = "⁄";
const frown = "⌢";
const fscr = "𝒻";
const Fscr = "ℱ";
const gacute = "ǵ";
const Gamma = "Γ";
const gamma = "γ";
const Gammad = "Ϝ";
const gammad = "ϝ";
const gap = "⪆";
const Gbreve = "Ğ";
const gbreve = "ğ";
const Gcedil = "Ģ";
const Gcirc = "Ĝ";
const gcirc = "ĝ";
const Gcy = "Г";
const gcy = "г";
const Gdot = "Ġ";
const gdot = "ġ";
const ge = "≥";
const gE = "≧";
const gEl = "⪌";
const gel = "⋛";
const geq = "≥";
const geqq = "≧";
const geqslant = "⩾";
const gescc = "⪩";
const ges = "⩾";
const gesdot = "⪀";
const gesdoto = "⪂";
const gesdotol = "⪄";
const gesl = "⋛︀";
const gesles = "⪔";
const Gfr = "𝔊";
const gfr = "𝔤";
const gg = "≫";
const Gg = "⋙";
const ggg = "⋙";
const gimel = "ℷ";
const GJcy = "Ѓ";
const gjcy = "ѓ";
const gla = "⪥";
const gl = "≷";
const glE = "⪒";
const glj = "⪤";
const gnap = "⪊";
const gnapprox = "⪊";
const gne = "⪈";
const gnE = "≩";
const gneq = "⪈";
const gneqq = "≩";
const gnsim = "⋧";
const Gopf = "𝔾";
const gopf = "𝕘";
const grave = "`";
const GreaterEqual = "≥";
const GreaterEqualLess = "⋛";
const GreaterFullEqual = "≧";
const GreaterGreater = "⪢";
const GreaterLess = "≷";
const GreaterSlantEqual = "⩾";
const GreaterTilde = "≳";
const Gscr = "𝒢";
const gscr = "ℊ";
const gsim = "≳";
const gsime = "⪎";
const gsiml = "⪐";
const gtcc = "⪧";
const gtcir = "⩺";
const gt = ">";
const GT = ">";
const Gt = "≫";
const gtdot = "⋗";
const gtlPar = "⦕";
const gtquest = "⩼";
const gtrapprox = "⪆";
const gtrarr = "⥸";
const gtrdot = "⋗";
const gtreqless = "⋛";
const gtreqqless = "⪌";
const gtrless = "≷";
const gtrsim = "≳";
const gvertneqq = "≩︀";
const gvnE = "≩︀";
const Hacek = "ˇ";
const hairsp = " ";
const half = "½";
const hamilt = "ℋ";
const HARDcy = "Ъ";
const hardcy = "ъ";
const harrcir = "⥈";
const harr = "↔";
const hArr = "⇔";
const harrw = "↭";
const Hat = "^";
const hbar = "ℏ";
const Hcirc = "Ĥ";
const hcirc = "ĥ";
const hearts = "♥";
const heartsuit = "♥";
const hellip = "…";
const hercon = "⊹";
const hfr = "𝔥";
const Hfr = "ℌ";
const HilbertSpace = "ℋ";
const hksearow = "⤥";
const hkswarow = "⤦";
const hoarr = "⇿";
const homtht = "∻";
const hookleftarrow = "↩";
const hookrightarrow = "↪";
const hopf = "𝕙";
const Hopf = "ℍ";
const horbar = "―";
const HorizontalLine = "─";
const hscr = "𝒽";
const Hscr = "ℋ";
const hslash = "ℏ";
const Hstrok = "Ħ";
const hstrok = "ħ";
const HumpDownHump = "≎";
const HumpEqual = "≏";
const hybull = "⁃";
const hyphen = "‐";
const Iacute = "Í";
const iacute = "í";
const ic = "⁣";
const Icirc = "Î";
const icirc = "î";
const Icy = "И";
const icy = "и";
const Idot = "İ";
const IEcy = "Е";
const iecy = "е";
const iexcl = "¡";
const iff = "⇔";
const ifr = "𝔦";
const Ifr = "ℑ";
const Igrave = "Ì";
const igrave = "ì";
const ii = "ⅈ";
const iiiint = "⨌";
const iiint = "∭";
const iinfin = "⧜";
const iiota = "℩";
const IJlig = "Ĳ";
const ijlig = "ĳ";
const Imacr = "Ī";
const imacr = "ī";
const image = "ℑ";
const ImaginaryI = "ⅈ";
const imagline = "ℐ";
const imagpart = "ℑ";
const imath = "ı";
const Im = "ℑ";
const imof = "⊷";
const imped = "Ƶ";
const Implies = "⇒";
const incare = "℅";
const infin = "∞";
const infintie = "⧝";
const inodot = "ı";
const intcal = "⊺";
const int = "∫";
const Int = "∬";
const integers = "ℤ";
const Integral = "∫";
const intercal = "⊺";
const Intersection = "⋂";
const intlarhk = "⨗";
const intprod = "⨼";
const InvisibleComma = "⁣";
const InvisibleTimes = "⁢";
const IOcy = "Ё";
const iocy = "ё";
const Iogon = "Į";
const iogon = "į";
const Iopf = "𝕀";
const iopf = "𝕚";
const Iota = "Ι";
const iota = "ι";
const iprod = "⨼";
const iquest = "¿";
const iscr = "𝒾";
const Iscr = "ℐ";
const isin = "∈";
const isindot = "⋵";
const isinE = "⋹";
const isins = "⋴";
const isinsv = "⋳";
const isinv = "∈";
const it = "⁢";
const Itilde = "Ĩ";
const itilde = "ĩ";
const Iukcy = "І";
const iukcy = "і";
const Iuml = "Ï";
const iuml = "ï";
const Jcirc = "Ĵ";
const jcirc = "ĵ";
const Jcy = "Й";
const jcy = "й";
const Jfr = "𝔍";
const jfr = "𝔧";
const jmath = "ȷ";
const Jopf = "𝕁";
const jopf = "𝕛";
const Jscr = "𝒥";
const jscr = "𝒿";
const Jsercy = "Ј";
const jsercy = "ј";
const Jukcy = "Є";
const jukcy = "є";
const Kappa = "Κ";
const kappa = "κ";
const kappav = "ϰ";
const Kcedil = "Ķ";
const kcedil = "ķ";
const Kcy = "К";
const kcy = "к";
const Kfr = "𝔎";
const kfr = "𝔨";
const kgreen = "ĸ";
const KHcy = "Х";
const khcy = "х";
const KJcy = "Ќ";
const kjcy = "ќ";
const Kopf = "𝕂";
const kopf = "𝕜";
const Kscr = "𝒦";
const kscr = "𝓀";
const lAarr = "⇚";
const Lacute = "Ĺ";
const lacute = "ĺ";
const laemptyv = "⦴";
const lagran = "ℒ";
const Lambda = "Λ";
const lambda = "λ";
const lang = "⟨";
const Lang = "⟪";
const langd = "⦑";
const langle = "⟨";
const lap = "⪅";
const Laplacetrf = "ℒ";
const laquo = "«";
const larrb = "⇤";
const larrbfs = "⤟";
const larr = "←";
const Larr = "↞";
const lArr = "⇐";
const larrfs = "⤝";
const larrhk = "↩";
const larrlp = "↫";
const larrpl = "⤹";
const larrsim = "⥳";
const larrtl = "↢";
const latail = "⤙";
const lAtail = "⤛";
const lat = "⪫";
const late = "⪭";
const lates = "⪭︀";
const lbarr = "⤌";
const lBarr = "⤎";
const lbbrk = "❲";
const lbrace = "{";
const lbrack = "[";
const lbrke = "⦋";
const lbrksld = "⦏";
const lbrkslu = "⦍";
const Lcaron = "Ľ";
const lcaron = "ľ";
const Lcedil = "Ļ";
const lcedil = "ļ";
const lceil = "⌈";
const lcub = "{";
const Lcy = "Л";
const lcy = "л";
const ldca = "⤶";
const ldquo = "“";
const ldquor = "„";
const ldrdhar = "⥧";
const ldrushar = "⥋";
const ldsh = "↲";
const le = "≤";
const lE = "≦";
const LeftAngleBracket = "⟨";
const LeftArrowBar = "⇤";
const leftarrow = "←";
const LeftArrow = "←";
const Leftarrow = "⇐";
const LeftArrowRightArrow = "⇆";
const leftarrowtail = "↢";
const LeftCeiling = "⌈";
const LeftDoubleBracket = "⟦";
const LeftDownTeeVector = "⥡";
const LeftDownVectorBar = "⥙";
const LeftDownVector = "⇃";
const LeftFloor = "⌊";
const leftharpoondown = "↽";
const leftharpoonup = "↼";
const leftleftarrows = "⇇";
const leftrightarrow = "↔";
const LeftRightArrow = "↔";
const Leftrightarrow = "⇔";
const leftrightarrows = "⇆";
const leftrightharpoons = "⇋";
const leftrightsquigarrow = "↭";
const LeftRightVector = "⥎";
const LeftTeeArrow = "↤";
const LeftTee = "⊣";
const LeftTeeVector = "⥚";
const leftthreetimes = "⋋";
const LeftTriangleBar = "⧏";
const LeftTriangle = "⊲";
const LeftTriangleEqual = "⊴";
const LeftUpDownVector = "⥑";
const LeftUpTeeVector = "⥠";
const LeftUpVectorBar = "⥘";
const LeftUpVector = "↿";
const LeftVectorBar = "⥒";
const LeftVector = "↼";
const lEg = "⪋";
const leg = "⋚";
const leq = "≤";
const leqq = "≦";
const leqslant = "⩽";
const lescc = "⪨";
const les = "⩽";
const lesdot = "⩿";
const lesdoto = "⪁";
const lesdotor = "⪃";
const lesg = "⋚︀";
const lesges = "⪓";
const lessapprox = "⪅";
const lessdot = "⋖";
const lesseqgtr = "⋚";
const lesseqqgtr = "⪋";
const LessEqualGreater = "⋚";
const LessFullEqual = "≦";
const LessGreater = "≶";
const lessgtr = "≶";
const LessLess = "⪡";
const lesssim = "≲";
const LessSlantEqual = "⩽";
const LessTilde = "≲";
const lfisht = "⥼";
const lfloor = "⌊";
const Lfr = "𝔏";
const lfr = "𝔩";
const lg = "≶";
const lgE = "⪑";
const lHar = "⥢";
const lhard = "↽";
const lharu = "↼";
const lharul = "⥪";
const lhblk = "▄";
const LJcy = "Љ";
const ljcy = "љ";
const llarr = "⇇";
const ll = "≪";
const Ll = "⋘";
const llcorner = "⌞";
const Lleftarrow = "⇚";
const llhard = "⥫";
const lltri = "◺";
const Lmidot = "Ŀ";
const lmidot = "ŀ";
const lmoustache = "⎰";
const lmoust = "⎰";
const lnap = "⪉";
const lnapprox = "⪉";
const lne = "⪇";
const lnE = "≨";
const lneq = "⪇";
const lneqq = "≨";
const lnsim = "⋦";
const loang = "⟬";
const loarr = "⇽";
const lobrk = "⟦";
const longleftarrow = "⟵";
const LongLeftArrow = "⟵";
const Longleftarrow = "⟸";
const longleftrightarrow = "⟷";
const LongLeftRightArrow = "⟷";
const Longleftrightarrow = "⟺";
const longmapsto = "⟼";
const longrightarrow = "⟶";
const LongRightArrow = "⟶";
const Longrightarrow = "⟹";
const looparrowleft = "↫";
const looparrowright = "↬";
const lopar = "⦅";
const Lopf = "𝕃";
const lopf = "𝕝";
const loplus = "⨭";
const lotimes = "⨴";
const lowast = "∗";
const lowbar = "_";
const LowerLeftArrow = "↙";
const LowerRightArrow = "↘";
const loz = "◊";
const lozenge = "◊";
const lozf = "⧫";
const lpar = "(";
const lparlt = "⦓";
const lrarr = "⇆";
const lrcorner = "⌟";
const lrhar = "⇋";
const lrhard = "⥭";
const lrm = "‎";
const lrtri = "⊿";
const lsaquo = "‹";
const lscr = "𝓁";
const Lscr = "ℒ";
const lsh = "↰";
const Lsh = "↰";
const lsim = "≲";
const lsime = "⪍";
const lsimg = "⪏";
const lsqb = "[";
const lsquo = "‘";
const lsquor = "‚";
const Lstrok = "Ł";
const lstrok = "ł";
const ltcc = "⪦";
const ltcir = "⩹";
const lt = "<";
const LT = "<";
const Lt = "≪";
const ltdot = "⋖";
const lthree = "⋋";
const ltimes = "⋉";
const ltlarr = "⥶";
const ltquest = "⩻";
const ltri = "◃";
const ltrie = "⊴";
const ltrif = "◂";
const ltrPar = "⦖";
const lurdshar = "⥊";
const luruhar = "⥦";
const lvertneqq = "≨︀";
const lvnE = "≨︀";
const macr = "¯";
const male = "♂";
const malt = "✠";
const maltese = "✠";
const map = "↦";
const mapsto = "↦";
const mapstodown = "↧";
const mapstoleft = "↤";
const mapstoup = "↥";
const marker = "▮";
const mcomma = "⨩";
const Mcy = "М";
const mcy = "м";
const mdash = "—";
const mDDot = "∺";
const measuredangle = "∡";
const MediumSpace = " ";
const Mellintrf = "ℳ";
const Mfr = "𝔐";
const mfr = "𝔪";
const mho = "℧";
const micro = "µ";
const midast = "*";
const midcir = "⫰";
const mid = "∣";
const middot = "·";
const minusb = "⊟";
const minus = "−";
const minusd = "∸";
const minusdu = "⨪";
const MinusPlus = "∓";
const mlcp = "⫛";
const mldr = "…";
const mnplus = "∓";
const models = "⊧";
const Mopf = "𝕄";
const mopf = "𝕞";
const mp = "∓";
const mscr = "𝓂";
const Mscr = "ℳ";
const mstpos = "∾";
const Mu = "Μ";
const mu = "μ";
const multimap = "⊸";
const mumap = "⊸";
const nabla = "∇";
const Nacute = "Ń";
const nacute = "ń";
const nang = "∠⃒";
const nap = "≉";
const napE = "⩰̸";
const napid = "≋̸";
const napos = "ŉ";
const napprox = "≉";
const natural = "♮";
const naturals = "ℕ";
const natur = "♮";
const nbsp = " ";
const nbump = "≎̸";
const nbumpe = "≏̸";
const ncap = "⩃";
const Ncaron = "Ň";
const ncaron = "ň";
const Ncedil = "Ņ";
const ncedil = "ņ";
const ncong = "≇";
const ncongdot = "⩭̸";
const ncup = "⩂";
const Ncy = "Н";
const ncy = "н";
const ndash = "–";
const nearhk = "⤤";
const nearr = "↗";
const neArr = "⇗";
const nearrow = "↗";
const ne = "≠";
const nedot = "≐̸";
const NegativeMediumSpace = "​";
const NegativeThickSpace = "​";
const NegativeThinSpace = "​";
const NegativeVeryThinSpace = "​";
const nequiv = "≢";
const nesear = "⤨";
const nesim = "≂̸";
const NestedGreaterGreater = "≫";
const NestedLessLess = "≪";
const NewLine = "\n";
const nexist = "∄";
const nexists = "∄";
const Nfr = "𝔑";
const nfr = "𝔫";
const ngE = "≧̸";
const nge = "≱";
const ngeq = "≱";
const ngeqq = "≧̸";
const ngeqslant = "⩾̸";
const nges = "⩾̸";
const nGg = "⋙̸";
const ngsim = "≵";
const nGt = "≫⃒";
const ngt = "≯";
const ngtr = "≯";
const nGtv = "≫̸";
const nharr = "↮";
const nhArr = "⇎";
const nhpar = "⫲";
const ni = "∋";
const nis = "⋼";
const nisd = "⋺";
const niv = "∋";
const NJcy = "Њ";
const njcy = "њ";
const nlarr = "↚";
const nlArr = "⇍";
const nldr = "‥";
const nlE = "≦̸";
const nle = "≰";
const nleftarrow = "↚";
const nLeftarrow = "⇍";
const nleftrightarrow = "↮";
const nLeftrightarrow = "⇎";
const nleq = "≰";
const nleqq = "≦̸";
const nleqslant = "⩽̸";
const nles = "⩽̸";
const nless = "≮";
const nLl = "⋘̸";
const nlsim = "≴";
const nLt = "≪⃒";
const nlt = "≮";
const nltri = "⋪";
const nltrie = "⋬";
const nLtv = "≪̸";
const nmid = "∤";
const NoBreak = "⁠";
const NonBreakingSpace = " ";
const nopf = "𝕟";
const Nopf = "ℕ";
const Not = "⫬";
const not = "¬";
const NotCongruent = "≢";
const NotCupCap = "≭";
const NotDoubleVerticalBar = "∦";
const NotElement = "∉";
const NotEqual = "≠";
const NotEqualTilde = "≂̸";
const NotExists = "∄";
const NotGreater = "≯";
const NotGreaterEqual = "≱";
const NotGreaterFullEqual = "≧̸";
const NotGreaterGreater = "≫̸";
const NotGreaterLess = "≹";
const NotGreaterSlantEqual = "⩾̸";
const NotGreaterTilde = "≵";
const NotHumpDownHump = "≎̸";
const NotHumpEqual = "≏̸";
const notin = "∉";
const notindot = "⋵̸";
const notinE = "⋹̸";
const notinva = "∉";
const notinvb = "⋷";
const notinvc = "⋶";
const NotLeftTriangleBar = "⧏̸";
const NotLeftTriangle = "⋪";
const NotLeftTriangleEqual = "⋬";
const NotLess = "≮";
const NotLessEqual = "≰";
const NotLessGreater = "≸";
const NotLessLess = "≪̸";
const NotLessSlantEqual = "⩽̸";
const NotLessTilde = "≴";
const NotNestedGreaterGreater = "⪢̸";
const NotNestedLessLess = "⪡̸";
const notni = "∌";
const notniva = "∌";
const notnivb = "⋾";
const notnivc = "⋽";
const NotPrecedes = "⊀";
const NotPrecedesEqual = "⪯̸";
const NotPrecedesSlantEqual = "⋠";
const NotReverseElement = "∌";
const NotRightTriangleBar = "⧐̸";
const NotRightTriangle = "⋫";
const NotRightTriangleEqual = "⋭";
const NotSquareSubset = "⊏̸";
const NotSquareSubsetEqual = "⋢";
const NotSquareSuperset = "⊐̸";
const NotSquareSupersetEqual = "⋣";
const NotSubset = "⊂⃒";
const NotSubsetEqual = "⊈";
const NotSucceeds = "⊁";
const NotSucceedsEqual = "⪰̸";
const NotSucceedsSlantEqual = "⋡";
const NotSucceedsTilde = "≿̸";
const NotSuperset = "⊃⃒";
const NotSupersetEqual = "⊉";
const NotTilde = "≁";
const NotTildeEqual = "≄";
const NotTildeFullEqual = "≇";
const NotTildeTilde = "≉";
const NotVerticalBar = "∤";
const nparallel = "∦";
const npar = "∦";
const nparsl = "⫽⃥";
const npart = "∂̸";
const npolint = "⨔";
const npr = "⊀";
const nprcue = "⋠";
const nprec = "⊀";
const npreceq = "⪯̸";
const npre = "⪯̸";
const nrarrc = "⤳̸";
const nrarr = "↛";
const nrArr = "⇏";
const nrarrw = "↝̸";
const nrightarrow = "↛";
const nRightarrow = "⇏";
const nrtri = "⋫";
const nrtrie = "⋭";
const nsc = "⊁";
const nsccue = "⋡";
const nsce = "⪰̸";
const Nscr = "𝒩";
const nscr = "𝓃";
const nshortmid = "∤";
const nshortparallel = "∦";
const nsim = "≁";
const nsime = "≄";
const nsimeq = "≄";
const nsmid = "∤";
const nspar = "∦";
const nsqsube = "⋢";
const nsqsupe = "⋣";
const nsub = "⊄";
const nsubE = "⫅̸";
const nsube = "⊈";
const nsubset = "⊂⃒";
const nsubseteq = "⊈";
const nsubseteqq = "⫅̸";
const nsucc = "⊁";
const nsucceq = "⪰̸";
const nsup = "⊅";
const nsupE = "⫆̸";
const nsupe = "⊉";
const nsupset = "⊃⃒";
const nsupseteq = "⊉";
const nsupseteqq = "⫆̸";
const ntgl = "≹";
const Ntilde = "Ñ";
const ntilde = "ñ";
const ntlg = "≸";
const ntriangleleft = "⋪";
const ntrianglelefteq = "⋬";
const ntriangleright = "⋫";
const ntrianglerighteq = "⋭";
const Nu = "Ν";
const nu = "ν";
const num = "#";
const numero = "№";
const numsp = " ";
const nvap = "≍⃒";
const nvdash = "⊬";
const nvDash = "⊭";
const nVdash = "⊮";
const nVDash = "⊯";
const nvge = "≥⃒";
const nvgt = ">⃒";
const nvHarr = "⤄";
const nvinfin = "⧞";
const nvlArr = "⤂";
const nvle = "≤⃒";
const nvlt = "<⃒";
const nvltrie = "⊴⃒";
const nvrArr = "⤃";
const nvrtrie = "⊵⃒";
const nvsim = "∼⃒";
const nwarhk = "⤣";
const nwarr = "↖";
const nwArr = "⇖";
const nwarrow = "↖";
const nwnear = "⤧";
const Oacute = "Ó";
const oacute = "ó";
const oast = "⊛";
const Ocirc = "Ô";
const ocirc = "ô";
const ocir = "⊚";
const Ocy = "О";
const ocy = "о";
const odash = "⊝";
const Odblac = "Ő";
const odblac = "ő";
const odiv = "⨸";
const odot = "⊙";
const odsold = "⦼";
const OElig = "Œ";
const oelig = "œ";
const ofcir = "⦿";
const Ofr = "𝔒";
const ofr = "𝔬";
const ogon = "˛";
const Ograve = "Ò";
const ograve = "ò";
const ogt = "⧁";
const ohbar = "⦵";
const ohm = "Ω";
const oint = "∮";
const olarr = "↺";
const olcir = "⦾";
const olcross = "⦻";
const oline = "‾";
const olt = "⧀";
const Omacr = "Ō";
const omacr = "ō";
const Omega = "Ω";
const omega = "ω";
const Omicron = "Ο";
const omicron = "ο";
const omid = "⦶";
const ominus = "⊖";
const Oopf = "𝕆";
const oopf = "𝕠";
const opar = "⦷";
const OpenCurlyDoubleQuote = "“";
const OpenCurlyQuote = "‘";
const operp = "⦹";
const oplus = "⊕";
const orarr = "↻";
const Or = "⩔";
const or = "∨";
const ord = "⩝";
const order = "ℴ";
const orderof = "ℴ";
const ordf = "ª";
const ordm = "º";
const origof = "⊶";
const oror = "⩖";
const orslope = "⩗";
const orv = "⩛";
const oS = "Ⓢ";
const Oscr = "𝒪";
const oscr = "ℴ";
const Oslash = "Ø";
const oslash = "ø";
const osol = "⊘";
const Otilde = "Õ";
const otilde = "õ";
const otimesas = "⨶";
const Otimes = "⨷";
const otimes = "⊗";
const Ouml = "Ö";
const ouml = "ö";
const ovbar = "⌽";
const OverBar = "‾";
const OverBrace = "⏞";
const OverBracket = "⎴";
const OverParenthesis = "⏜";
const para = "¶";
const parallel = "∥";
const par = "∥";
const parsim = "⫳";
const parsl = "⫽";
const part = "∂";
const PartialD = "∂";
const Pcy = "П";
const pcy = "п";
const percnt = "%";
const period = ".";
const permil = "‰";
const perp = "⊥";
const pertenk = "‱";
const Pfr = "𝔓";
const pfr = "𝔭";
const Phi = "Φ";
const phi = "φ";
const phiv = "ϕ";
const phmmat = "ℳ";
const phone = "☎";
const Pi = "Π";
const pi = "π";
const pitchfork = "⋔";
const piv = "ϖ";
const planck = "ℏ";
const planckh = "ℎ";
const plankv = "ℏ";
const plusacir = "⨣";
const plusb = "⊞";
const pluscir = "⨢";
const plus = "+";
const plusdo = "∔";
const plusdu = "⨥";
const pluse = "⩲";
const PlusMinus = "±";
const plusmn = "±";
const plussim = "⨦";
const plustwo = "⨧";
const pm = "±";
const Poincareplane = "ℌ";
const pointint = "⨕";
const popf = "𝕡";
const Popf = "ℙ";
const pound = "£";
const prap = "⪷";
const Pr = "⪻";
const pr = "≺";
const prcue = "≼";
const precapprox = "⪷";
const prec = "≺";
const preccurlyeq = "≼";
const Precedes = "≺";
const PrecedesEqual = "⪯";
const PrecedesSlantEqual = "≼";
const PrecedesTilde = "≾";
const preceq = "⪯";
const precnapprox = "⪹";
const precneqq = "⪵";
const precnsim = "⋨";
const pre = "⪯";
const prE = "⪳";
const precsim = "≾";
const prime = "′";
const Prime = "″";
const primes = "ℙ";
const prnap = "⪹";
const prnE = "⪵";
const prnsim = "⋨";
const prod = "∏";
const Product = "∏";
const profalar = "⌮";
const profline = "⌒";
const profsurf = "⌓";
const prop = "∝";
const Proportional = "∝";
const Proportion = "∷";
const propto = "∝";
const prsim = "≾";
const prurel = "⊰";
const Pscr = "𝒫";
const pscr = "𝓅";
const Psi = "Ψ";
const psi = "ψ";
const puncsp = " ";
const Qfr = "𝔔";
const qfr = "𝔮";
const qint = "⨌";
const qopf = "𝕢";
const Qopf = "ℚ";
const qprime = "⁗";
const Qscr = "𝒬";
const qscr = "𝓆";
const quaternions = "ℍ";
const quatint = "⨖";
const quest = "?";
const questeq = "≟";
const quot = '"';
const QUOT = '"';
const rAarr = "⇛";
const race = "∽̱";
const Racute = "Ŕ";
const racute = "ŕ";
const radic = "√";
const raemptyv = "⦳";
const rang = "⟩";
const Rang = "⟫";
const rangd = "⦒";
const range = "⦥";
const rangle = "⟩";
const raquo = "»";
const rarrap = "⥵";
const rarrb = "⇥";
const rarrbfs = "⤠";
const rarrc = "⤳";
const rarr = "→";
const Rarr = "↠";
const rArr = "⇒";
const rarrfs = "⤞";
const rarrhk = "↪";
const rarrlp = "↬";
const rarrpl = "⥅";
const rarrsim = "⥴";
const Rarrtl = "⤖";
const rarrtl = "↣";
const rarrw = "↝";
const ratail = "⤚";
const rAtail = "⤜";
const ratio = "∶";
const rationals = "ℚ";
const rbarr = "⤍";
const rBarr = "⤏";
const RBarr = "⤐";
const rbbrk = "❳";
const rbrace = "}";
const rbrack = "]";
const rbrke = "⦌";
const rbrksld = "⦎";
const rbrkslu = "⦐";
const Rcaron = "Ř";
const rcaron = "ř";
const Rcedil = "Ŗ";
const rcedil = "ŗ";
const rceil = "⌉";
const rcub = "}";
const Rcy = "Р";
const rcy = "р";
const rdca = "⤷";
const rdldhar = "⥩";
const rdquo = "”";
const rdquor = "”";
const rdsh = "↳";
const real = "ℜ";
const realine = "ℛ";
const realpart = "ℜ";
const reals = "ℝ";
const Re = "ℜ";
const rect = "▭";
const reg = "®";
const REG = "®";
const ReverseElement = "∋";
const ReverseEquilibrium = "⇋";
const ReverseUpEquilibrium = "⥯";
const rfisht = "⥽";
const rfloor = "⌋";
const rfr = "𝔯";
const Rfr = "ℜ";
const rHar = "⥤";
const rhard = "⇁";
const rharu = "⇀";
const rharul = "⥬";
const Rho = "Ρ";
const rho = "ρ";
const rhov = "ϱ";
const RightAngleBracket = "⟩";
const RightArrowBar = "⇥";
const rightarrow = "→";
const RightArrow = "→";
const Rightarrow = "⇒";
const RightArrowLeftArrow = "⇄";
const rightarrowtail = "↣";
const RightCeiling = "⌉";
const RightDoubleBracket = "⟧";
const RightDownTeeVector = "⥝";
const RightDownVectorBar = "⥕";
const RightDownVector = "⇂";
const RightFloor = "⌋";
const rightharpoondown = "⇁";
const rightharpoonup = "⇀";
const rightleftarrows = "⇄";
const rightleftharpoons = "⇌";
const rightrightarrows = "⇉";
const rightsquigarrow = "↝";
const RightTeeArrow = "↦";
const RightTee = "⊢";
const RightTeeVector = "⥛";
const rightthreetimes = "⋌";
const RightTriangleBar = "⧐";
const RightTriangle = "⊳";
const RightTriangleEqual = "⊵";
const RightUpDownVector = "⥏";
const RightUpTeeVector = "⥜";
const RightUpVectorBar = "⥔";
const RightUpVector = "↾";
const RightVectorBar = "⥓";
const RightVector = "⇀";
const ring = "˚";
const risingdotseq = "≓";
const rlarr = "⇄";
const rlhar = "⇌";
const rlm = "‏";
const rmoustache = "⎱";
const rmoust = "⎱";
const rnmid = "⫮";
const roang = "⟭";
const roarr = "⇾";
const robrk = "⟧";
const ropar = "⦆";
const ropf = "𝕣";
const Ropf = "ℝ";
const roplus = "⨮";
const rotimes = "⨵";
const RoundImplies = "⥰";
const rpar = ")";
const rpargt = "⦔";
const rppolint = "⨒";
const rrarr = "⇉";
const Rrightarrow = "⇛";
const rsaquo = "›";
const rscr = "𝓇";
const Rscr = "ℛ";
const rsh = "↱";
const Rsh = "↱";
const rsqb = "]";
const rsquo = "’";
const rsquor = "’";
const rthree = "⋌";
const rtimes = "⋊";
const rtri = "▹";
const rtrie = "⊵";
const rtrif = "▸";
const rtriltri = "⧎";
const RuleDelayed = "⧴";
const ruluhar = "⥨";
const rx = "℞";
const Sacute = "Ś";
const sacute = "ś";
const sbquo = "‚";
const scap = "⪸";
const Scaron = "Š";
const scaron = "š";
const Sc = "⪼";
const sc = "≻";
const sccue = "≽";
const sce = "⪰";
const scE = "⪴";
const Scedil = "Ş";
const scedil = "ş";
const Scirc = "Ŝ";
const scirc = "ŝ";
const scnap = "⪺";
const scnE = "⪶";
const scnsim = "⋩";
const scpolint = "⨓";
const scsim = "≿";
const Scy = "С";
const scy = "с";
const sdotb = "⊡";
const sdot = "⋅";
const sdote = "⩦";
const searhk = "⤥";
const searr = "↘";
const seArr = "⇘";
const searrow = "↘";
const sect = "§";
const semi = ";";
const seswar = "⤩";
const setminus = "∖";
const setmn = "∖";
const sext = "✶";
const Sfr = "𝔖";
const sfr = "𝔰";
const sfrown = "⌢";
const sharp = "♯";
const SHCHcy = "Щ";
const shchcy = "щ";
const SHcy = "Ш";
const shcy = "ш";
const ShortDownArrow = "↓";
const ShortLeftArrow = "←";
const shortmid = "∣";
const shortparallel = "∥";
const ShortRightArrow = "→";
const ShortUpArrow = "↑";
const shy = "­";
const Sigma = "Σ";
const sigma = "σ";
const sigmaf = "ς";
const sigmav = "ς";
const sim = "∼";
const simdot = "⩪";
const sime = "≃";
const simeq = "≃";
const simg = "⪞";
const simgE = "⪠";
const siml = "⪝";
const simlE = "⪟";
const simne = "≆";
const simplus = "⨤";
const simrarr = "⥲";
const slarr = "←";
const SmallCircle = "∘";
const smallsetminus = "∖";
const smashp = "⨳";
const smeparsl = "⧤";
const smid = "∣";
const smile = "⌣";
const smt = "⪪";
const smte = "⪬";
const smtes = "⪬︀";
const SOFTcy = "Ь";
const softcy = "ь";
const solbar = "⌿";
const solb = "⧄";
const sol = "/";
const Sopf = "𝕊";
const sopf = "𝕤";
const spades = "♠";
const spadesuit = "♠";
const spar = "∥";
const sqcap = "⊓";
const sqcaps = "⊓︀";
const sqcup = "⊔";
const sqcups = "⊔︀";
const Sqrt = "√";
const sqsub = "⊏";
const sqsube = "⊑";
const sqsubset = "⊏";
const sqsubseteq = "⊑";
const sqsup = "⊐";
const sqsupe = "⊒";
const sqsupset = "⊐";
const sqsupseteq = "⊒";
const square = "□";
const Square = "□";
const SquareIntersection = "⊓";
const SquareSubset = "⊏";
const SquareSubsetEqual = "⊑";
const SquareSuperset = "⊐";
const SquareSupersetEqual = "⊒";
const SquareUnion = "⊔";
const squarf = "▪";
const squ = "□";
const squf = "▪";
const srarr = "→";
const Sscr = "𝒮";
const sscr = "𝓈";
const ssetmn = "∖";
const ssmile = "⌣";
const sstarf = "⋆";
const Star = "⋆";
const star = "☆";
const starf = "★";
const straightepsilon = "ϵ";
const straightphi = "ϕ";
const strns = "¯";
const sub = "⊂";
const Sub = "⋐";
const subdot = "⪽";
const subE = "⫅";
const sube = "⊆";
const subedot = "⫃";
const submult = "⫁";
const subnE = "⫋";
const subne = "⊊";
const subplus = "⪿";
const subrarr = "⥹";
const subset = "⊂";
const Subset = "⋐";
const subseteq = "⊆";
const subseteqq = "⫅";
const SubsetEqual = "⊆";
const subsetneq = "⊊";
const subsetneqq = "⫋";
const subsim = "⫇";
const subsub = "⫕";
const subsup = "⫓";
const succapprox = "⪸";
const succ = "≻";
const succcurlyeq = "≽";
const Succeeds = "≻";
const SucceedsEqual = "⪰";
const SucceedsSlantEqual = "≽";
const SucceedsTilde = "≿";
const succeq = "⪰";
const succnapprox = "⪺";
const succneqq = "⪶";
const succnsim = "⋩";
const succsim = "≿";
const SuchThat = "∋";
const sum = "∑";
const Sum = "∑";
const sung = "♪";
const sup1 = "¹";
const sup2 = "²";
const sup3 = "³";
const sup = "⊃";
const Sup = "⋑";
const supdot = "⪾";
const supdsub = "⫘";
const supE = "⫆";
const supe = "⊇";
const supedot = "⫄";
const Superset = "⊃";
const SupersetEqual = "⊇";
const suphsol = "⟉";
const suphsub = "⫗";
const suplarr = "⥻";
const supmult = "⫂";
const supnE = "⫌";
const supne = "⊋";
const supplus = "⫀";
const supset = "⊃";
const Supset = "⋑";
const supseteq = "⊇";
const supseteqq = "⫆";
const supsetneq = "⊋";
const supsetneqq = "⫌";
const supsim = "⫈";
const supsub = "⫔";
const supsup = "⫖";
const swarhk = "⤦";
const swarr = "↙";
const swArr = "⇙";
const swarrow = "↙";
const swnwar = "⤪";
const szlig = "ß";
const Tab = "	";
const target = "⌖";
const Tau = "Τ";
const tau = "τ";
const tbrk = "⎴";
const Tcaron = "Ť";
const tcaron = "ť";
const Tcedil = "Ţ";
const tcedil = "ţ";
const Tcy = "Т";
const tcy = "т";
const tdot = "⃛";
const telrec = "⌕";
const Tfr = "𝔗";
const tfr = "𝔱";
const there4 = "∴";
const therefore = "∴";
const Therefore = "∴";
const Theta = "Θ";
const theta = "θ";
const thetasym = "ϑ";
const thetav = "ϑ";
const thickapprox = "≈";
const thicksim = "∼";
const ThickSpace = "  ";
const ThinSpace = " ";
const thinsp = " ";
const thkap = "≈";
const thksim = "∼";
const THORN = "Þ";
const thorn = "þ";
const tilde = "˜";
const Tilde = "∼";
const TildeEqual = "≃";
const TildeFullEqual = "≅";
const TildeTilde = "≈";
const timesbar = "⨱";
const timesb = "⊠";
const times = "×";
const timesd = "⨰";
const tint = "∭";
const toea = "⤨";
const topbot = "⌶";
const topcir = "⫱";
const top = "⊤";
const Topf = "𝕋";
const topf = "𝕥";
const topfork = "⫚";
const tosa = "⤩";
const tprime = "‴";
const trade = "™";
const TRADE = "™";
const triangle = "▵";
const triangledown = "▿";
const triangleleft = "◃";
const trianglelefteq = "⊴";
const triangleq = "≜";
const triangleright = "▹";
const trianglerighteq = "⊵";
const tridot = "◬";
const trie = "≜";
const triminus = "⨺";
const TripleDot = "⃛";
const triplus = "⨹";
const trisb = "⧍";
const tritime = "⨻";
const trpezium = "⏢";
const Tscr = "𝒯";
const tscr = "𝓉";
const TScy = "Ц";
const tscy = "ц";
const TSHcy = "Ћ";
const tshcy = "ћ";
const Tstrok = "Ŧ";
const tstrok = "ŧ";
const twixt = "≬";
const twoheadleftarrow = "↞";
const twoheadrightarrow = "↠";
const Uacute = "Ú";
const uacute = "ú";
const uarr = "↑";
const Uarr = "↟";
const uArr = "⇑";
const Uarrocir = "⥉";
const Ubrcy = "Ў";
const ubrcy = "ў";
const Ubreve = "Ŭ";
const ubreve = "ŭ";
const Ucirc = "Û";
const ucirc = "û";
const Ucy = "У";
const ucy = "у";
const udarr = "⇅";
const Udblac = "Ű";
const udblac = "ű";
const udhar = "⥮";
const ufisht = "⥾";
const Ufr = "𝔘";
const ufr = "𝔲";
const Ugrave = "Ù";
const ugrave = "ù";
const uHar = "⥣";
const uharl = "↿";
const uharr = "↾";
const uhblk = "▀";
const ulcorn = "⌜";
const ulcorner = "⌜";
const ulcrop = "⌏";
const ultri = "◸";
const Umacr = "Ū";
const umacr = "ū";
const uml = "¨";
const UnderBar = "_";
const UnderBrace = "⏟";
const UnderBracket = "⎵";
const UnderParenthesis = "⏝";
const Union = "⋃";
const UnionPlus = "⊎";
const Uogon = "Ų";
const uogon = "ų";
const Uopf = "𝕌";
const uopf = "𝕦";
const UpArrowBar = "⤒";
const uparrow = "↑";
const UpArrow = "↑";
const Uparrow = "⇑";
const UpArrowDownArrow = "⇅";
const updownarrow = "↕";
const UpDownArrow = "↕";
const Updownarrow = "⇕";
const UpEquilibrium = "⥮";
const upharpoonleft = "↿";
const upharpoonright = "↾";
const uplus = "⊎";
const UpperLeftArrow = "↖";
const UpperRightArrow = "↗";
const upsi = "υ";
const Upsi = "ϒ";
const upsih = "ϒ";
const Upsilon = "Υ";
const upsilon = "υ";
const UpTeeArrow = "↥";
const UpTee = "⊥";
const upuparrows = "⇈";
const urcorn = "⌝";
const urcorner = "⌝";
const urcrop = "⌎";
const Uring = "Ů";
const uring = "ů";
const urtri = "◹";
const Uscr = "𝒰";
const uscr = "𝓊";
const utdot = "⋰";
const Utilde = "Ũ";
const utilde = "ũ";
const utri = "▵";
const utrif = "▴";
const uuarr = "⇈";
const Uuml = "Ü";
const uuml = "ü";
const uwangle = "⦧";
const vangrt = "⦜";
const varepsilon = "ϵ";
const varkappa = "ϰ";
const varnothing = "∅";
const varphi = "ϕ";
const varpi = "ϖ";
const varpropto = "∝";
const varr = "↕";
const vArr = "⇕";
const varrho = "ϱ";
const varsigma = "ς";
const varsubsetneq = "⊊︀";
const varsubsetneqq = "⫋︀";
const varsupsetneq = "⊋︀";
const varsupsetneqq = "⫌︀";
const vartheta = "ϑ";
const vartriangleleft = "⊲";
const vartriangleright = "⊳";
const vBar = "⫨";
const Vbar = "⫫";
const vBarv = "⫩";
const Vcy = "В";
const vcy = "в";
const vdash = "⊢";
const vDash = "⊨";
const Vdash = "⊩";
const VDash = "⊫";
const Vdashl = "⫦";
const veebar = "⊻";
const vee = "∨";
const Vee = "⋁";
const veeeq = "≚";
const vellip = "⋮";
const verbar = "|";
const Verbar = "‖";
const vert = "|";
const Vert = "‖";
const VerticalBar = "∣";
const VerticalLine = "|";
const VerticalSeparator = "❘";
const VerticalTilde = "≀";
const VeryThinSpace = " ";
const Vfr = "𝔙";
const vfr = "𝔳";
const vltri = "⊲";
const vnsub = "⊂⃒";
const vnsup = "⊃⃒";
const Vopf = "𝕍";
const vopf = "𝕧";
const vprop = "∝";
const vrtri = "⊳";
const Vscr = "𝒱";
const vscr = "𝓋";
const vsubnE = "⫋︀";
const vsubne = "⊊︀";
const vsupnE = "⫌︀";
const vsupne = "⊋︀";
const Vvdash = "⊪";
const vzigzag = "⦚";
const Wcirc = "Ŵ";
const wcirc = "ŵ";
const wedbar = "⩟";
const wedge = "∧";
const Wedge = "⋀";
const wedgeq = "≙";
const weierp = "℘";
const Wfr = "𝔚";
const wfr = "𝔴";
const Wopf = "𝕎";
const wopf = "𝕨";
const wp = "℘";
const wr = "≀";
const wreath = "≀";
const Wscr = "𝒲";
const wscr = "𝓌";
const xcap = "⋂";
const xcirc = "◯";
const xcup = "⋃";
const xdtri = "▽";
const Xfr = "𝔛";
const xfr = "𝔵";
const xharr = "⟷";
const xhArr = "⟺";
const Xi = "Ξ";
const xi = "ξ";
const xlarr = "⟵";
const xlArr = "⟸";
const xmap = "⟼";
const xnis = "⋻";
const xodot = "⨀";
const Xopf = "𝕏";
const xopf = "𝕩";
const xoplus = "⨁";
const xotime = "⨂";
const xrarr = "⟶";
const xrArr = "⟹";
const Xscr = "𝒳";
const xscr = "𝓍";
const xsqcup = "⨆";
const xuplus = "⨄";
const xutri = "△";
const xvee = "⋁";
const xwedge = "⋀";
const Yacute = "Ý";
const yacute = "ý";
const YAcy = "Я";
const yacy = "я";
const Ycirc = "Ŷ";
const ycirc = "ŷ";
const Ycy = "Ы";
const ycy = "ы";
const yen = "¥";
const Yfr = "𝔜";
const yfr = "𝔶";
const YIcy = "Ї";
const yicy = "ї";
const Yopf = "𝕐";
const yopf = "𝕪";
const Yscr = "𝒴";
const yscr = "𝓎";
const YUcy = "Ю";
const yucy = "ю";
const yuml = "ÿ";
const Yuml = "Ÿ";
const Zacute = "Ź";
const zacute = "ź";
const Zcaron = "Ž";
const zcaron = "ž";
const Zcy = "З";
const zcy = "з";
const Zdot = "Ż";
const zdot = "ż";
const zeetrf = "ℨ";
const ZeroWidthSpace = "​";
const Zeta = "Ζ";
const zeta = "ζ";
const zfr = "𝔷";
const Zfr = "ℨ";
const ZHcy = "Ж";
const zhcy = "ж";
const zigrarr = "⇝";
const zopf = "𝕫";
const Zopf = "ℤ";
const Zscr = "𝒵";
const zscr = "𝓏";
const zwj = "‍";
const zwnj = "‌";
const require$$0 = {
  Aacute,
  aacute,
  Abreve,
  abreve,
  ac,
  acd,
  acE,
  Acirc,
  acirc,
  acute,
  Acy,
  acy,
  AElig,
  aelig,
  af,
  Afr,
  afr,
  Agrave,
  agrave,
  alefsym,
  aleph,
  Alpha,
  alpha,
  Amacr,
  amacr,
  amalg,
  amp,
  AMP,
  andand,
  And,
  and,
  andd,
  andslope,
  andv,
  ang,
  ange,
  angle,
  angmsdaa,
  angmsdab,
  angmsdac,
  angmsdad,
  angmsdae,
  angmsdaf,
  angmsdag,
  angmsdah,
  angmsd,
  angrt,
  angrtvb,
  angrtvbd,
  angsph,
  angst,
  angzarr,
  Aogon,
  aogon,
  Aopf,
  aopf,
  apacir,
  ap,
  apE,
  ape,
  apid,
  apos,
  ApplyFunction,
  approx,
  approxeq,
  Aring,
  aring,
  Ascr,
  ascr,
  Assign,
  ast,
  asymp,
  asympeq,
  Atilde,
  atilde,
  Auml,
  auml,
  awconint,
  awint,
  backcong,
  backepsilon,
  backprime,
  backsim,
  backsimeq,
  Backslash,
  Barv,
  barvee,
  barwed,
  Barwed,
  barwedge,
  bbrk,
  bbrktbrk,
  bcong,
  Bcy,
  bcy,
  bdquo,
  becaus,
  because,
  Because,
  bemptyv,
  bepsi,
  bernou,
  Bernoullis,
  Beta,
  beta,
  beth,
  between,
  Bfr,
  bfr,
  bigcap,
  bigcirc,
  bigcup,
  bigodot,
  bigoplus,
  bigotimes,
  bigsqcup,
  bigstar,
  bigtriangledown,
  bigtriangleup,
  biguplus,
  bigvee,
  bigwedge,
  bkarow,
  blacklozenge,
  blacksquare,
  blacktriangle,
  blacktriangledown,
  blacktriangleleft,
  blacktriangleright,
  blank,
  blk12,
  blk14,
  blk34,
  block,
  bne,
  bnequiv,
  bNot,
  bnot,
  Bopf,
  bopf,
  bot,
  bottom,
  bowtie,
  boxbox,
  boxdl,
  boxdL,
  boxDl,
  boxDL,
  boxdr,
  boxdR,
  boxDr,
  boxDR,
  boxh,
  boxH,
  boxhd,
  boxHd,
  boxhD,
  boxHD,
  boxhu,
  boxHu,
  boxhU,
  boxHU,
  boxminus,
  boxplus,
  boxtimes,
  boxul,
  boxuL,
  boxUl,
  boxUL,
  boxur,
  boxuR,
  boxUr,
  boxUR,
  boxv,
  boxV,
  boxvh,
  boxvH,
  boxVh,
  boxVH,
  boxvl,
  boxvL,
  boxVl,
  boxVL,
  boxvr,
  boxvR,
  boxVr,
  boxVR,
  bprime,
  breve,
  Breve,
  brvbar,
  bscr,
  Bscr,
  bsemi,
  bsim,
  bsime,
  bsolb,
  bsol,
  bsolhsub,
  bull,
  bullet,
  bump,
  bumpE,
  bumpe,
  Bumpeq,
  bumpeq,
  Cacute,
  cacute,
  capand,
  capbrcup,
  capcap,
  cap,
  Cap,
  capcup,
  capdot,
  CapitalDifferentialD,
  caps,
  caret,
  caron,
  Cayleys,
  ccaps,
  Ccaron,
  ccaron,
  Ccedil,
  ccedil,
  Ccirc,
  ccirc,
  Cconint,
  ccups,
  ccupssm,
  Cdot,
  cdot,
  cedil,
  Cedilla,
  cemptyv,
  cent,
  centerdot,
  CenterDot,
  cfr,
  Cfr,
  CHcy,
  chcy,
  check,
  checkmark,
  Chi,
  chi,
  circ,
  circeq,
  circlearrowleft,
  circlearrowright,
  circledast,
  circledcirc,
  circleddash,
  CircleDot,
  circledR,
  circledS,
  CircleMinus,
  CirclePlus,
  CircleTimes,
  cir,
  cirE,
  cire,
  cirfnint,
  cirmid,
  cirscir,
  ClockwiseContourIntegral,
  CloseCurlyDoubleQuote,
  CloseCurlyQuote,
  clubs,
  clubsuit,
  colon,
  Colon,
  Colone,
  colone,
  coloneq,
  comma,
  commat,
  comp,
  compfn,
  complement,
  complexes,
  cong,
  congdot,
  Congruent,
  conint,
  Conint,
  ContourIntegral,
  copf,
  Copf,
  coprod,
  Coproduct,
  copy,
  COPY,
  copysr,
  CounterClockwiseContourIntegral,
  crarr,
  cross,
  Cross,
  Cscr,
  cscr,
  csub,
  csube,
  csup,
  csupe,
  ctdot,
  cudarrl,
  cudarrr,
  cuepr,
  cuesc,
  cularr,
  cularrp,
  cupbrcap,
  cupcap,
  CupCap,
  cup,
  Cup,
  cupcup,
  cupdot,
  cupor,
  cups,
  curarr,
  curarrm,
  curlyeqprec,
  curlyeqsucc,
  curlyvee,
  curlywedge,
  curren,
  curvearrowleft,
  curvearrowright,
  cuvee,
  cuwed,
  cwconint,
  cwint,
  cylcty,
  dagger,
  Dagger,
  daleth,
  darr,
  Darr,
  dArr,
  dash,
  Dashv,
  dashv,
  dbkarow,
  dblac,
  Dcaron,
  dcaron,
  Dcy,
  dcy,
  ddagger,
  ddarr,
  DD,
  dd,
  DDotrahd,
  ddotseq,
  deg,
  Del,
  Delta,
  delta,
  demptyv,
  dfisht,
  Dfr,
  dfr,
  dHar,
  dharl,
  dharr,
  DiacriticalAcute,
  DiacriticalDot,
  DiacriticalDoubleAcute,
  DiacriticalGrave,
  DiacriticalTilde,
  diam,
  diamond,
  Diamond,
  diamondsuit,
  diams,
  die,
  DifferentialD,
  digamma,
  disin,
  div,
  divide,
  divideontimes,
  divonx,
  DJcy,
  djcy,
  dlcorn,
  dlcrop,
  dollar,
  Dopf,
  dopf,
  Dot,
  dot,
  DotDot,
  doteq,
  doteqdot,
  DotEqual,
  dotminus,
  dotplus,
  dotsquare,
  doublebarwedge,
  DoubleContourIntegral,
  DoubleDot,
  DoubleDownArrow,
  DoubleLeftArrow,
  DoubleLeftRightArrow,
  DoubleLeftTee,
  DoubleLongLeftArrow,
  DoubleLongLeftRightArrow,
  DoubleLongRightArrow,
  DoubleRightArrow,
  DoubleRightTee,
  DoubleUpArrow,
  DoubleUpDownArrow,
  DoubleVerticalBar,
  DownArrowBar,
  downarrow,
  DownArrow,
  Downarrow,
  DownArrowUpArrow,
  DownBreve,
  downdownarrows,
  downharpoonleft,
  downharpoonright,
  DownLeftRightVector,
  DownLeftTeeVector,
  DownLeftVectorBar,
  DownLeftVector,
  DownRightTeeVector,
  DownRightVectorBar,
  DownRightVector,
  DownTeeArrow,
  DownTee,
  drbkarow,
  drcorn,
  drcrop,
  Dscr,
  dscr,
  DScy,
  dscy,
  dsol,
  Dstrok,
  dstrok,
  dtdot,
  dtri,
  dtrif,
  duarr,
  duhar,
  dwangle,
  DZcy,
  dzcy,
  dzigrarr,
  Eacute,
  eacute,
  easter,
  Ecaron,
  ecaron,
  Ecirc,
  ecirc,
  ecir,
  ecolon,
  Ecy,
  ecy,
  eDDot,
  Edot,
  edot,
  eDot,
  ee,
  efDot,
  Efr,
  efr,
  eg,
  Egrave,
  egrave,
  egs,
  egsdot,
  el,
  Element,
  elinters,
  ell,
  els,
  elsdot,
  Emacr,
  emacr,
  empty,
  emptyset,
  EmptySmallSquare,
  emptyv,
  EmptyVerySmallSquare,
  emsp13,
  emsp14,
  emsp,
  ENG,
  eng,
  ensp,
  Eogon,
  eogon,
  Eopf,
  eopf,
  epar,
  eparsl,
  eplus,
  epsi,
  Epsilon,
  epsilon,
  epsiv,
  eqcirc,
  eqcolon,
  eqsim,
  eqslantgtr,
  eqslantless,
  Equal,
  equals,
  EqualTilde,
  equest,
  Equilibrium,
  equiv,
  equivDD,
  eqvparsl,
  erarr,
  erDot,
  escr,
  Escr,
  esdot,
  Esim,
  esim,
  Eta,
  eta,
  ETH,
  eth,
  Euml,
  euml,
  euro,
  excl,
  exist,
  Exists,
  expectation,
  exponentiale,
  ExponentialE,
  fallingdotseq,
  Fcy,
  fcy,
  female,
  ffilig,
  fflig,
  ffllig,
  Ffr,
  ffr,
  filig,
  FilledSmallSquare,
  FilledVerySmallSquare,
  fjlig,
  flat,
  fllig,
  fltns,
  fnof,
  Fopf,
  fopf,
  forall,
  ForAll,
  fork,
  forkv,
  Fouriertrf,
  fpartint,
  frac12,
  frac13,
  frac14,
  frac15,
  frac16,
  frac18,
  frac23,
  frac25,
  frac34,
  frac35,
  frac38,
  frac45,
  frac56,
  frac58,
  frac78,
  frasl,
  frown,
  fscr,
  Fscr,
  gacute,
  Gamma,
  gamma,
  Gammad,
  gammad,
  gap,
  Gbreve,
  gbreve,
  Gcedil,
  Gcirc,
  gcirc,
  Gcy,
  gcy,
  Gdot,
  gdot,
  ge,
  gE,
  gEl,
  gel,
  geq,
  geqq,
  geqslant,
  gescc,
  ges,
  gesdot,
  gesdoto,
  gesdotol,
  gesl,
  gesles,
  Gfr,
  gfr,
  gg,
  Gg,
  ggg,
  gimel,
  GJcy,
  gjcy,
  gla,
  gl,
  glE,
  glj,
  gnap,
  gnapprox,
  gne,
  gnE,
  gneq,
  gneqq,
  gnsim,
  Gopf,
  gopf,
  grave,
  GreaterEqual,
  GreaterEqualLess,
  GreaterFullEqual,
  GreaterGreater,
  GreaterLess,
  GreaterSlantEqual,
  GreaterTilde,
  Gscr,
  gscr,
  gsim,
  gsime,
  gsiml,
  gtcc,
  gtcir,
  gt,
  GT,
  Gt,
  gtdot,
  gtlPar,
  gtquest,
  gtrapprox,
  gtrarr,
  gtrdot,
  gtreqless,
  gtreqqless,
  gtrless,
  gtrsim,
  gvertneqq,
  gvnE,
  Hacek,
  hairsp,
  half,
  hamilt,
  HARDcy,
  hardcy,
  harrcir,
  harr,
  hArr,
  harrw,
  Hat,
  hbar,
  Hcirc,
  hcirc,
  hearts,
  heartsuit,
  hellip,
  hercon,
  hfr,
  Hfr,
  HilbertSpace,
  hksearow,
  hkswarow,
  hoarr,
  homtht,
  hookleftarrow,
  hookrightarrow,
  hopf,
  Hopf,
  horbar,
  HorizontalLine,
  hscr,
  Hscr,
  hslash,
  Hstrok,
  hstrok,
  HumpDownHump,
  HumpEqual,
  hybull,
  hyphen,
  Iacute,
  iacute,
  ic,
  Icirc,
  icirc,
  Icy,
  icy,
  Idot,
  IEcy,
  iecy,
  iexcl,
  iff,
  ifr,
  Ifr,
  Igrave,
  igrave,
  ii,
  iiiint,
  iiint,
  iinfin,
  iiota,
  IJlig,
  ijlig,
  Imacr,
  imacr,
  image,
  ImaginaryI,
  imagline,
  imagpart,
  imath,
  Im,
  imof,
  imped,
  Implies,
  incare,
  "in": "∈",
  infin,
  infintie,
  inodot,
  intcal,
  int,
  Int,
  integers,
  Integral,
  intercal,
  Intersection,
  intlarhk,
  intprod,
  InvisibleComma,
  InvisibleTimes,
  IOcy,
  iocy,
  Iogon,
  iogon,
  Iopf,
  iopf,
  Iota,
  iota,
  iprod,
  iquest,
  iscr,
  Iscr,
  isin,
  isindot,
  isinE,
  isins,
  isinsv,
  isinv,
  it,
  Itilde,
  itilde,
  Iukcy,
  iukcy,
  Iuml,
  iuml,
  Jcirc,
  jcirc,
  Jcy,
  jcy,
  Jfr,
  jfr,
  jmath,
  Jopf,
  jopf,
  Jscr,
  jscr,
  Jsercy,
  jsercy,
  Jukcy,
  jukcy,
  Kappa,
  kappa,
  kappav,
  Kcedil,
  kcedil,
  Kcy,
  kcy,
  Kfr,
  kfr,
  kgreen,
  KHcy,
  khcy,
  KJcy,
  kjcy,
  Kopf,
  kopf,
  Kscr,
  kscr,
  lAarr,
  Lacute,
  lacute,
  laemptyv,
  lagran,
  Lambda,
  lambda,
  lang,
  Lang,
  langd,
  langle,
  lap,
  Laplacetrf,
  laquo,
  larrb,
  larrbfs,
  larr,
  Larr,
  lArr,
  larrfs,
  larrhk,
  larrlp,
  larrpl,
  larrsim,
  larrtl,
  latail,
  lAtail,
  lat,
  late,
  lates,
  lbarr,
  lBarr,
  lbbrk,
  lbrace,
  lbrack,
  lbrke,
  lbrksld,
  lbrkslu,
  Lcaron,
  lcaron,
  Lcedil,
  lcedil,
  lceil,
  lcub,
  Lcy,
  lcy,
  ldca,
  ldquo,
  ldquor,
  ldrdhar,
  ldrushar,
  ldsh,
  le,
  lE,
  LeftAngleBracket,
  LeftArrowBar,
  leftarrow,
  LeftArrow,
  Leftarrow,
  LeftArrowRightArrow,
  leftarrowtail,
  LeftCeiling,
  LeftDoubleBracket,
  LeftDownTeeVector,
  LeftDownVectorBar,
  LeftDownVector,
  LeftFloor,
  leftharpoondown,
  leftharpoonup,
  leftleftarrows,
  leftrightarrow,
  LeftRightArrow,
  Leftrightarrow,
  leftrightarrows,
  leftrightharpoons,
  leftrightsquigarrow,
  LeftRightVector,
  LeftTeeArrow,
  LeftTee,
  LeftTeeVector,
  leftthreetimes,
  LeftTriangleBar,
  LeftTriangle,
  LeftTriangleEqual,
  LeftUpDownVector,
  LeftUpTeeVector,
  LeftUpVectorBar,
  LeftUpVector,
  LeftVectorBar,
  LeftVector,
  lEg,
  leg,
  leq,
  leqq,
  leqslant,
  lescc,
  les,
  lesdot,
  lesdoto,
  lesdotor,
  lesg,
  lesges,
  lessapprox,
  lessdot,
  lesseqgtr,
  lesseqqgtr,
  LessEqualGreater,
  LessFullEqual,
  LessGreater,
  lessgtr,
  LessLess,
  lesssim,
  LessSlantEqual,
  LessTilde,
  lfisht,
  lfloor,
  Lfr,
  lfr,
  lg,
  lgE,
  lHar,
  lhard,
  lharu,
  lharul,
  lhblk,
  LJcy,
  ljcy,
  llarr,
  ll,
  Ll,
  llcorner,
  Lleftarrow,
  llhard,
  lltri,
  Lmidot,
  lmidot,
  lmoustache,
  lmoust,
  lnap,
  lnapprox,
  lne,
  lnE,
  lneq,
  lneqq,
  lnsim,
  loang,
  loarr,
  lobrk,
  longleftarrow,
  LongLeftArrow,
  Longleftarrow,
  longleftrightarrow,
  LongLeftRightArrow,
  Longleftrightarrow,
  longmapsto,
  longrightarrow,
  LongRightArrow,
  Longrightarrow,
  looparrowleft,
  looparrowright,
  lopar,
  Lopf,
  lopf,
  loplus,
  lotimes,
  lowast,
  lowbar,
  LowerLeftArrow,
  LowerRightArrow,
  loz,
  lozenge,
  lozf,
  lpar,
  lparlt,
  lrarr,
  lrcorner,
  lrhar,
  lrhard,
  lrm,
  lrtri,
  lsaquo,
  lscr,
  Lscr,
  lsh,
  Lsh,
  lsim,
  lsime,
  lsimg,
  lsqb,
  lsquo,
  lsquor,
  Lstrok,
  lstrok,
  ltcc,
  ltcir,
  lt,
  LT,
  Lt,
  ltdot,
  lthree,
  ltimes,
  ltlarr,
  ltquest,
  ltri,
  ltrie,
  ltrif,
  ltrPar,
  lurdshar,
  luruhar,
  lvertneqq,
  lvnE,
  macr,
  male,
  malt,
  maltese,
  "Map": "⤅",
  map,
  mapsto,
  mapstodown,
  mapstoleft,
  mapstoup,
  marker,
  mcomma,
  Mcy,
  mcy,
  mdash,
  mDDot,
  measuredangle,
  MediumSpace,
  Mellintrf,
  Mfr,
  mfr,
  mho,
  micro,
  midast,
  midcir,
  mid,
  middot,
  minusb,
  minus,
  minusd,
  minusdu,
  MinusPlus,
  mlcp,
  mldr,
  mnplus,
  models,
  Mopf,
  mopf,
  mp,
  mscr,
  Mscr,
  mstpos,
  Mu,
  mu,
  multimap,
  mumap,
  nabla,
  Nacute,
  nacute,
  nang,
  nap,
  napE,
  napid,
  napos,
  napprox,
  natural,
  naturals,
  natur,
  nbsp,
  nbump,
  nbumpe,
  ncap,
  Ncaron,
  ncaron,
  Ncedil,
  ncedil,
  ncong,
  ncongdot,
  ncup,
  Ncy,
  ncy,
  ndash,
  nearhk,
  nearr,
  neArr,
  nearrow,
  ne,
  nedot,
  NegativeMediumSpace,
  NegativeThickSpace,
  NegativeThinSpace,
  NegativeVeryThinSpace,
  nequiv,
  nesear,
  nesim,
  NestedGreaterGreater,
  NestedLessLess,
  NewLine,
  nexist,
  nexists,
  Nfr,
  nfr,
  ngE,
  nge,
  ngeq,
  ngeqq,
  ngeqslant,
  nges,
  nGg,
  ngsim,
  nGt,
  ngt,
  ngtr,
  nGtv,
  nharr,
  nhArr,
  nhpar,
  ni,
  nis,
  nisd,
  niv,
  NJcy,
  njcy,
  nlarr,
  nlArr,
  nldr,
  nlE,
  nle,
  nleftarrow,
  nLeftarrow,
  nleftrightarrow,
  nLeftrightarrow,
  nleq,
  nleqq,
  nleqslant,
  nles,
  nless,
  nLl,
  nlsim,
  nLt,
  nlt,
  nltri,
  nltrie,
  nLtv,
  nmid,
  NoBreak,
  NonBreakingSpace,
  nopf,
  Nopf,
  Not,
  not,
  NotCongruent,
  NotCupCap,
  NotDoubleVerticalBar,
  NotElement,
  NotEqual,
  NotEqualTilde,
  NotExists,
  NotGreater,
  NotGreaterEqual,
  NotGreaterFullEqual,
  NotGreaterGreater,
  NotGreaterLess,
  NotGreaterSlantEqual,
  NotGreaterTilde,
  NotHumpDownHump,
  NotHumpEqual,
  notin,
  notindot,
  notinE,
  notinva,
  notinvb,
  notinvc,
  NotLeftTriangleBar,
  NotLeftTriangle,
  NotLeftTriangleEqual,
  NotLess,
  NotLessEqual,
  NotLessGreater,
  NotLessLess,
  NotLessSlantEqual,
  NotLessTilde,
  NotNestedGreaterGreater,
  NotNestedLessLess,
  notni,
  notniva,
  notnivb,
  notnivc,
  NotPrecedes,
  NotPrecedesEqual,
  NotPrecedesSlantEqual,
  NotReverseElement,
  NotRightTriangleBar,
  NotRightTriangle,
  NotRightTriangleEqual,
  NotSquareSubset,
  NotSquareSubsetEqual,
  NotSquareSuperset,
  NotSquareSupersetEqual,
  NotSubset,
  NotSubsetEqual,
  NotSucceeds,
  NotSucceedsEqual,
  NotSucceedsSlantEqual,
  NotSucceedsTilde,
  NotSuperset,
  NotSupersetEqual,
  NotTilde,
  NotTildeEqual,
  NotTildeFullEqual,
  NotTildeTilde,
  NotVerticalBar,
  nparallel,
  npar,
  nparsl,
  npart,
  npolint,
  npr,
  nprcue,
  nprec,
  npreceq,
  npre,
  nrarrc,
  nrarr,
  nrArr,
  nrarrw,
  nrightarrow,
  nRightarrow,
  nrtri,
  nrtrie,
  nsc,
  nsccue,
  nsce,
  Nscr,
  nscr,
  nshortmid,
  nshortparallel,
  nsim,
  nsime,
  nsimeq,
  nsmid,
  nspar,
  nsqsube,
  nsqsupe,
  nsub,
  nsubE,
  nsube,
  nsubset,
  nsubseteq,
  nsubseteqq,
  nsucc,
  nsucceq,
  nsup,
  nsupE,
  nsupe,
  nsupset,
  nsupseteq,
  nsupseteqq,
  ntgl,
  Ntilde,
  ntilde,
  ntlg,
  ntriangleleft,
  ntrianglelefteq,
  ntriangleright,
  ntrianglerighteq,
  Nu,
  nu,
  num,
  numero,
  numsp,
  nvap,
  nvdash,
  nvDash,
  nVdash,
  nVDash,
  nvge,
  nvgt,
  nvHarr,
  nvinfin,
  nvlArr,
  nvle,
  nvlt,
  nvltrie,
  nvrArr,
  nvrtrie,
  nvsim,
  nwarhk,
  nwarr,
  nwArr,
  nwarrow,
  nwnear,
  Oacute,
  oacute,
  oast,
  Ocirc,
  ocirc,
  ocir,
  Ocy,
  ocy,
  odash,
  Odblac,
  odblac,
  odiv,
  odot,
  odsold,
  OElig,
  oelig,
  ofcir,
  Ofr,
  ofr,
  ogon,
  Ograve,
  ograve,
  ogt,
  ohbar,
  ohm,
  oint,
  olarr,
  olcir,
  olcross,
  oline,
  olt,
  Omacr,
  omacr,
  Omega,
  omega,
  Omicron,
  omicron,
  omid,
  ominus,
  Oopf,
  oopf,
  opar,
  OpenCurlyDoubleQuote,
  OpenCurlyQuote,
  operp,
  oplus,
  orarr,
  Or,
  or,
  ord,
  order,
  orderof,
  ordf,
  ordm,
  origof,
  oror,
  orslope,
  orv,
  oS,
  Oscr,
  oscr,
  Oslash,
  oslash,
  osol,
  Otilde,
  otilde,
  otimesas,
  Otimes,
  otimes,
  Ouml,
  ouml,
  ovbar,
  OverBar,
  OverBrace,
  OverBracket,
  OverParenthesis,
  para,
  parallel,
  par,
  parsim,
  parsl,
  part,
  PartialD,
  Pcy,
  pcy,
  percnt,
  period,
  permil,
  perp,
  pertenk,
  Pfr,
  pfr,
  Phi,
  phi,
  phiv,
  phmmat,
  phone,
  Pi,
  pi,
  pitchfork,
  piv,
  planck,
  planckh,
  plankv,
  plusacir,
  plusb,
  pluscir,
  plus,
  plusdo,
  plusdu,
  pluse,
  PlusMinus,
  plusmn,
  plussim,
  plustwo,
  pm,
  Poincareplane,
  pointint,
  popf,
  Popf,
  pound,
  prap,
  Pr,
  pr,
  prcue,
  precapprox,
  prec,
  preccurlyeq,
  Precedes,
  PrecedesEqual,
  PrecedesSlantEqual,
  PrecedesTilde,
  preceq,
  precnapprox,
  precneqq,
  precnsim,
  pre,
  prE,
  precsim,
  prime,
  Prime,
  primes,
  prnap,
  prnE,
  prnsim,
  prod,
  Product,
  profalar,
  profline,
  profsurf,
  prop,
  Proportional,
  Proportion,
  propto,
  prsim,
  prurel,
  Pscr,
  pscr,
  Psi,
  psi,
  puncsp,
  Qfr,
  qfr,
  qint,
  qopf,
  Qopf,
  qprime,
  Qscr,
  qscr,
  quaternions,
  quatint,
  quest,
  questeq,
  quot,
  QUOT,
  rAarr,
  race,
  Racute,
  racute,
  radic,
  raemptyv,
  rang,
  Rang,
  rangd,
  range,
  rangle,
  raquo,
  rarrap,
  rarrb,
  rarrbfs,
  rarrc,
  rarr,
  Rarr,
  rArr,
  rarrfs,
  rarrhk,
  rarrlp,
  rarrpl,
  rarrsim,
  Rarrtl,
  rarrtl,
  rarrw,
  ratail,
  rAtail,
  ratio,
  rationals,
  rbarr,
  rBarr,
  RBarr,
  rbbrk,
  rbrace,
  rbrack,
  rbrke,
  rbrksld,
  rbrkslu,
  Rcaron,
  rcaron,
  Rcedil,
  rcedil,
  rceil,
  rcub,
  Rcy,
  rcy,
  rdca,
  rdldhar,
  rdquo,
  rdquor,
  rdsh,
  real,
  realine,
  realpart,
  reals,
  Re,
  rect,
  reg,
  REG,
  ReverseElement,
  ReverseEquilibrium,
  ReverseUpEquilibrium,
  rfisht,
  rfloor,
  rfr,
  Rfr,
  rHar,
  rhard,
  rharu,
  rharul,
  Rho,
  rho,
  rhov,
  RightAngleBracket,
  RightArrowBar,
  rightarrow,
  RightArrow,
  Rightarrow,
  RightArrowLeftArrow,
  rightarrowtail,
  RightCeiling,
  RightDoubleBracket,
  RightDownTeeVector,
  RightDownVectorBar,
  RightDownVector,
  RightFloor,
  rightharpoondown,
  rightharpoonup,
  rightleftarrows,
  rightleftharpoons,
  rightrightarrows,
  rightsquigarrow,
  RightTeeArrow,
  RightTee,
  RightTeeVector,
  rightthreetimes,
  RightTriangleBar,
  RightTriangle,
  RightTriangleEqual,
  RightUpDownVector,
  RightUpTeeVector,
  RightUpVectorBar,
  RightUpVector,
  RightVectorBar,
  RightVector,
  ring,
  risingdotseq,
  rlarr,
  rlhar,
  rlm,
  rmoustache,
  rmoust,
  rnmid,
  roang,
  roarr,
  robrk,
  ropar,
  ropf,
  Ropf,
  roplus,
  rotimes,
  RoundImplies,
  rpar,
  rpargt,
  rppolint,
  rrarr,
  Rrightarrow,
  rsaquo,
  rscr,
  Rscr,
  rsh,
  Rsh,
  rsqb,
  rsquo,
  rsquor,
  rthree,
  rtimes,
  rtri,
  rtrie,
  rtrif,
  rtriltri,
  RuleDelayed,
  ruluhar,
  rx,
  Sacute,
  sacute,
  sbquo,
  scap,
  Scaron,
  scaron,
  Sc,
  sc,
  sccue,
  sce,
  scE,
  Scedil,
  scedil,
  Scirc,
  scirc,
  scnap,
  scnE,
  scnsim,
  scpolint,
  scsim,
  Scy,
  scy,
  sdotb,
  sdot,
  sdote,
  searhk,
  searr,
  seArr,
  searrow,
  sect,
  semi,
  seswar,
  setminus,
  setmn,
  sext,
  Sfr,
  sfr,
  sfrown,
  sharp,
  SHCHcy,
  shchcy,
  SHcy,
  shcy,
  ShortDownArrow,
  ShortLeftArrow,
  shortmid,
  shortparallel,
  ShortRightArrow,
  ShortUpArrow,
  shy,
  Sigma,
  sigma,
  sigmaf,
  sigmav,
  sim,
  simdot,
  sime,
  simeq,
  simg,
  simgE,
  siml,
  simlE,
  simne,
  simplus,
  simrarr,
  slarr,
  SmallCircle,
  smallsetminus,
  smashp,
  smeparsl,
  smid,
  smile,
  smt,
  smte,
  smtes,
  SOFTcy,
  softcy,
  solbar,
  solb,
  sol,
  Sopf,
  sopf,
  spades,
  spadesuit,
  spar,
  sqcap,
  sqcaps,
  sqcup,
  sqcups,
  Sqrt,
  sqsub,
  sqsube,
  sqsubset,
  sqsubseteq,
  sqsup,
  sqsupe,
  sqsupset,
  sqsupseteq,
  square,
  Square,
  SquareIntersection,
  SquareSubset,
  SquareSubsetEqual,
  SquareSuperset,
  SquareSupersetEqual,
  SquareUnion,
  squarf,
  squ,
  squf,
  srarr,
  Sscr,
  sscr,
  ssetmn,
  ssmile,
  sstarf,
  Star,
  star,
  starf,
  straightepsilon,
  straightphi,
  strns,
  sub,
  Sub,
  subdot,
  subE,
  sube,
  subedot,
  submult,
  subnE,
  subne,
  subplus,
  subrarr,
  subset,
  Subset,
  subseteq,
  subseteqq,
  SubsetEqual,
  subsetneq,
  subsetneqq,
  subsim,
  subsub,
  subsup,
  succapprox,
  succ,
  succcurlyeq,
  Succeeds,
  SucceedsEqual,
  SucceedsSlantEqual,
  SucceedsTilde,
  succeq,
  succnapprox,
  succneqq,
  succnsim,
  succsim,
  SuchThat,
  sum,
  Sum,
  sung,
  sup1,
  sup2,
  sup3,
  sup,
  Sup,
  supdot,
  supdsub,
  supE,
  supe,
  supedot,
  Superset,
  SupersetEqual,
  suphsol,
  suphsub,
  suplarr,
  supmult,
  supnE,
  supne,
  supplus,
  supset,
  Supset,
  supseteq,
  supseteqq,
  supsetneq,
  supsetneqq,
  supsim,
  supsub,
  supsup,
  swarhk,
  swarr,
  swArr,
  swarrow,
  swnwar,
  szlig,
  Tab,
  target,
  Tau,
  tau,
  tbrk,
  Tcaron,
  tcaron,
  Tcedil,
  tcedil,
  Tcy,
  tcy,
  tdot,
  telrec,
  Tfr,
  tfr,
  there4,
  therefore,
  Therefore,
  Theta,
  theta,
  thetasym,
  thetav,
  thickapprox,
  thicksim,
  ThickSpace,
  ThinSpace,
  thinsp,
  thkap,
  thksim,
  THORN,
  thorn,
  tilde,
  Tilde,
  TildeEqual,
  TildeFullEqual,
  TildeTilde,
  timesbar,
  timesb,
  times,
  timesd,
  tint,
  toea,
  topbot,
  topcir,
  top,
  Topf,
  topf,
  topfork,
  tosa,
  tprime,
  trade,
  TRADE,
  triangle,
  triangledown,
  triangleleft,
  trianglelefteq,
  triangleq,
  triangleright,
  trianglerighteq,
  tridot,
  trie,
  triminus,
  TripleDot,
  triplus,
  trisb,
  tritime,
  trpezium,
  Tscr,
  tscr,
  TScy,
  tscy,
  TSHcy,
  tshcy,
  Tstrok,
  tstrok,
  twixt,
  twoheadleftarrow,
  twoheadrightarrow,
  Uacute,
  uacute,
  uarr,
  Uarr,
  uArr,
  Uarrocir,
  Ubrcy,
  ubrcy,
  Ubreve,
  ubreve,
  Ucirc,
  ucirc,
  Ucy,
  ucy,
  udarr,
  Udblac,
  udblac,
  udhar,
  ufisht,
  Ufr,
  ufr,
  Ugrave,
  ugrave,
  uHar,
  uharl,
  uharr,
  uhblk,
  ulcorn,
  ulcorner,
  ulcrop,
  ultri,
  Umacr,
  umacr,
  uml,
  UnderBar,
  UnderBrace,
  UnderBracket,
  UnderParenthesis,
  Union,
  UnionPlus,
  Uogon,
  uogon,
  Uopf,
  uopf,
  UpArrowBar,
  uparrow,
  UpArrow,
  Uparrow,
  UpArrowDownArrow,
  updownarrow,
  UpDownArrow,
  Updownarrow,
  UpEquilibrium,
  upharpoonleft,
  upharpoonright,
  uplus,
  UpperLeftArrow,
  UpperRightArrow,
  upsi,
  Upsi,
  upsih,
  Upsilon,
  upsilon,
  UpTeeArrow,
  UpTee,
  upuparrows,
  urcorn,
  urcorner,
  urcrop,
  Uring,
  uring,
  urtri,
  Uscr,
  uscr,
  utdot,
  Utilde,
  utilde,
  utri,
  utrif,
  uuarr,
  Uuml,
  uuml,
  uwangle,
  vangrt,
  varepsilon,
  varkappa,
  varnothing,
  varphi,
  varpi,
  varpropto,
  varr,
  vArr,
  varrho,
  varsigma,
  varsubsetneq,
  varsubsetneqq,
  varsupsetneq,
  varsupsetneqq,
  vartheta,
  vartriangleleft,
  vartriangleright,
  vBar,
  Vbar,
  vBarv,
  Vcy,
  vcy,
  vdash,
  vDash,
  Vdash,
  VDash,
  Vdashl,
  veebar,
  vee,
  Vee,
  veeeq,
  vellip,
  verbar,
  Verbar,
  vert,
  Vert,
  VerticalBar,
  VerticalLine,
  VerticalSeparator,
  VerticalTilde,
  VeryThinSpace,
  Vfr,
  vfr,
  vltri,
  vnsub,
  vnsup,
  Vopf,
  vopf,
  vprop,
  vrtri,
  Vscr,
  vscr,
  vsubnE,
  vsubne,
  vsupnE,
  vsupne,
  Vvdash,
  vzigzag,
  Wcirc,
  wcirc,
  wedbar,
  wedge,
  Wedge,
  wedgeq,
  weierp,
  Wfr,
  wfr,
  Wopf,
  wopf,
  wp,
  wr,
  wreath,
  Wscr,
  wscr,
  xcap,
  xcirc,
  xcup,
  xdtri,
  Xfr,
  xfr,
  xharr,
  xhArr,
  Xi,
  xi,
  xlarr,
  xlArr,
  xmap,
  xnis,
  xodot,
  Xopf,
  xopf,
  xoplus,
  xotime,
  xrarr,
  xrArr,
  Xscr,
  xscr,
  xsqcup,
  xuplus,
  xutri,
  xvee,
  xwedge,
  Yacute,
  yacute,
  YAcy,
  yacy,
  Ycirc,
  ycirc,
  Ycy,
  ycy,
  yen,
  Yfr,
  yfr,
  YIcy,
  yicy,
  Yopf,
  yopf,
  Yscr,
  yscr,
  YUcy,
  yucy,
  yuml,
  Yuml,
  Zacute,
  zacute,
  Zcaron,
  zcaron,
  Zcy,
  zcy,
  Zdot,
  zdot,
  zeetrf,
  ZeroWidthSpace,
  Zeta,
  zeta,
  zfr,
  Zfr,
  ZHcy,
  zhcy,
  zigrarr,
  zopf,
  Zopf,
  Zscr,
  zscr,
  zwj,
  zwnj
};
(function(module) {
  module.exports = require$$0;
})(entities);
var regex$4 = /[!-#%-\*,-\/:;\?@\[-\]_\{\}\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061E\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166D\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4E\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]|\uD800[\uDD00-\uDD02\uDF9F\uDFD0]|\uD801\uDD6F|\uD802[\uDC57\uDD1F\uDD3F\uDE50-\uDE58\uDE7F\uDEF0-\uDEF6\uDF39-\uDF3F\uDF99-\uDF9C]|\uD803[\uDF55-\uDF59]|\uD804[\uDC47-\uDC4D\uDCBB\uDCBC\uDCBE-\uDCC1\uDD40-\uDD43\uDD74\uDD75\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDDF\uDE38-\uDE3D\uDEA9]|\uD805[\uDC4B-\uDC4F\uDC5B\uDC5D\uDCC6\uDDC1-\uDDD7\uDE41-\uDE43\uDE60-\uDE6C\uDF3C-\uDF3E]|\uD806[\uDC3B\uDE3F-\uDE46\uDE9A-\uDE9C\uDE9E-\uDEA2]|\uD807[\uDC41-\uDC45\uDC70\uDC71\uDEF7\uDEF8]|\uD809[\uDC70-\uDC74]|\uD81A[\uDE6E\uDE6F\uDEF5\uDF37-\uDF3B\uDF44]|\uD81B[\uDE97-\uDE9A]|\uD82F\uDC9F|\uD836[\uDE87-\uDE8B]|\uD83A[\uDD5E\uDD5F]/;
var mdurl = {};
var encode_1;
var hasRequiredEncode;
function requireEncode() {
  if (hasRequiredEncode)
    return encode_1;
  hasRequiredEncode = 1;
  var encodeCache = {};
  function getEncodeCache(exclude) {
    var i, ch, cache = encodeCache[exclude];
    if (cache) {
      return cache;
    }
    cache = encodeCache[exclude] = [];
    for (i = 0; i < 128; i++) {
      ch = String.fromCharCode(i);
      if (/^[0-9a-z]$/i.test(ch)) {
        cache.push(ch);
      } else {
        cache.push("%" + ("0" + i.toString(16).toUpperCase()).slice(-2));
      }
    }
    for (i = 0; i < exclude.length; i++) {
      cache[exclude.charCodeAt(i)] = exclude[i];
    }
    return cache;
  }
  function encode(string, exclude, keepEscaped) {
    var i, l, code, nextCode, cache, result = "";
    if (typeof exclude !== "string") {
      keepEscaped = exclude;
      exclude = encode.defaultChars;
    }
    if (typeof keepEscaped === "undefined") {
      keepEscaped = true;
    }
    cache = getEncodeCache(exclude);
    for (i = 0, l = string.length; i < l; i++) {
      code = string.charCodeAt(i);
      if (keepEscaped && code === 37 && i + 2 < l) {
        if (/^[0-9a-f]{2}$/i.test(string.slice(i + 1, i + 3))) {
          result += string.slice(i, i + 3);
          i += 2;
          continue;
        }
      }
      if (code < 128) {
        result += cache[code];
        continue;
      }
      if (code >= 55296 && code <= 57343) {
        if (code >= 55296 && code <= 56319 && i + 1 < l) {
          nextCode = string.charCodeAt(i + 1);
          if (nextCode >= 56320 && nextCode <= 57343) {
            result += encodeURIComponent(string[i] + string[i + 1]);
            i++;
            continue;
          }
        }
        result += "%EF%BF%BD";
        continue;
      }
      result += encodeURIComponent(string[i]);
    }
    return result;
  }
  encode.defaultChars = ";/?:@&=+$,-_.!~*'()#";
  encode.componentChars = "-_.!~*'()";
  encode_1 = encode;
  return encode_1;
}
var decode_1;
var hasRequiredDecode;
function requireDecode() {
  if (hasRequiredDecode)
    return decode_1;
  hasRequiredDecode = 1;
  var decodeCache = {};
  function getDecodeCache(exclude) {
    var i, ch, cache = decodeCache[exclude];
    if (cache) {
      return cache;
    }
    cache = decodeCache[exclude] = [];
    for (i = 0; i < 128; i++) {
      ch = String.fromCharCode(i);
      cache.push(ch);
    }
    for (i = 0; i < exclude.length; i++) {
      ch = exclude.charCodeAt(i);
      cache[ch] = "%" + ("0" + ch.toString(16).toUpperCase()).slice(-2);
    }
    return cache;
  }
  function decode(string, exclude) {
    var cache;
    if (typeof exclude !== "string") {
      exclude = decode.defaultChars;
    }
    cache = getDecodeCache(exclude);
    return string.replace(/(%[a-f0-9]{2})+/gi, function(seq) {
      var i, l, b1, b2, b3, b4, chr, result = "";
      for (i = 0, l = seq.length; i < l; i += 3) {
        b1 = parseInt(seq.slice(i + 1, i + 3), 16);
        if (b1 < 128) {
          result += cache[b1];
          continue;
        }
        if ((b1 & 224) === 192 && i + 3 < l) {
          b2 = parseInt(seq.slice(i + 4, i + 6), 16);
          if ((b2 & 192) === 128) {
            chr = b1 << 6 & 1984 | b2 & 63;
            if (chr < 128) {
              result += "��";
            } else {
              result += String.fromCharCode(chr);
            }
            i += 3;
            continue;
          }
        }
        if ((b1 & 240) === 224 && i + 6 < l) {
          b2 = parseInt(seq.slice(i + 4, i + 6), 16);
          b3 = parseInt(seq.slice(i + 7, i + 9), 16);
          if ((b2 & 192) === 128 && (b3 & 192) === 128) {
            chr = b1 << 12 & 61440 | b2 << 6 & 4032 | b3 & 63;
            if (chr < 2048 || chr >= 55296 && chr <= 57343) {
              result += "���";
            } else {
              result += String.fromCharCode(chr);
            }
            i += 6;
            continue;
          }
        }
        if ((b1 & 248) === 240 && i + 9 < l) {
          b2 = parseInt(seq.slice(i + 4, i + 6), 16);
          b3 = parseInt(seq.slice(i + 7, i + 9), 16);
          b4 = parseInt(seq.slice(i + 10, i + 12), 16);
          if ((b2 & 192) === 128 && (b3 & 192) === 128 && (b4 & 192) === 128) {
            chr = b1 << 18 & 1835008 | b2 << 12 & 258048 | b3 << 6 & 4032 | b4 & 63;
            if (chr < 65536 || chr > 1114111) {
              result += "����";
            } else {
              chr -= 65536;
              result += String.fromCharCode(55296 + (chr >> 10), 56320 + (chr & 1023));
            }
            i += 9;
            continue;
          }
        }
        result += "�";
      }
      return result;
    });
  }
  decode.defaultChars = ";/?:@&=+$,#";
  decode.componentChars = "";
  decode_1 = decode;
  return decode_1;
}
var format;
var hasRequiredFormat;
function requireFormat() {
  if (hasRequiredFormat)
    return format;
  hasRequiredFormat = 1;
  format = function format2(url) {
    var result = "";
    result += url.protocol || "";
    result += url.slashes ? "//" : "";
    result += url.auth ? url.auth + "@" : "";
    if (url.hostname && url.hostname.indexOf(":") !== -1) {
      result += "[" + url.hostname + "]";
    } else {
      result += url.hostname || "";
    }
    result += url.port ? ":" + url.port : "";
    result += url.pathname || "";
    result += url.search || "";
    result += url.hash || "";
    return result;
  };
  return format;
}
var parse;
var hasRequiredParse;
function requireParse() {
  if (hasRequiredParse)
    return parse;
  hasRequiredParse = 1;
  function Url() {
    this.protocol = null;
    this.slashes = null;
    this.auth = null;
    this.port = null;
    this.hostname = null;
    this.hash = null;
    this.search = null;
    this.pathname = null;
  }
  var protocolPattern = /^([a-z0-9.+-]+:)/i, portPattern = /:[0-9]*$/, simplePathPattern = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/, delims = ["<", ">", '"', "`", " ", "\r", "\n", "	"], unwise = ["{", "}", "|", "\\", "^", "`"].concat(delims), autoEscape = ["'"].concat(unwise), nonHostChars = ["%", "/", "?", ";", "#"].concat(autoEscape), hostEndingChars = ["/", "?", "#"], hostnameMaxLen = 255, hostnamePartPattern = /^[+a-z0-9A-Z_-]{0,63}$/, hostnamePartStart = /^([+a-z0-9A-Z_-]{0,63})(.*)$/, hostlessProtocol = {
    "javascript": true,
    "javascript:": true
  }, slashedProtocol = {
    "http": true,
    "https": true,
    "ftp": true,
    "gopher": true,
    "file": true,
    "http:": true,
    "https:": true,
    "ftp:": true,
    "gopher:": true,
    "file:": true
  };
  function urlParse(url, slashesDenoteHost) {
    if (url && url instanceof Url) {
      return url;
    }
    var u = new Url();
    u.parse(url, slashesDenoteHost);
    return u;
  }
  Url.prototype.parse = function(url, slashesDenoteHost) {
    var i, l, lowerProto, hec, slashes, rest = url;
    rest = rest.trim();
    if (!slashesDenoteHost && url.split("#").length === 1) {
      var simplePath = simplePathPattern.exec(rest);
      if (simplePath) {
        this.pathname = simplePath[1];
        if (simplePath[2]) {
          this.search = simplePath[2];
        }
        return this;
      }
    }
    var proto = protocolPattern.exec(rest);
    if (proto) {
      proto = proto[0];
      lowerProto = proto.toLowerCase();
      this.protocol = proto;
      rest = rest.substr(proto.length);
    }
    if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
      slashes = rest.substr(0, 2) === "//";
      if (slashes && !(proto && hostlessProtocol[proto])) {
        rest = rest.substr(2);
        this.slashes = true;
      }
    }
    if (!hostlessProtocol[proto] && (slashes || proto && !slashedProtocol[proto])) {
      var hostEnd = -1;
      for (i = 0; i < hostEndingChars.length; i++) {
        hec = rest.indexOf(hostEndingChars[i]);
        if (hec !== -1 && (hostEnd === -1 || hec < hostEnd)) {
          hostEnd = hec;
        }
      }
      var auth, atSign;
      if (hostEnd === -1) {
        atSign = rest.lastIndexOf("@");
      } else {
        atSign = rest.lastIndexOf("@", hostEnd);
      }
      if (atSign !== -1) {
        auth = rest.slice(0, atSign);
        rest = rest.slice(atSign + 1);
        this.auth = auth;
      }
      hostEnd = -1;
      for (i = 0; i < nonHostChars.length; i++) {
        hec = rest.indexOf(nonHostChars[i]);
        if (hec !== -1 && (hostEnd === -1 || hec < hostEnd)) {
          hostEnd = hec;
        }
      }
      if (hostEnd === -1) {
        hostEnd = rest.length;
      }
      if (rest[hostEnd - 1] === ":") {
        hostEnd--;
      }
      var host = rest.slice(0, hostEnd);
      rest = rest.slice(hostEnd);
      this.parseHost(host);
      this.hostname = this.hostname || "";
      var ipv6Hostname = this.hostname[0] === "[" && this.hostname[this.hostname.length - 1] === "]";
      if (!ipv6Hostname) {
        var hostparts = this.hostname.split(/\./);
        for (i = 0, l = hostparts.length; i < l; i++) {
          var part2 = hostparts[i];
          if (!part2) {
            continue;
          }
          if (!part2.match(hostnamePartPattern)) {
            var newpart = "";
            for (var j = 0, k = part2.length; j < k; j++) {
              if (part2.charCodeAt(j) > 127) {
                newpart += "x";
              } else {
                newpart += part2[j];
              }
            }
            if (!newpart.match(hostnamePartPattern)) {
              var validParts = hostparts.slice(0, i);
              var notHost = hostparts.slice(i + 1);
              var bit = part2.match(hostnamePartStart);
              if (bit) {
                validParts.push(bit[1]);
                notHost.unshift(bit[2]);
              }
              if (notHost.length) {
                rest = notHost.join(".") + rest;
              }
              this.hostname = validParts.join(".");
              break;
            }
          }
        }
      }
      if (this.hostname.length > hostnameMaxLen) {
        this.hostname = "";
      }
      if (ipv6Hostname) {
        this.hostname = this.hostname.substr(1, this.hostname.length - 2);
      }
    }
    var hash = rest.indexOf("#");
    if (hash !== -1) {
      this.hash = rest.substr(hash);
      rest = rest.slice(0, hash);
    }
    var qm = rest.indexOf("?");
    if (qm !== -1) {
      this.search = rest.substr(qm);
      rest = rest.slice(0, qm);
    }
    if (rest) {
      this.pathname = rest;
    }
    if (slashedProtocol[lowerProto] && this.hostname && !this.pathname) {
      this.pathname = "";
    }
    return this;
  };
  Url.prototype.parseHost = function(host) {
    var port = portPattern.exec(host);
    if (port) {
      port = port[0];
      if (port !== ":") {
        this.port = port.substr(1);
      }
      host = host.substr(0, host.length - port.length);
    }
    if (host) {
      this.hostname = host;
    }
  };
  parse = urlParse;
  return parse;
}
var hasRequiredMdurl;
function requireMdurl() {
  if (hasRequiredMdurl)
    return mdurl;
  hasRequiredMdurl = 1;
  mdurl.encode = requireEncode();
  mdurl.decode = requireDecode();
  mdurl.format = requireFormat();
  mdurl.parse = requireParse();
  return mdurl;
}
var uc_micro = {};
var regex$3;
var hasRequiredRegex$3;
function requireRegex$3() {
  if (hasRequiredRegex$3)
    return regex$3;
  hasRequiredRegex$3 = 1;
  regex$3 = /[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/;
  return regex$3;
}
var regex$2;
var hasRequiredRegex$2;
function requireRegex$2() {
  if (hasRequiredRegex$2)
    return regex$2;
  hasRequiredRegex$2 = 1;
  regex$2 = /[\0-\x1F\x7F-\x9F]/;
  return regex$2;
}
var regex$1;
var hasRequiredRegex$1;
function requireRegex$1() {
  if (hasRequiredRegex$1)
    return regex$1;
  hasRequiredRegex$1 = 1;
  regex$1 = /[\xAD\u0600-\u0605\u061C\u06DD\u070F\u08E2\u180E\u200B-\u200F\u202A-\u202E\u2060-\u2064\u2066-\u206F\uFEFF\uFFF9-\uFFFB]|\uD804[\uDCBD\uDCCD]|\uD82F[\uDCA0-\uDCA3]|\uD834[\uDD73-\uDD7A]|\uDB40[\uDC01\uDC20-\uDC7F]/;
  return regex$1;
}
var regex;
var hasRequiredRegex;
function requireRegex() {
  if (hasRequiredRegex)
    return regex;
  hasRequiredRegex = 1;
  regex = /[ \xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/;
  return regex;
}
var hasRequiredUc_micro;
function requireUc_micro() {
  if (hasRequiredUc_micro)
    return uc_micro;
  hasRequiredUc_micro = 1;
  uc_micro.Any = requireRegex$3();
  uc_micro.Cc = requireRegex$2();
  uc_micro.Cf = requireRegex$1();
  uc_micro.P = regex$4;
  uc_micro.Z = requireRegex();
  return uc_micro;
}
(function(exports) {
  function _class(obj) {
    return Object.prototype.toString.call(obj);
  }
  function isString(obj) {
    return _class(obj) === "[object String]";
  }
  var _hasOwnProperty = Object.prototype.hasOwnProperty;
  function has(object, key) {
    return _hasOwnProperty.call(object, key);
  }
  function assign(obj) {
    var sources = Array.prototype.slice.call(arguments, 1);
    sources.forEach(function(source) {
      if (!source) {
        return;
      }
      if (typeof source !== "object") {
        throw new TypeError(source + "must be object");
      }
      Object.keys(source).forEach(function(key) {
        obj[key] = source[key];
      });
    });
    return obj;
  }
  function arrayReplaceAt(src, pos, newElements) {
    return [].concat(src.slice(0, pos), newElements, src.slice(pos + 1));
  }
  function isValidEntityCode(c) {
    if (c >= 55296 && c <= 57343) {
      return false;
    }
    if (c >= 64976 && c <= 65007) {
      return false;
    }
    if ((c & 65535) === 65535 || (c & 65535) === 65534) {
      return false;
    }
    if (c >= 0 && c <= 8) {
      return false;
    }
    if (c === 11) {
      return false;
    }
    if (c >= 14 && c <= 31) {
      return false;
    }
    if (c >= 127 && c <= 159) {
      return false;
    }
    if (c > 1114111) {
      return false;
    }
    return true;
  }
  function fromCodePoint(c) {
    if (c > 65535) {
      c -= 65536;
      var surrogate1 = 55296 + (c >> 10), surrogate2 = 56320 + (c & 1023);
      return String.fromCharCode(surrogate1, surrogate2);
    }
    return String.fromCharCode(c);
  }
  var UNESCAPE_MD_RE = /\\([!"#$%&'()*+,\-.\/:;<=>?@[\\\]^_`{|}~])/g;
  var ENTITY_RE = /&([a-z#][a-z0-9]{1,31});/gi;
  var UNESCAPE_ALL_RE = new RegExp(UNESCAPE_MD_RE.source + "|" + ENTITY_RE.source, "gi");
  var DIGITAL_ENTITY_TEST_RE = /^#((?:x[a-f0-9]{1,8}|[0-9]{1,8}))/i;
  var entities2 = entitiesExports;
  function replaceEntityPattern(match, name) {
    var code = 0;
    if (has(entities2, name)) {
      return entities2[name];
    }
    if (name.charCodeAt(0) === 35 && DIGITAL_ENTITY_TEST_RE.test(name)) {
      code = name[1].toLowerCase() === "x" ? parseInt(name.slice(2), 16) : parseInt(name.slice(1), 10);
      if (isValidEntityCode(code)) {
        return fromCodePoint(code);
      }
    }
    return match;
  }
  function unescapeMd(str) {
    if (str.indexOf("\\") < 0) {
      return str;
    }
    return str.replace(UNESCAPE_MD_RE, "$1");
  }
  function unescapeAll(str) {
    if (str.indexOf("\\") < 0 && str.indexOf("&") < 0) {
      return str;
    }
    return str.replace(UNESCAPE_ALL_RE, function(match, escaped, entity) {
      if (escaped) {
        return escaped;
      }
      return replaceEntityPattern(match, entity);
    });
  }
  var HTML_ESCAPE_TEST_RE = /[&<>"]/;
  var HTML_ESCAPE_REPLACE_RE = /[&<>"]/g;
  var HTML_REPLACEMENTS = {
    "&": "&amp;",
    "<": "&lt;",
    ">": "&gt;",
    '"': "&quot;"
  };
  function replaceUnsafeChar(ch) {
    return HTML_REPLACEMENTS[ch];
  }
  function escapeHtml(str) {
    if (HTML_ESCAPE_TEST_RE.test(str)) {
      return str.replace(HTML_ESCAPE_REPLACE_RE, replaceUnsafeChar);
    }
    return str;
  }
  var REGEXP_ESCAPE_RE = /[.?*+^$[\]\\(){}|-]/g;
  function escapeRE(str) {
    return str.replace(REGEXP_ESCAPE_RE, "\\$&");
  }
  function isSpace2(code) {
    switch (code) {
      case 9:
      case 32:
        return true;
    }
    return false;
  }
  function isWhiteSpace(code) {
    if (code >= 8192 && code <= 8202) {
      return true;
    }
    switch (code) {
      case 9:
      case 10:
      case 11:
      case 12:
      case 13:
      case 32:
      case 160:
      case 5760:
      case 8239:
      case 8287:
      case 12288:
        return true;
    }
    return false;
  }
  var UNICODE_PUNCT_RE = regex$4;
  function isPunctChar(ch) {
    return UNICODE_PUNCT_RE.test(ch);
  }
  function isMdAsciiPunct(ch) {
    switch (ch) {
      case 33:
      case 34:
      case 35:
      case 36:
      case 37:
      case 38:
      case 39:
      case 40:
      case 41:
      case 42:
      case 43:
      case 44:
      case 45:
      case 46:
      case 47:
      case 58:
      case 59:
      case 60:
      case 61:
      case 62:
      case 63:
      case 64:
      case 91:
      case 92:
      case 93:
      case 94:
      case 95:
      case 96:
      case 123:
      case 124:
      case 125:
      case 126:
        return true;
      default:
        return false;
    }
  }
  function normalizeReference(str) {
    str = str.trim().replace(/\s+/g, " ");
    if ("ẞ".toLowerCase() === "Ṿ") {
      str = str.replace(/ẞ/g, "ß");
    }
    return str.toLowerCase().toUpperCase();
  }
  exports.lib = {};
  exports.lib.mdurl = requireMdurl();
  exports.lib.ucmicro = requireUc_micro();
  exports.assign = assign;
  exports.isString = isString;
  exports.has = has;
  exports.unescapeMd = unescapeMd;
  exports.unescapeAll = unescapeAll;
  exports.isValidEntityCode = isValidEntityCode;
  exports.fromCodePoint = fromCodePoint;
  exports.escapeHtml = escapeHtml;
  exports.arrayReplaceAt = arrayReplaceAt;
  exports.isSpace = isSpace2;
  exports.isWhiteSpace = isWhiteSpace;
  exports.isMdAsciiPunct = isMdAsciiPunct;
  exports.isPunctChar = isPunctChar;
  exports.escapeRE = escapeRE;
  exports.normalizeReference = normalizeReference;
})(utils);
var isSpace$1 = utils.isSpace;
var newline = function newline2(state, silent) {
  var pmax, max, ws, pos = state.pos;
  if (state.src.charCodeAt(pos) !== 10) {
    return false;
  }
  pmax = state.pending.length - 1;
  max = state.posMax;
  if (!silent) {
    if (pmax >= 0 && state.pending.charCodeAt(pmax) === 32) {
      if (pmax >= 1 && state.pending.charCodeAt(pmax - 1) === 32) {
        ws = pmax - 1;
        while (ws >= 1 && state.pending.charCodeAt(ws - 1) === 32)
          ws--;
        state.pending = state.pending.slice(0, ws);
        state.push("hardbreak", "br", 0);
      } else {
        state.pending = state.pending.slice(0, -1);
        state.push("softbreak", "br", 0);
      }
    } else {
      state.push("softbreak", "br", 0);
    }
  }
  pos++;
  while (pos < max && isSpace$1(state.src.charCodeAt(pos))) {
    pos++;
  }
  state.pos = pos;
  return true;
};
var isSpace = utils.isSpace;
var ESCAPED = [];
for (var i = 0; i < 256; i++) {
  ESCAPED.push(0);
}
"\\!\"#$%&'()*+,./:;<=>?@[]^_`{|}~-".split("").forEach(function(ch) {
  ESCAPED[ch.charCodeAt(0)] = 1;
});
var _escape = function escape(state, silent) {
  var ch1, ch2, origStr, escapedStr, token, pos = state.pos, max = state.posMax;
  if (state.src.charCodeAt(pos) !== 92)
    return false;
  pos++;
  if (pos >= max)
    return false;
  ch1 = state.src.charCodeAt(pos);
  if (ch1 === 10) {
    if (!silent) {
      state.push("hardbreak", "br", 0);
    }
    pos++;
    while (pos < max) {
      ch1 = state.src.charCodeAt(pos);
      if (!isSpace(ch1))
        break;
      pos++;
    }
    state.pos = pos;
    return true;
  }
  escapedStr = state.src[pos];
  if (ch1 >= 55296 && ch1 <= 56319 && pos + 1 < max) {
    ch2 = state.src.charCodeAt(pos + 1);
    if (ch2 >= 56320 && ch2 <= 57343) {
      escapedStr += state.src[pos + 1];
      pos++;
    }
  }
  origStr = "\\" + escapedStr;
  if (!silent) {
    token = state.push("text_special", "", 0);
    if (ch1 < 256 && ESCAPED[ch1] !== 0) {
      token.content = escapedStr;
    } else {
      token.content = origStr;
    }
    token.markup = origStr;
    token.info = "escape";
  }
  state.pos = pos + 1;
  return true;
};
function keepHardbreakSyntax(md) {
  md.inline.ruler.at("newline", (state, silent) => {
    const rval = newline(state, silent);
    if (rval && state.tokens.length && state.tokens[state.tokens.length - 1].type === "hardbreak")
      state.tokens[state.tokens.length - 1].attrSet("syntax", "  ");
    return rval;
  });
  md.inline.ruler.at("escape", (state, silent) => {
    const rval = _escape(state, silent);
    if (rval && state.tokens.length && state.tokens[state.tokens.length - 1].type === "hardbreak")
      state.tokens[state.tokens.length - 1].attrSet("syntax", "\\");
    return rval;
  });
  md.inline.ruler.after("html_inline", "html_breaks", (state) => {
    const res = state.src.slice(state.pos).match(/^\s*<br\s*\/?>/);
    if (res) {
      const token = state.push("hardbreak", "br", 0);
      token.attrPush(["syntax", "html"]);
      state.pos += res[0].length;
      return true;
    }
    return false;
  });
  md.renderer.rules.hardbreak = (tokens, idx, options) => `<br data-syntax="${tokens[idx].attrGet("syntax")}" ${options.xhtmlOut ? "/" : ""}>`;
}
function keepSyntax(md) {
  const escaped = /(\n(?<linestart>[#\-*+>])|(?<special>[`*\\~[\]]+))/;
  md.core.ruler.before("text_join", "tag-markdown-syntax", (state) => {
    const open = new state.Token("keep_md_open", "span", 1);
    open.attrSet("class", "keep-md");
    const close = new state.Token("keep_md_close", "span", -1);
    for (let i = 0; i < state.tokens.length; i++) {
      const block2 = state.tokens[i];
      if (block2.type !== "inline")
        continue;
      for (let j = 0; j < block2.children.length; j++) {
        const token = block2.children[j];
        if (token.type === "text") {
          const match = escaped.exec(token.content);
          if (match) {
            const index = match.groups.linestart ? match.index + 1 : match.index;
            const matchChars = match.groups.linestart ?? match.groups.special;
            const contentNext = index + matchChars.length;
            block2.children.splice(
              j,
              1,
              Object.assign({}, token, { content: token.content.slice(0, index) }),
              Object.assign({}, open),
              Object.assign({}, token, { content: token.content.slice(index, contentNext) }),
              Object.assign({}, close),
              Object.assign({}, token, { content: token.content.slice(contentNext) })
            );
            j += 3;
          }
        }
      }
    }
    return false;
  });
}
const markdownit = MarkdownIt("commonmark", { html: false, breaks: false }).enable("strikethrough").enable("table").use(taskLists, { enable: true, labelAfter: true }).use(frontMatter, (fm) => {
}).use(splitMixedLists).use(markdownUnderlines).use(keepHardbreakSyntax).use(callouts).use(keepSyntax).use(markdownitMentions).use(implicitFigures);
markdownit.renderer.rules.front_matter = (tokens, idx, options) => `<pre id="frontmatter"><code>${utils.escapeHtml(tokens[idx].meta)}</code></pre>`;
markdownit.renderer.rules.bullet_list_open = (tokens, idx, options) => {
  tokens[idx].attrs = [
    ...tokens[idx].attrs || [],
    ["data-bullet", tokens[idx].markup]
  ];
  return markdownit.renderer.renderToken(tokens, idx, options);
};
const absolutePath = function(base, rel) {
  if (!rel) {
    return base;
  }
  if (rel[0] === "/") {
    return rel;
  }
  base = base.split("/");
  rel = rel.split("/");
  while (rel[0] === ".." || rel[0] === ".") {
    if (rel[0] === "..") {
      base.pop();
    }
    rel.shift();
  }
  return base.concat(rel).join("/");
};
const basedir = function(file) {
  const end = file.lastIndexOf("/");
  return end > 0 ? file.slice(0, end) : file.slice(0, end + 1);
};
const domHref = function(node, relativePath) {
  const ref = node.attrs.href;
  if (!ref) {
    return ref;
  }
  if (ref.match(/^[a-zA-Z]*:/)) {
    return ref;
  }
  if (ref.startsWith("#")) {
    return ref;
  }
  const match = ref.match(/^([^?]*)\?fileId=(\d+)/);
  if (match) {
    const [, relPath, id] = match;
    const currentDir = basedir(relativePath || OCA.Viewer.file);
    const dir = absolutePath(currentDir, basedir(relPath));
    if (relPath.length > 1 && relPath.endsWith("/")) {
      return generateUrl(`/apps/files/?dir=${dir}&fileId=${id}`);
    } else {
      return generateUrl(`/apps/files/?dir=${dir}&openfile=${id}#relPath=${relPath}`);
    }
  }
  return ref;
};
const parseHref = function(dom) {
  const ref = dom.getAttribute("href");
  if (!ref) {
    return ref;
  }
  const match = ref.match(/\?dir=([^&]*)&openfile=([^&]*)#relPath=([^&]*)/);
  if (match) {
    const [, , id, path] = match;
    return `${path}?fileId=${id}`;
  }
  return ref;
};
const openLink = function(event, _attrs) {
  const linkElement = event.target.closest("a");
  const htmlHref = linkElement.href;
  const query = OC.parseQueryString(htmlHref);
  const fragment = htmlHref.split("#").pop();
  const fragmentQuery = OC.parseQueryString(fragment);
  if ((query == null ? void 0 : query.dir) && (fragmentQuery == null ? void 0 : fragmentQuery.relPath)) {
    const filename = fragmentQuery.relPath.split("/").pop();
    const path = `${query.dir}/${filename}`;
    document.title = `${filename} - ${OC.theme.title}`;
    if (window.location.pathname.match(/apps\/files\/$/))
      ;
    OCA.Viewer.open({ path });
    return;
  }
  if (query == null ? void 0 : query.fileId) {
    window.open(generateUrl(`/f/${query.fileId}`), "_self");
    return;
  }
  if (!markdownit.validateLink(htmlHref)) {
    logger.error("Invalid link", { htmlHref });
    return false;
  }
  if (fragment) {
    const el2 = document.getElementById(fragment);
    if (el2) {
      el2.scrollIntoView();
      window.location.hash = fragment;
      return;
    }
  }
  window.open(htmlHref);
  return true;
};
const clickHandler = ({ editor, type, onClick }) => {
  return new Plugin({
    props: {
      key: new PluginKey("textLink"),
      handleClick: (view, pos, event) => {
        const $clicked = view.state.doc.resolve(pos);
        const link = $clicked.marks().find((m) => m.type.name === type.name);
        if (!link) {
          return false;
        }
        if (!link.attrs.href) {
          logger.warn("Could not determine href of link.");
          logger.debug("Link", { link });
          return false;
        }
        if (event.button === 0 && !event.ctrlKey) {
          event.stopPropagation();
          return onClick == null ? void 0 : onClick(event, link.attrs);
        }
      }
    }
  });
};
const clickPreventer = () => {
  return new Plugin({
    props: {
      key: new PluginKey("textAvoidLinkClick"),
      handleDOMEvents: {
        click: (view, event) => {
          if (!view.editable) {
            event.preventDefault();
            return false;
          }
        }
      }
    }
  });
};
const Link = TipTapLink.extend({
  addOptions() {
    var _a2;
    return {
      ...(_a2 = this.parent) == null ? void 0 : _a2.call(this),
      onClick: openLink,
      relativePath: null
    };
  },
  addAttributes() {
    return {
      href: {
        default: null
      },
      title: {
        default: null
      }
    };
  },
  inclusive: false,
  parseHTML: [
    {
      tag: "a[href]",
      getAttrs: (dom) => ({
        href: parseHref(dom),
        title: dom.getAttribute("title")
      })
    }
  ],
  renderHTML(options) {
    const { mark } = options;
    return ["a", {
      ...mark.attrs,
      href: domHref(mark, this.options.relativePath),
      rel: "noopener noreferrer nofollow"
    }, 0];
  },
  addProseMirrorPlugins() {
    const plugins = this.parent().filter(({ key }) => {
      return !key.startsWith("handleClickLink");
    });
    if (!this.options.openOnClick) {
      return plugins;
    }
    return [
      ...plugins,
      clickHandler({
        editor: this.editor,
        type: this.type,
        onClick: this.options.onClick
      }),
      clickPreventer()
    ];
  }
});
const Strike = TipTapStrike.extend({
  parseHTML() {
    return [
      {
        tag: "s"
      },
      {
        tag: "del"
      },
      {
        tag: "strike"
      },
      {
        style: "text-decoration",
        getAttrs: (value) => value === "line-through"
      }
    ];
  },
  renderHTML() {
    return ["s", 0];
  },
  toMarkdown: {
    open: "~~",
    close: "~~",
    mixable: true,
    expelEnclosingWhitespace: true
  }
});
const Strong = Bold.extend({
  name: "strong",
  addInputRules() {
    return [
      markInputRule({
        find: starInputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: starPasteRegex,
        type: this.type
      })
    ];
  }
});
const Underline = TipTapUnderline.extend({
  parseHTML() {
    return [
      {
        tag: "u"
      },
      {
        style: "text-decoration",
        getAttrs: (value) => value === "underline"
      }
    ];
  },
  renderHTML() {
    return ["u", 0];
  },
  toMarkdown: {
    open: "__",
    close: "__",
    mixable: true,
    expelEnclosingWhitespace: true
  },
  addInputRules() {
    return [
      markInputRule({
        find: underscoreInputRegex,
        type: this.type
      })
    ];
  },
  addPasteRules() {
    return [
      markPasteRule({
        find: underscorePasteRegex,
        type: this.type
      })
    ];
  }
});
const Italic = TipTapItalic.extend({
  name: "em"
});
const RichText = Extension.create({
  name: "RichText",
  addOptions() {
    return {
      link: {},
      extensions: []
    };
  },
  addExtensions() {
    const defaultExtensions = [
      Document,
      Text,
      Paragraph,
      HardBreak,
      Heading,
      Strong,
      Italic,
      Strike,
      Blockquote,
      CharacterCount,
      Code,
      CodeBlock,
      BulletList,
      HorizontalRule,
      OrderedList,
      ListItem,
      Table,
      TaskList,
      TaskItem,
      Callout,
      Underline,
      Image$1,
      ImageInline,
      Dropcursor,
      KeepSyntax,
      FrontMatter,
      Mention.configure({
        HTMLAttributes: {
          class: "mention"
        }
      })
    ];
    if (this.options.link !== false) {
      defaultExtensions.push(Link.configure({
        ...this.options.link,
        openOnClick: true,
        validate: (href) => /^https?:\/\//.test(href),
        relativePath: this.options.relativePath
      }));
    }
    const additionalExtensionNames = this.options.extensions.map((e) => e.name);
    return [
      ...defaultExtensions.filter((e) => !additionalExtensionNames.includes(e.name)),
      ...this.options.extensions
    ];
  }
});
const RichTextReader_vue_vue_type_style_index_0_lang = "";
const _sfc_main = {
  name: "RichTextReader",
  components: { BaseReader },
  provide: {
    renderHtml(content) {
      return markdownit.render(content);
    },
    extensions() {
      return [
        RichText.configure({
          link: {
            onClick: (event, attrs) => {
              this.$emit("click-link", event, attrs);
              return true;
            }
          }
        })
      ];
    }
  },
  props: {
    content: {
      type: String,
      required: true
    }
  },
  mounted() {
    this.$el.addEventListener("click", this.preventOpeningLinks, true);
  },
  unmounted() {
    this.$el.removeEventListener("click", this.preventOpeningLinks, true);
  },
  methods: {
    preventOpeningLinks(event) {
      if (event.target.closest("a") && event.button === 0 && !event.ctrlKey) {
        event.preventDefault();
      }
    }
  }
};
var _sfc_render = function render16() {
  var _vm = this, _c = _vm._self._c;
  return _c("BaseReader", { attrs: { "content": _vm.content }, on: { "click-link": (e, a) => _vm.$emit("click-link", e, a) } });
};
var _sfc_staticRenderFns = [];
var __component__ = /* @__PURE__ */ normalizeComponent(
  _sfc_main,
  _sfc_render,
  _sfc_staticRenderFns,
  false,
  null,
  null,
  null,
  null
);
const RichTextReader = __component__.exports;
class AttachmentResolver {
  constructor({ session, user, shareToken, currentDirectory, fileId }) {
    __privateAdd(this, _getImageAttachmentUrl);
    __privateAdd(this, _getMediaPreviewUrl);
    __privateAdd(this, _textApiParams);
    __privateAdd(this, _previewUrl);
    __privateAdd(this, _davUrl);
    __privateAdd(this, _relativePath);
    __privateAdd(this, _filePath);
    __privateAdd(this, _session, void 0);
    __privateAdd(this, _user, void 0);
    __privateAdd(this, _shareToken, void 0);
    __privateAdd(this, _currentDirectory, void 0);
    __privateAdd(this, _attachmentDirectory, void 0);
    __publicField(this, "ATTACHMENT_TYPE_IMAGE", "image");
    __publicField(this, "ATTACHMENT_TYPE_MEDIA", "media");
    __privateSet(this, _session, session);
    __privateSet(this, _user, user);
    __privateSet(this, _shareToken, shareToken);
    __privateSet(this, _currentDirectory, currentDirectory);
    fileId || (fileId = session == null ? void 0 : session.documentId);
    __privateSet(this, _attachmentDirectory, `.attachments.${fileId}`);
  }
  resolve(src) {
    var _a2, _b2;
    if (__privateGet(this, _session) && src.startsWith("text://")) {
      const imageFileName = getQueryVariable(src, "imageFileName");
      return [{
        type: this.ATTACHMENT_TYPE_IMAGE,
        url: __privateMethod(this, _getImageAttachmentUrl, getImageAttachmentUrl_fn).call(this, imageFileName)
      }];
    }
    if (__privateGet(this, _session) && src.startsWith(`.attachments.${(_a2 = __privateGet(this, _session)) == null ? void 0 : _a2.documentId}/`)) {
      const imageFileName = decodeURIComponent(src.replace(`.attachments.${(_b2 = __privateGet(this, _session)) == null ? void 0 : _b2.documentId}/`, "").split("?")[0]);
      return [
        {
          type: this.ATTACHMENT_TYPE_IMAGE,
          url: __privateMethod(this, _getImageAttachmentUrl, getImageAttachmentUrl_fn).call(this, imageFileName)
        },
        {
          type: this.ATTACHMENT_TYPE_MEDIA,
          url: __privateMethod(this, _getMediaPreviewUrl, getMediaPreviewUrl_fn).call(this, imageFileName),
          name: imageFileName
        }
      ];
    }
    if (isDirectUrl(src)) {
      return [{
        type: this.ATTACHMENT_TYPE_IMAGE,
        url: src
      }];
    }
    if (hasPreview(src)) {
      return [{
        type: this.ATTACHMENT_TYPE_IMAGE,
        url: __privateMethod(this, _previewUrl, previewUrl_fn).call(this, src)
      }];
    }
    if (src.match(/^\.attachments\.\d+\//)) {
      const imageFileName = __privateMethod(this, _relativePath, relativePath_fn).call(this, src).replace(/\.attachments\.\d+\//, "");
      return [
        {
          type: this.ATTACHMENT_TYPE_IMAGE,
          url: __privateMethod(this, _davUrl, davUrl_fn).call(this, src)
        },
        {
          type: this.ATTACHMENT_TYPE_IMAGE,
          url: __privateMethod(this, _getImageAttachmentUrl, getImageAttachmentUrl_fn).call(this, imageFileName)
        },
        {
          type: this.ATTACHMENT_TYPE_MEDIA,
          url: __privateMethod(this, _getMediaPreviewUrl, getMediaPreviewUrl_fn).call(this, imageFileName),
          name: imageFileName
        }
      ];
    }
    return [{
      type: this.ATTACHMENT_TYPE_IMAGE,
      url: __privateMethod(this, _davUrl, davUrl_fn).call(this, src)
    }];
  }
  getMediaMetadataUrl(mediaFileName) {
    if (__privateGet(this, _user) || !__privateGet(this, _shareToken)) {
      return generateUrl("/apps/text/mediaMetadata?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&mediaFileName={mediaFileName}", {
        ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
        mediaFileName
      });
    }
    return generateUrl("/apps/text/mediaMetadata?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&mediaFileName={mediaFileName}&shareToken={shareToken}", {
      ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
      mediaFileName,
      shareToken: __privateGet(this, _shareToken)
    });
  }
}
_session = new WeakMap();
_user = new WeakMap();
_shareToken = new WeakMap();
_currentDirectory = new WeakMap();
_attachmentDirectory = new WeakMap();
_getImageAttachmentUrl = new WeakSet();
getImageAttachmentUrl_fn = function(imageFileName, preferRawImage = false) {
  if (!__privateGet(this, _session)) {
    return __privateMethod(this, _davUrl, davUrl_fn).call(this, `${__privateGet(this, _attachmentDirectory)}/${imageFileName}`);
  }
  if (__privateGet(this, _user) || !__privateGet(this, _shareToken)) {
    return generateUrl("/apps/text/image?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&imageFileName={imageFileName}&preferRawImage={preferRawImage}", {
      ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
      imageFileName,
      preferRawImage: preferRawImage ? 1 : 0
    });
  }
  return generateUrl("/apps/text/image?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&imageFileName={imageFileName}&shareToken={shareToken}&preferRawImage={preferRawImage}", {
    ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
    imageFileName,
    shareToken: __privateGet(this, _shareToken),
    preferRawImage: preferRawImage ? 1 : 0
  });
};
_getMediaPreviewUrl = new WeakSet();
getMediaPreviewUrl_fn = function(mediaFileName) {
  if (__privateGet(this, _user) || !__privateGet(this, _shareToken)) {
    return generateUrl("/apps/text/mediaPreview?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&mediaFileName={mediaFileName}", {
      ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
      mediaFileName
    });
  }
  return generateUrl("/apps/text/mediaPreview?documentId={documentId}&sessionId={sessionId}&sessionToken={sessionToken}&mediaFileName={mediaFileName}&shareToken={shareToken}", {
    ...__privateMethod(this, _textApiParams, textApiParams_fn).call(this),
    mediaFileName,
    shareToken: __privateGet(this, _shareToken)
  });
};
_textApiParams = new WeakSet();
textApiParams_fn = function() {
  if (__privateGet(this, _session)) {
    return {
      documentId: __privateGet(this, _session).documentId,
      sessionId: __privateGet(this, _session).id,
      sessionToken: __privateGet(this, _session).token
    };
  }
  return {};
};
_previewUrl = new WeakSet();
previewUrl_fn = function(src) {
  const imageFileId = getQueryVariable(src, "fileId");
  const path = __privateMethod(this, _filePath, filePath_fn).call(this, src);
  const fileQuery = `file=${encodeURIComponent(path)}`;
  const query = fileQuery + "&x=1024&y=1024&a=true";
  if (__privateGet(this, _user) && imageFileId) {
    return generateUrl(`/core/preview?fileId=${imageFileId}&${query}`);
  }
  if (__privateGet(this, _user)) {
    return generateUrl(`/core/preview.png?${query}`);
  }
  if (__privateGet(this, _shareToken)) {
    return generateUrl(`/apps/files_sharing/publicpreview/${__privateGet(this, _shareToken)}?${query}`);
  }
  logger.error("No way to authenticate image retrival - need to be logged in or provide a token");
  return src;
};
_davUrl = new WeakSet();
davUrl_fn = function(src) {
  if (__privateGet(this, _user)) {
    const uid = __privateGet(this, _user).uid;
    const encoded = encodeURI(__privateMethod(this, _filePath, filePath_fn).call(this, src));
    return generateRemoteUrl(`dav/files/${uid}${encoded}`);
  }
  const path = __privateMethod(this, _filePath, filePath_fn).call(this, src).split("/");
  const basename = path.pop();
  const dirname = path.join("/");
  return generateUrl("/s/{token}/download?path={dirname}&files={basename}", {
    token: __privateGet(this, _shareToken),
    basename,
    dirname
  });
};
_relativePath = new WeakSet();
relativePath_fn = function(src) {
  if (src.startsWith("text://")) {
    return [
      __privateGet(this, _attachmentDirectory),
      getQueryVariable(src, "imageFileName")
    ].join("/");
  }
  return decodeURI(src.split("?")[0]);
};
_filePath = new WeakSet();
filePath_fn = function(src) {
  const f = [
    __privateGet(this, _currentDirectory),
    __privateMethod(this, _relativePath, relativePath_fn).call(this, src)
  ].join("/");
  return pathNormalize(f);
};
function isDirectUrl(src) {
  return src.startsWith("http://") || src.startsWith("https://") || src.startsWith("data:") || src.match(/^(\/index.php)?\/core\/preview/) || src.match(/^(\/index.php)?\/apps\/files_sharing\/publicpreview\//);
}
function hasPreview(src) {
  return getQueryVariable(src, "hasPreview") === "true";
}
function getQueryVariable(src, variable) {
  const query = src.split("?")[1];
  if (typeof query === "undefined") {
    return;
  }
  const vars = query.split(/[&#]/);
  if (typeof vars === "undefined") {
    return;
  }
  for (let i = 0; i < vars.length; i++) {
    const pair = vars[i].split("=");
    if (decodeURIComponent(pair[0]) === variable) {
      return decodeURIComponent(pair[1]);
    }
  }
}
export {
  ATTACHMENT_RESOLVER,
  AttachmentResolver,
  OUTLINE_ACTIONS,
  OUTLINE_STATE,
  RichTextReader
};
